Class: Google::Apis::SheetsV4::AppendValuesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The response when updating a range of values in a spreadsheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppendValuesResponse



559
560
561
# File 'lib/google/apis/sheets_v4/classes.rb', line 559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spreadsheet_idString

The spreadsheet the updates were applied to. Corresponds to the JSON property spreadsheetId



546
547
548
# File 'lib/google/apis/sheets_v4/classes.rb', line 546

def spreadsheet_id
  @spreadsheet_id
end

#table_rangeString

The range (in A1 notation) of the table that values are being appended to ( before the values were appended). Empty if no table was found. Corresponds to the JSON property tableRange



552
553
554
# File 'lib/google/apis/sheets_v4/classes.rb', line 552

def table_range
  @table_range
end

#updatesGoogle::Apis::SheetsV4::UpdateValuesResponse

The response when updating a range of values in a spreadsheet. Corresponds to the JSON property updates



557
558
559
# File 'lib/google/apis/sheets_v4/classes.rb', line 557

def updates
  @updates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



564
565
566
567
568
# File 'lib/google/apis/sheets_v4/classes.rb', line 564

def update!(**args)
  @spreadsheet_id = args[:spreadsheet_id] if args.key?(:spreadsheet_id)
  @table_range = args[:table_range] if args.key?(:table_range)
  @updates = args[:updates] if args.key?(:updates)
end