Class: Google::Apis::SheetsV4::BandedRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A banded (alternating colors) range in a sheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BandedRange

Returns a new instance of BandedRange.



704
705
706
# File 'lib/google/apis/sheets_v4/classes.rb', line 704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#banded_range_idFixnum

The ID of the banded range. If unset, refer to banded_range_reference. Corresponds to the JSON property bandedRangeId

Returns:

  • (Fixnum)


651
652
653
# File 'lib/google/apis/sheets_v4/classes.rb', line 651

def banded_range_id
  @banded_range_id
end

#banded_range_referenceString

Output only. The reference of the banded range, used to identify the ID that is not supported by the banded_range_id. Corresponds to the JSON property bandedRangeReference

Returns:

  • (String)


657
658
659
# File 'lib/google/apis/sheets_v4/classes.rb', line 657

def banded_range_reference
  @banded_range_reference
end

#column_propertiesGoogle::Apis::SheetsV4::BandingProperties

Properties referring a single dimension (either row or column). If both BandedRange.row_properties and BandedRange.column_properties are set, the fill colors are applied to cells according to the following rules: * header_color and footer_color take priority over band colors. * first_band_color takes priority over second_band_color. * row_properties takes priority over column_properties. For example, the first row color takes priority over the first column color, but the first column color takes priority over the second row color. Similarly, the row header takes priority over the column header in the top left cell, but the column header takes priority over the first row color if the row header is not set. Corresponds to the JSON property columnProperties



671
672
673
# File 'lib/google/apis/sheets_v4/classes.rb', line 671

def column_properties
  @column_properties
end

#rangeGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, i.e. the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id: 123456, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id: 123456 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property range



688
689
690
# File 'lib/google/apis/sheets_v4/classes.rb', line 688

def range
  @range
end

#row_propertiesGoogle::Apis::SheetsV4::BandingProperties

Properties referring a single dimension (either row or column). If both BandedRange.row_properties and BandedRange.column_properties are set, the fill colors are applied to cells according to the following rules: * header_color and footer_color take priority over band colors. * first_band_color takes priority over second_band_color. * row_properties takes priority over column_properties. For example, the first row color takes priority over the first column color, but the first column color takes priority over the second row color. Similarly, the row header takes priority over the column header in the top left cell, but the column header takes priority over the first row color if the row header is not set. Corresponds to the JSON property rowProperties



702
703
704
# File 'lib/google/apis/sheets_v4/classes.rb', line 702

def row_properties
  @row_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



709
710
711
712
713
714
715
# File 'lib/google/apis/sheets_v4/classes.rb', line 709

def update!(**args)
  @banded_range_id = args[:banded_range_id] if args.key?(:banded_range_id)
  @banded_range_reference = args[:banded_range_reference] if args.key?(:banded_range_reference)
  @column_properties = args[:column_properties] if args.key?(:column_properties)
  @range = args[:range] if args.key?(:range)
  @row_properties = args[:row_properties] if args.key?(:row_properties)
end