Class: Google::Apis::SheetsV4::BasicChartAxis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

An axis of the chart. A chart may not have more than one axis per axis position.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BasicChartAxis

Returns a new instance of BasicChartAxis.



1147
1148
1149
# File 'lib/google/apis/sheets_v4/classes.rb', line 1147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#formatGoogle::Apis::SheetsV4::TextFormat

The format of a run of text in a cell. Absent values indicate that the field isn't specified. Corresponds to the JSON property format



1123
1124
1125
# File 'lib/google/apis/sheets_v4/classes.rb', line 1123

def format
  @format
end

#positionString

The position of this axis. Corresponds to the JSON property position

Returns:

  • (String)


1128
1129
1130
# File 'lib/google/apis/sheets_v4/classes.rb', line 1128

def position
  @position
end

#titleString

The title of this axis. If set, this overrides any title inferred from headers of the data. Corresponds to the JSON property title

Returns:

  • (String)


1134
1135
1136
# File 'lib/google/apis/sheets_v4/classes.rb', line 1134

def title
  @title
end

#title_text_positionGoogle::Apis::SheetsV4::TextPosition

Position settings for text. Corresponds to the JSON property titleTextPosition



1139
1140
1141
# File 'lib/google/apis/sheets_v4/classes.rb', line 1139

def title_text_position
  @title_text_position
end

#view_window_optionsGoogle::Apis::SheetsV4::ChartAxisViewWindowOptions

The options that define a "view window" for a chart (such as the visible values in an axis). Corresponds to the JSON property viewWindowOptions



1145
1146
1147
# File 'lib/google/apis/sheets_v4/classes.rb', line 1145

def view_window_options
  @view_window_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1152
1153
1154
1155
1156
1157
1158
# File 'lib/google/apis/sheets_v4/classes.rb', line 1152

def update!(**args)
  @format = args[:format] if args.key?(:format)
  @position = args[:position] if args.key?(:position)
  @title = args[:title] if args.key?(:title)
  @title_text_position = args[:title_text_position] if args.key?(:title_text_position)
  @view_window_options = args[:view_window_options] if args.key?(:view_window_options)
end