Class: Google::Apis::SheetsV4::BasicSeriesDataPointStyleOverride
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BasicSeriesDataPointStyleOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Style override settings for a single series data point.
Instance Attribute Summary collapse
-
#color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space.
-
#color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
-
#index ⇒ Fixnum
The zero-based index of the series data point.
-
#point_style ⇒ Google::Apis::SheetsV4::PointStyle
The style of a point on the chart.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BasicSeriesDataPointStyleOverride
constructor
A new instance of BasicSeriesDataPointStyleOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BasicSeriesDataPointStyleOverride
Returns a new instance of BasicSeriesDataPointStyleOverride.
1541 1542 1543 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1541 def initialize(**args) update!(**args) end |
Instance Attribute Details
#color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property color
1524 1525 1526 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1524 def color @color end |
#color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
Corresponds to the JSON property colorStyle
1529 1530 1531 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1529 def color_style @color_style end |
#index ⇒ Fixnum
The zero-based index of the series data point.
Corresponds to the JSON property index
1534 1535 1536 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1534 def index @index end |
#point_style ⇒ Google::Apis::SheetsV4::PointStyle
The style of a point on the chart.
Corresponds to the JSON property pointStyle
1539 1540 1541 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1539 def point_style @point_style end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1546 1547 1548 1549 1550 1551 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1546 def update!(**args) @color = args[:color] if args.key?(:color) @color_style = args[:color_style] if args.key?(:color_style) @index = args[:index] if args.key?(:index) @point_style = args[:point_style] if args.key?(:point_style) end |