Class: Google::Apis::SheetsV4::BatchGetValuesByDataFilterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The request for retrieving a range of values in a spreadsheet selected by a set of DataFilters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchGetValuesByDataFilterRequest

Returns a new instance of BatchGetValuesByDataFilterRequest.



1682
1683
1684
# File 'lib/google/apis/sheets_v4/classes.rb', line 1682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_filtersArray<Google::Apis::SheetsV4::DataFilter>

The data filters used to match the ranges of values to retrieve. Ranges that match any of the specified data filters are included in the response. Corresponds to the JSON property dataFilters



1659
1660
1661
# File 'lib/google/apis/sheets_v4/classes.rb', line 1659

def data_filters
  @data_filters
end

#date_time_render_optionString

How dates, times, and durations should be represented in the output. This is ignored if value_render_option is FORMATTED_VALUE. The default dateTime render option is SERIAL_NUMBER. Corresponds to the JSON property dateTimeRenderOption

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/sheets_v4/classes.rb', line 1666

def date_time_render_option
  @date_time_render_option
end

#major_dimensionString

The major dimension that results should use. For example, if the spreadsheet data is: A1=1,B1=2,A2=3,B2=4, then a request that selects that range and sets majorDimension=ROWS returns [[1,2],[3,4]], whereas a request that sets majorDimension=COLUMNS returns [[1,3],[2,4]]. Corresponds to the JSON property majorDimension

Returns:

  • (String)


1674
1675
1676
# File 'lib/google/apis/sheets_v4/classes.rb', line 1674

def major_dimension
  @major_dimension
end

#value_render_optionString

How values should be represented in the output. The default render option is FORMATTED_VALUE. Corresponds to the JSON property valueRenderOption

Returns:

  • (String)


1680
1681
1682
# File 'lib/google/apis/sheets_v4/classes.rb', line 1680

def value_render_option
  @value_render_option
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1687
1688
1689
1690
1691
1692
# File 'lib/google/apis/sheets_v4/classes.rb', line 1687

def update!(**args)
  @data_filters = args[:data_filters] if args.key?(:data_filters)
  @date_time_render_option = args[:date_time_render_option] if args.key?(:date_time_render_option)
  @major_dimension = args[:major_dimension] if args.key?(:major_dimension)
  @value_render_option = args[:value_render_option] if args.key?(:value_render_option)
end