Class: Google::Apis::SheetsV4::BatchUpdateValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BatchUpdateValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The request for updating more than one range of values in a spreadsheet.
Instance Attribute Summary collapse
-
#data ⇒ Array<Google::Apis::SheetsV4::ValueRange>
The new values to apply to the spreadsheet.
-
#include_values_in_response ⇒ Boolean
(also: #include_values_in_response?)
Determines if the update response should include the values of the cells that were updated.
-
#response_date_time_render_option ⇒ String
Determines how dates, times, and durations in the response should be rendered.
-
#response_value_render_option ⇒ String
Determines how values in the response should be rendered.
-
#value_input_option ⇒ String
How the input data should be interpreted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchUpdateValuesRequest
constructor
A new instance of BatchUpdateValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchUpdateValuesRequest
Returns a new instance of BatchUpdateValuesRequest.
1964 1965 1966 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Array<Google::Apis::SheetsV4::ValueRange>
The new values to apply to the spreadsheet.
Corresponds to the JSON property data
1933 1934 1935 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1933 def data @data end |
#include_values_in_response ⇒ Boolean Also known as: include_values_in_response?
Determines if the update response should include the values of the cells that
were updated. By default, responses do not include the updated values. The
updatedData field within each of the BatchUpdateValuesResponse.responses
contains the updated values. If the range to write was larger than the range
actually written, the response includes all values in the requested range (
excluding trailing empty rows and columns).
Corresponds to the JSON property includeValuesInResponse
1943 1944 1945 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1943 def include_values_in_response @include_values_in_response end |
#response_date_time_render_option ⇒ String
Determines how dates, times, and durations in the response should be rendered.
This is ignored if response_value_render_option is FORMATTED_VALUE. The
default dateTime render option is SERIAL_NUMBER.
Corresponds to the JSON property responseDateTimeRenderOption
1951 1952 1953 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1951 def response_date_time_render_option @response_date_time_render_option end |
#response_value_render_option ⇒ String
Determines how values in the response should be rendered. The default render
option is FORMATTED_VALUE.
Corresponds to the JSON property responseValueRenderOption
1957 1958 1959 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1957 def response_value_render_option @response_value_render_option end |
#value_input_option ⇒ String
How the input data should be interpreted.
Corresponds to the JSON property valueInputOption
1962 1963 1964 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1962 def value_input_option @value_input_option end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1969 1970 1971 1972 1973 1974 1975 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1969 def update!(**args) @data = args[:data] if args.key?(:data) @include_values_in_response = args[:include_values_in_response] if args.key?(:include_values_in_response) @response_date_time_render_option = args[:response_date_time_render_option] if args.key?(:response_date_time_render_option) @response_value_render_option = args[:response_value_render_option] if args.key?(:response_value_render_option) @value_input_option = args[:value_input_option] if args.key?(:value_input_option) end |