Class: Google::Apis::SheetsV4::BatchUpdateValuesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The response when updating a range of values in a spreadsheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchUpdateValuesResponse

Returns a new instance of BatchUpdateValuesResponse.



2013
2014
2015
# File 'lib/google/apis/sheets_v4/classes.rb', line 2013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#responsesArray<Google::Apis::SheetsV4::UpdateValuesResponse>

One UpdateValuesResponse per requested range, in the same order as the requests appeared. Corresponds to the JSON property responses

Returns:



1986
1987
1988
# File 'lib/google/apis/sheets_v4/classes.rb', line 1986

def responses
  @responses
end

#spreadsheet_idString

The spreadsheet the updates were applied to. Corresponds to the JSON property spreadsheetId

Returns:



1991
1992
1993
# File 'lib/google/apis/sheets_v4/classes.rb', line 1991

def spreadsheet_id
  @spreadsheet_id
end

#total_updated_cellsFixnum

The total number of cells updated. Corresponds to the JSON property totalUpdatedCells

Returns:



1996
1997
1998
# File 'lib/google/apis/sheets_v4/classes.rb', line 1996

def total_updated_cells
  @total_updated_cells
end

#total_updated_columnsFixnum

The total number of columns where at least one cell in the column was updated. Corresponds to the JSON property totalUpdatedColumns

Returns:



2001
2002
2003
# File 'lib/google/apis/sheets_v4/classes.rb', line 2001

def total_updated_columns
  @total_updated_columns
end

#total_updated_rowsFixnum

The total number of rows where at least one cell in the row was updated. Corresponds to the JSON property totalUpdatedRows

Returns:



2006
2007
2008
# File 'lib/google/apis/sheets_v4/classes.rb', line 2006

def total_updated_rows
  @total_updated_rows
end

#total_updated_sheetsFixnum

The total number of sheets where at least one cell in the sheet was updated. Corresponds to the JSON property totalUpdatedSheets

Returns:



2011
2012
2013
# File 'lib/google/apis/sheets_v4/classes.rb', line 2011

def total_updated_sheets
  @total_updated_sheets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2018
2019
2020
2021
2022
2023
2024
2025
# File 'lib/google/apis/sheets_v4/classes.rb', line 2018

def update!(**args)
  @responses = args[:responses] if args.key?(:responses)
  @spreadsheet_id = args[:spreadsheet_id] if args.key?(:spreadsheet_id)
  @total_updated_cells = args[:total_updated_cells] if args.key?(:total_updated_cells)
  @total_updated_columns = args[:total_updated_columns] if args.key?(:total_updated_columns)
  @total_updated_rows = args[:total_updated_rows] if args.key?(:total_updated_rows)
  @total_updated_sheets = args[:total_updated_sheets] if args.key?(:total_updated_sheets)
end