Class: Google::Apis::SheetsV4::BigQueryDataSourceSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The specification of a BigQuery data source that's connected to a sheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BigQueryDataSourceSpec

Returns a new instance of BigQueryDataSourceSpec.



2050
2051
2052
# File 'lib/google/apis/sheets_v4/classes.rb', line 2050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#project_idString

The ID of a BigQuery enabled Google Cloud project with a billing account attached. For any queries executed against the data source, the project is charged. Corresponds to the JSON property projectId

Returns:

  • (String)


2037
2038
2039
# File 'lib/google/apis/sheets_v4/classes.rb', line 2037

def project_id
  @project_id
end

#query_specGoogle::Apis::SheetsV4::BigQueryQuerySpec

Specifies a custom BigQuery query. Corresponds to the JSON property querySpec



2042
2043
2044
# File 'lib/google/apis/sheets_v4/classes.rb', line 2042

def query_spec
  @query_spec
end

#table_specGoogle::Apis::SheetsV4::BigQueryTableSpec

Specifies a BigQuery table definition. Only native tables are allowed. Corresponds to the JSON property tableSpec



2048
2049
2050
# File 'lib/google/apis/sheets_v4/classes.rb', line 2048

def table_spec
  @table_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2055
2056
2057
2058
2059
# File 'lib/google/apis/sheets_v4/classes.rb', line 2055

def update!(**args)
  @project_id = args[:project_id] if args.key?(:project_id)
  @query_spec = args[:query_spec] if args.key?(:query_spec)
  @table_spec = args[:table_spec] if args.key?(:table_spec)
end