Class: Google::Apis::SheetsV4::BooleanCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A condition that can evaluate to true or false. BooleanConditions are used by conditional formatting, data validation, and the criteria in filters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BooleanCondition

Returns a new instance of BooleanCondition.



2131
2132
2133
# File 'lib/google/apis/sheets_v4/classes.rb', line 2131

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#typeString

The type of condition. Corresponds to the JSON property type

Returns:

  • (String)


2122
2123
2124
# File 'lib/google/apis/sheets_v4/classes.rb', line 2122

def type
  @type
end

#valuesArray<Google::Apis::SheetsV4::ConditionValue>

The values of the condition. The number of supported values depends on the condition type. Some support zero values, others one or two values, and ConditionType.ONE_OF_LIST supports an arbitrary number of values. Corresponds to the JSON property values



2129
2130
2131
# File 'lib/google/apis/sheets_v4/classes.rb', line 2129

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2136
2137
2138
2139
# File 'lib/google/apis/sheets_v4/classes.rb', line 2136

def update!(**args)
  @type = args[:type] if args.key?(:type)
  @values = args[:values] if args.key?(:values)
end