Class: Google::Apis::SheetsV4::CancelDataSourceRefreshRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Cancels one or multiple refreshes of data source objects in the spreadsheet by the specified references. The request requires an additional bigquery. readonly OAuth scope if you are cancelling a refresh on a BigQuery data source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CancelDataSourceRefreshRequest

Returns a new instance of CancelDataSourceRefreshRequest.



2445
2446
2447
# File 'lib/google/apis/sheets_v4/classes.rb', line 2445

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_idString

Reference to a DataSource. If specified, cancels all associated data source object refreshes for this data source. Corresponds to the JSON property dataSourceId

Returns:

  • (String)


2431
2432
2433
# File 'lib/google/apis/sheets_v4/classes.rb', line 2431

def data_source_id
  @data_source_id
end

#is_allBoolean Also known as: is_all?

Cancels all existing data source object refreshes for all data sources in the spreadsheet. Corresponds to the JSON property isAll

Returns:

  • (Boolean)


2437
2438
2439
# File 'lib/google/apis/sheets_v4/classes.rb', line 2437

def is_all
  @is_all
end

#referencesGoogle::Apis::SheetsV4::DataSourceObjectReferences

A list of references to data source objects. Corresponds to the JSON property references



2443
2444
2445
# File 'lib/google/apis/sheets_v4/classes.rb', line 2443

def references
  @references
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2450
2451
2452
2453
2454
# File 'lib/google/apis/sheets_v4/classes.rb', line 2450

def update!(**args)
  @data_source_id = args[:data_source_id] if args.key?(:data_source_id)
  @is_all = args[:is_all] if args.key?(:is_all)
  @references = args[:references] if args.key?(:references)
end