Class: Google::Apis::SheetsV4::ChartAxisViewWindowOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The options that define a "view window" for a chart (such as the visible values in an axis).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChartAxisViewWindowOptions

Returns a new instance of ChartAxisViewWindowOptions.



2876
2877
2878
# File 'lib/google/apis/sheets_v4/classes.rb', line 2876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#view_window_maxFloat

The maximum numeric value to be shown in this view window. If unset, will automatically determine a maximum value that looks good for the data. Corresponds to the JSON property viewWindowMax

Returns:

  • (Float)


2863
2864
2865
# File 'lib/google/apis/sheets_v4/classes.rb', line 2863

def view_window_max
  @view_window_max
end

#view_window_minFloat

The minimum numeric value to be shown in this view window. If unset, will automatically determine a minimum value that looks good for the data. Corresponds to the JSON property viewWindowMin

Returns:

  • (Float)


2869
2870
2871
# File 'lib/google/apis/sheets_v4/classes.rb', line 2869

def view_window_min
  @view_window_min
end

#view_window_modeString

The view window's mode. Corresponds to the JSON property viewWindowMode

Returns:

  • (String)


2874
2875
2876
# File 'lib/google/apis/sheets_v4/classes.rb', line 2874

def view_window_mode
  @view_window_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2881
2882
2883
2884
2885
# File 'lib/google/apis/sheets_v4/classes.rb', line 2881

def update!(**args)
  @view_window_max = args[:view_window_max] if args.key?(:view_window_max)
  @view_window_min = args[:view_window_min] if args.key?(:view_window_min)
  @view_window_mode = args[:view_window_mode] if args.key?(:view_window_mode)
end