Class: Google::Apis::SheetsV4::ChartCustomNumberFormatOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Custom number formatting options for chart attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChartCustomNumberFormatOptions

Returns a new instance of ChartCustomNumberFormatOptions.



2902
2903
2904
# File 'lib/google/apis/sheets_v4/classes.rb', line 2902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#prefixString

Custom prefix to be prepended to the chart attribute. This field is optional. Corresponds to the JSON property prefix

Returns:



2895
2896
2897
# File 'lib/google/apis/sheets_v4/classes.rb', line 2895

def prefix
  @prefix
end

#suffixString

Custom suffix to be appended to the chart attribute. This field is optional. Corresponds to the JSON property suffix

Returns:



2900
2901
2902
# File 'lib/google/apis/sheets_v4/classes.rb', line 2900

def suffix
  @suffix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2907
2908
2909
2910
# File 'lib/google/apis/sheets_v4/classes.rb', line 2907

def update!(**args)
  @prefix = args[:prefix] if args.key?(:prefix)
  @suffix = args[:suffix] if args.key?(:suffix)
end