Class: Google::Apis::SheetsV4::Chip

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The Smart Chip.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Chip

Returns a new instance of Chip.



3315
3316
3317
# File 'lib/google/apis/sheets_v4/classes.rb', line 3315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#person_propertiesGoogle::Apis::SheetsV4::PersonProperties

Properties specific to a linked person. Corresponds to the JSON property personProperties



3304
3305
3306
# File 'lib/google/apis/sheets_v4/classes.rb', line 3304

def person_properties
  @person_properties
end

Properties of a link to a Google resource (such as a file in Drive, a YouTube video, a Maps address, or a Calendar event). Only Drive files can be written as chips. All other rich link types are read only. URIs cannot exceed 2000 bytes when writing. NOTE: Writing Drive file chips requires at least one of the drive.file, drive.readonly, or drive OAuth scopes. Corresponds to the JSON property richLinkProperties



3313
3314
3315
# File 'lib/google/apis/sheets_v4/classes.rb', line 3313

def rich_link_properties
  @rich_link_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3320
3321
3322
3323
# File 'lib/google/apis/sheets_v4/classes.rb', line 3320

def update!(**args)
  @person_properties = args[:person_properties] if args.key?(:person_properties)
  @rich_link_properties = args[:rich_link_properties] if args.key?(:rich_link_properties)
end