Class: Google::Apis::SheetsV4::ChipRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The run of a chip. The chip continues until the start index of the next run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChipRun

Returns a new instance of ChipRun.



3341
3342
3343
# File 'lib/google/apis/sheets_v4/classes.rb', line 3341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chipGoogle::Apis::SheetsV4::Chip

The Smart Chip. Corresponds to the JSON property chip



3333
3334
3335
# File 'lib/google/apis/sheets_v4/classes.rb', line 3333

def chip
  @chip
end

#start_indexFixnum

Required. The zero-based character index where this run starts, in UTF-16 code units. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


3339
3340
3341
# File 'lib/google/apis/sheets_v4/classes.rb', line 3339

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3346
3347
3348
3349
# File 'lib/google/apis/sheets_v4/classes.rb', line 3346

def update!(**args)
  @chip = args[:chip] if args.key?(:chip)
  @start_index = args[:start_index] if args.key?(:start_index)
end