Class: Google::Apis::SheetsV4::ClearValuesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The response when clearing a range of values in a spreadsheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClearValuesResponse

Returns a new instance of ClearValuesResponse.



3400
3401
3402
# File 'lib/google/apis/sheets_v4/classes.rb', line 3400

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cleared_rangeString

The range (in A1 notation) that was cleared. (If the request was for an unbounded range or a range larger than the bounds of the sheet, this will be the actual range that was cleared, bounded to the sheet's limits.) Corresponds to the JSON property clearedRange

Returns:

  • (String)


3393
3394
3395
# File 'lib/google/apis/sheets_v4/classes.rb', line 3393

def cleared_range
  @cleared_range
end

#spreadsheet_idString

The spreadsheet the updates were applied to. Corresponds to the JSON property spreadsheetId

Returns:

  • (String)


3398
3399
3400
# File 'lib/google/apis/sheets_v4/classes.rb', line 3398

def spreadsheet_id
  @spreadsheet_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3405
3406
3407
3408
# File 'lib/google/apis/sheets_v4/classes.rb', line 3405

def update!(**args)
  @cleared_range = args[:cleared_range] if args.key?(:cleared_range)
  @spreadsheet_id = args[:spreadsheet_id] if args.key?(:spreadsheet_id)
end