Class: Google::Apis::SheetsV4::CutPasteRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Moves data from the source to the destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CutPasteRequest

Returns a new instance of CutPasteRequest.



3799
3800
3801
# File 'lib/google/apis/sheets_v4/classes.rb', line 3799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationGoogle::Apis::SheetsV4::GridCoordinate

A coordinate in a sheet. All indexes are zero-based. Corresponds to the JSON property destination



3774
3775
3776
# File 'lib/google/apis/sheets_v4/classes.rb', line 3774

def destination
  @destination
end

#paste_typeString

What kind of data to paste. All the source data will be cut, regardless of what is pasted. Corresponds to the JSON property pasteType

Returns:

  • (String)


3780
3781
3782
# File 'lib/google/apis/sheets_v4/classes.rb', line 3780

def paste_type
  @paste_type
end

#sourceGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, i.e. the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id: 123456, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id: 123456 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property source



3797
3798
3799
# File 'lib/google/apis/sheets_v4/classes.rb', line 3797

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3804
3805
3806
3807
3808
# File 'lib/google/apis/sheets_v4/classes.rb', line 3804

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @paste_type = args[:paste_type] if args.key?(:paste_type)
  @source = args[:source] if args.key?(:source)
end