Class: Google::Apis::SheetsV4::DataFilterValueRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A range of values whose location is specified by a DataFilter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataFilterValueRange

Returns a new instance of DataFilterValueRange.



3933
3934
3935
# File 'lib/google/apis/sheets_v4/classes.rb', line 3933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_filterGoogle::Apis::SheetsV4::DataFilter

Filter that describes what data should be selected or returned from a request. For more information, see Read, write, and search metadata. Corresponds to the JSON property dataFilter



3918
3919
3920
# File 'lib/google/apis/sheets_v4/classes.rb', line 3918

def data_filter
  @data_filter
end

#major_dimensionString

The major dimension of the values. Corresponds to the JSON property majorDimension

Returns:

  • (String)


3923
3924
3925
# File 'lib/google/apis/sheets_v4/classes.rb', line 3923

def major_dimension
  @major_dimension
end

#valuesArray<Array<Object>>

The data to be written. If the provided values exceed any of the ranges matched by the data filter then the request fails. If the provided values are less than the matched ranges only the specified values are written, existing values in the matched ranges remain unaffected. Corresponds to the JSON property values

Returns:

  • (Array<Array<Object>>)


3931
3932
3933
# File 'lib/google/apis/sheets_v4/classes.rb', line 3931

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3938
3939
3940
3941
3942
# File 'lib/google/apis/sheets_v4/classes.rb', line 3938

def update!(**args)
  @data_filter = args[:data_filter] if args.key?(:data_filter)
  @major_dimension = args[:major_dimension] if args.key?(:major_dimension)
  @values = args[:values] if args.key?(:values)
end