Class: Google::Apis::SheetsV4::DataSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Information about an external data source in the spreadsheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSource

Returns a new instance of DataSource.



4015
4016
4017
# File 'lib/google/apis/sheets_v4/classes.rb', line 4015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#calculated_columnsArray<Google::Apis::SheetsV4::DataSourceColumn>

All calculated columns in the data source. Corresponds to the JSON property calculatedColumns



3993
3994
3995
# File 'lib/google/apis/sheets_v4/classes.rb', line 3993

def calculated_columns
  @calculated_columns
end

#data_source_idString

The spreadsheet-scoped unique ID that identifies the data source. Example: 1080547365. Corresponds to the JSON property dataSourceId

Returns:

  • (String)


3999
4000
4001
# File 'lib/google/apis/sheets_v4/classes.rb', line 3999

def data_source_id
  @data_source_id
end

#sheet_idFixnum

The ID of the Sheet connected with the data source. The field cannot be changed once set. When creating a data source, an associated DATA_SOURCE sheet is also created, if the field is not specified, the ID of the created sheet will be randomly generated. Corresponds to the JSON property sheetId

Returns:

  • (Fixnum)


4007
4008
4009
# File 'lib/google/apis/sheets_v4/classes.rb', line 4007

def sheet_id
  @sheet_id
end

#specGoogle::Apis::SheetsV4::DataSourceSpec

This specifies the details of the data source. For example, for BigQuery, this specifies information about the BigQuery source. Corresponds to the JSON property spec



4013
4014
4015
# File 'lib/google/apis/sheets_v4/classes.rb', line 4013

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4020
4021
4022
4023
4024
4025
# File 'lib/google/apis/sheets_v4/classes.rb', line 4020

def update!(**args)
  @calculated_columns = args[:calculated_columns] if args.key?(:calculated_columns)
  @data_source_id = args[:data_source_id] if args.key?(:data_source_id)
  @sheet_id = args[:sheet_id] if args.key?(:sheet_id)
  @spec = args[:spec] if args.key?(:spec)
end