Class: Google::Apis::SheetsV4::DataSourceRefreshSchedule
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::DataSourceRefreshSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Schedule for refreshing the data source. Data sources in the spreadsheet are refreshed within a time interval. You can specify the start time by clicking the Scheduled Refresh button in the Sheets editor, but the interval is fixed at 4 hours. For example, if you specify a start time of 8 AM , the refresh will take place between 8 AM and 12 PM every day.
Instance Attribute Summary collapse
-
#daily_schedule ⇒ Google::Apis::SheetsV4::DataSourceRefreshDailySchedule
A schedule for data to refresh every day in a given time interval.
-
#enabled ⇒ Boolean
(also: #enabled?)
True if the refresh schedule is enabled, or false otherwise.
-
#monthly_schedule ⇒ Google::Apis::SheetsV4::DataSourceRefreshMonthlySchedule
A monthly schedule for data to refresh on specific days in the month in a given time interval.
-
#next_run ⇒ Google::Apis::SheetsV4::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#refresh_scope ⇒ String
The scope of the refresh.
-
#weekly_schedule ⇒ Google::Apis::SheetsV4::DataSourceRefreshWeeklySchedule
A weekly schedule for data to refresh on specific days in a given time interval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSourceRefreshSchedule
constructor
A new instance of DataSourceRefreshSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSourceRefreshSchedule
Returns a new instance of DataSourceRefreshSchedule.
4340 4341 4342 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4340 def initialize(**args) update!(**args) end |
Instance Attribute Details
#daily_schedule ⇒ Google::Apis::SheetsV4::DataSourceRefreshDailySchedule
A schedule for data to refresh every day in a given time interval.
Corresponds to the JSON property dailySchedule
4307 4308 4309 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4307 def daily_schedule @daily_schedule end |
#enabled ⇒ Boolean Also known as: enabled?
True if the refresh schedule is enabled, or false otherwise.
Corresponds to the JSON property enabled
4312 4313 4314 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4312 def enabled @enabled end |
#monthly_schedule ⇒ Google::Apis::SheetsV4::DataSourceRefreshMonthlySchedule
A monthly schedule for data to refresh on specific days in the month in a
given time interval.
Corresponds to the JSON property monthlySchedule
4319 4320 4321 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4319 def monthly_schedule @monthly_schedule end |
#next_run ⇒ Google::Apis::SheetsV4::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property nextRun
4327 4328 4329 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4327 def next_run @next_run end |
#refresh_scope ⇒ String
The scope of the refresh. Must be ALL_DATA_SOURCES.
Corresponds to the JSON property refreshScope
4332 4333 4334 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4332 def refresh_scope @refresh_scope end |
#weekly_schedule ⇒ Google::Apis::SheetsV4::DataSourceRefreshWeeklySchedule
A weekly schedule for data to refresh on specific days in a given time
interval.
Corresponds to the JSON property weeklySchedule
4338 4339 4340 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4338 def weekly_schedule @weekly_schedule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4345 4346 4347 4348 4349 4350 4351 4352 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4345 def update!(**args) @daily_schedule = args[:daily_schedule] if args.key?(:daily_schedule) @enabled = args[:enabled] if args.key?(:enabled) @monthly_schedule = args[:monthly_schedule] if args.key?(:monthly_schedule) @next_run = args[:next_run] if args.key?(:next_run) @refresh_scope = args[:refresh_scope] if args.key?(:refresh_scope) @weekly_schedule = args[:weekly_schedule] if args.key?(:weekly_schedule) end |