Class: Google::Apis::SheetsV4::DataSourceRefreshWeeklySchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A weekly schedule for data to refresh on specific days in a given time interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSourceRefreshWeeklySchedule

Returns a new instance of DataSourceRefreshWeeklySchedule.



4372
4373
4374
# File 'lib/google/apis/sheets_v4/classes.rb', line 4372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#days_of_weekArray<String>

Days of the week to refresh. At least one day must be specified. Corresponds to the JSON property daysOfWeek

Returns:

  • (Array<String>)


4363
4364
4365
# File 'lib/google/apis/sheets_v4/classes.rb', line 4363

def days_of_week
  @days_of_week
end

#start_timeGoogle::Apis::SheetsV4::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



4370
4371
4372
# File 'lib/google/apis/sheets_v4/classes.rb', line 4370

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4377
4378
4379
4380
# File 'lib/google/apis/sheets_v4/classes.rb', line 4377

def update!(**args)
  @days_of_week = args[:days_of_week] if args.key?(:days_of_week)
  @start_time = args[:start_time] if args.key?(:start_time)
end