Class: Google::Apis::SheetsV4::DataSourceTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A data source table, which allows the user to import a static table of data from the DataSource into Sheets. This is also known as "Extract" in the Sheets editor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSourceTable

Returns a new instance of DataSourceTable.



4531
4532
4533
# File 'lib/google/apis/sheets_v4/classes.rb', line 4531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_selection_typeString

The type to select columns for the data source table. Defaults to SELECTED. Corresponds to the JSON property columnSelectionType

Returns:

  • (String)


4488
4489
4490
# File 'lib/google/apis/sheets_v4/classes.rb', line 4488

def column_selection_type
  @column_selection_type
end

#columnsArray<Google::Apis::SheetsV4::DataSourceColumnReference>

Columns selected for the data source table. The column_selection_type must be SELECTED. Corresponds to the JSON property columns



4494
4495
4496
# File 'lib/google/apis/sheets_v4/classes.rb', line 4494

def columns
  @columns
end

#data_execution_statusGoogle::Apis::SheetsV4::DataExecutionStatus

The data execution status. A data execution is created to sync a data source object with the latest data from a DataSource. It is usually scheduled to run at background, you can check its state to tell if an execution completes There are several scenarios where a data execution is triggered to run: * Adding a data source creates an associated data source sheet as well as a data execution to sync the data from the data source to the sheet. * Updating a data source creates a data execution to refresh the associated data source sheet similarly. * You can send refresh request to explicitly refresh one or multiple data source objects. Corresponds to the JSON property dataExecutionStatus



4507
4508
4509
# File 'lib/google/apis/sheets_v4/classes.rb', line 4507

def data_execution_status
  @data_execution_status
end

#data_source_idString

The ID of the data source the data source table is associated with. Corresponds to the JSON property dataSourceId

Returns:

  • (String)


4512
4513
4514
# File 'lib/google/apis/sheets_v4/classes.rb', line 4512

def data_source_id
  @data_source_id
end

#filter_specsArray<Google::Apis::SheetsV4::FilterSpec>

Filter specifications in the data source table. Corresponds to the JSON property filterSpecs



4517
4518
4519
# File 'lib/google/apis/sheets_v4/classes.rb', line 4517

def filter_specs
  @filter_specs
end

#row_limitFixnum

The limit of rows to return. If not set, a default limit is applied. Please refer to the Sheets editor for the default and max limit. Corresponds to the JSON property rowLimit

Returns:

  • (Fixnum)


4523
4524
4525
# File 'lib/google/apis/sheets_v4/classes.rb', line 4523

def row_limit
  @row_limit
end

#sort_specsArray<Google::Apis::SheetsV4::SortSpec>

Sort specifications in the data source table. The result of the data source table is sorted based on the sort specifications in order. Corresponds to the JSON property sortSpecs



4529
4530
4531
# File 'lib/google/apis/sheets_v4/classes.rb', line 4529

def sort_specs
  @sort_specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4536
4537
4538
4539
4540
4541
4542
4543
4544
# File 'lib/google/apis/sheets_v4/classes.rb', line 4536

def update!(**args)
  @column_selection_type = args[:column_selection_type] if args.key?(:column_selection_type)
  @columns = args[:columns] if args.key?(:columns)
  @data_execution_status = args[:data_execution_status] if args.key?(:data_execution_status)
  @data_source_id = args[:data_source_id] if args.key?(:data_source_id)
  @filter_specs = args[:filter_specs] if args.key?(:filter_specs)
  @row_limit = args[:row_limit] if args.key?(:row_limit)
  @sort_specs = args[:sort_specs] if args.key?(:sort_specs)
end