Class: Google::Apis::SheetsV4::DeveloperMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Developer metadata associated with a location or object in a spreadsheet. For more information, see Read, write, and search metadata. Developer metadata may be used to associate arbitrary data with various parts of a spreadsheet and it will remain associated at those locations as they move around and the spreadsheet is edited. For example, if developer metadata is associated with row 5 and another row is then subsequently inserted above row 5, that original metadata is still associated with the row it was first associated with (what is now row 6). If the associated object is deleted then its metadata is deleted too.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeveloperMetadata

Returns a new instance of DeveloperMetadata.



5064
5065
5066
# File 'lib/google/apis/sheets_v4/classes.rb', line 5064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationGoogle::Apis::SheetsV4::DeveloperMetadataLocation

A location where metadata may be associated in a spreadsheet. Corresponds to the JSON property location



5038
5039
5040
# File 'lib/google/apis/sheets_v4/classes.rb', line 5038

def location
  @location
end

#metadata_idFixnum

The spreadsheet-scoped unique ID that identifies the metadata. IDs may be specified when metadata is created, otherwise one will be randomly generated and assigned. Must be positive. Corresponds to the JSON property metadataId

Returns:

  • (Fixnum)


5045
5046
5047
# File 'lib/google/apis/sheets_v4/classes.rb', line 5045

def 
  
end

#metadata_keyString

The metadata key. There may be multiple metadata in a spreadsheet with the same key. Developer metadata must always have a key specified. Corresponds to the JSON property metadataKey

Returns:

  • (String)


5051
5052
5053
# File 'lib/google/apis/sheets_v4/classes.rb', line 5051

def 
  
end

#metadata_valueString

Data associated with the metadata's key. Corresponds to the JSON property metadataValue

Returns:

  • (String)


5056
5057
5058
# File 'lib/google/apis/sheets_v4/classes.rb', line 5056

def 
  
end

#visibilityString

The metadata visibility. Developer metadata must always have visibility specified. Corresponds to the JSON property visibility

Returns:

  • (String)


5062
5063
5064
# File 'lib/google/apis/sheets_v4/classes.rb', line 5062

def visibility
  @visibility
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5069
5070
5071
5072
5073
5074
5075
# File 'lib/google/apis/sheets_v4/classes.rb', line 5069

def update!(**args)
  @location = args[:location] if args.key?(:location)
   = args[:metadata_id] if args.key?(:metadata_id)
   = args[:metadata_key] if args.key?(:metadata_key)
   = args[:metadata_value] if args.key?(:metadata_value)
  @visibility = args[:visibility] if args.key?(:visibility)
end