Class: Google::Apis::SheetsV4::DeveloperMetadataLookup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Selects DeveloperMetadata that matches all of the specified fields. For example, if only a metadata ID is specified this considers the DeveloperMetadata with that particular unique ID. If a metadata key is specified, this considers all developer metadata with that key. If a key, visibility, and location type are all specified, this considers all developer metadata with that key and visibility that are associated with a location of that type. In general, this selects all DeveloperMetadata that match the intersection of all the specified fields; any field or combination of fields may be specified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeveloperMetadataLookup

Returns a new instance of DeveloperMetadataLookup.



5184
5185
5186
# File 'lib/google/apis/sheets_v4/classes.rb', line 5184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#location_matching_strategyString

Determines how this lookup matches the location. If this field is specified as EXACT, only developer metadata associated on the exact location specified is matched. If this field is specified to INTERSECTING, developer metadata associated on intersecting locations is also matched. If left unspecified, this field assumes a default value of INTERSECTING. If this field is specified, a metadataLocation must also be specified. Corresponds to the JSON property locationMatchingStrategy

Returns:

  • (String)


5138
5139
5140
# File 'lib/google/apis/sheets_v4/classes.rb', line 5138

def location_matching_strategy
  @location_matching_strategy
end

#location_typeString

Limits the selected developer metadata to those entries which are associated with locations of the specified type. For example, when this field is specified as ROW this lookup only considers developer metadata associated on rows. If the field is left unspecified, all location types are considered. This field cannot be specified as SPREADSHEET when the locationMatchingStrategy is specified as INTERSECTING or when the metadataLocation is specified as a non-spreadsheet location. Spreadsheet metadata cannot intersect any other developer metadata location. This field also must be left unspecified when the locationMatchingStrategy is specified as EXACT. Corresponds to the JSON property locationType

Returns:

  • (String)


5152
5153
5154
# File 'lib/google/apis/sheets_v4/classes.rb', line 5152

def location_type
  @location_type
end

#metadata_idFixnum

Limits the selected developer metadata to that which has a matching DeveloperMetadata.metadata_id. Corresponds to the JSON property metadataId

Returns:

  • (Fixnum)


5158
5159
5160
# File 'lib/google/apis/sheets_v4/classes.rb', line 5158

def 
  
end

#metadata_keyString

Limits the selected developer metadata to that which has a matching DeveloperMetadata.metadata_key. Corresponds to the JSON property metadataKey

Returns:

  • (String)


5164
5165
5166
# File 'lib/google/apis/sheets_v4/classes.rb', line 5164

def 
  
end

#metadata_locationGoogle::Apis::SheetsV4::DeveloperMetadataLocation

A location where metadata may be associated in a spreadsheet. Corresponds to the JSON property metadataLocation



5169
5170
5171
# File 'lib/google/apis/sheets_v4/classes.rb', line 5169

def 
  
end

#metadata_valueString

Limits the selected developer metadata to that which has a matching DeveloperMetadata.metadata_value. Corresponds to the JSON property metadataValue

Returns:

  • (String)


5175
5176
5177
# File 'lib/google/apis/sheets_v4/classes.rb', line 5175

def 
  
end

#visibilityString

Limits the selected developer metadata to that which has a matching DeveloperMetadata.visibility. If left unspecified, all developer metadata visible to the requesting project is considered. Corresponds to the JSON property visibility

Returns:

  • (String)


5182
5183
5184
# File 'lib/google/apis/sheets_v4/classes.rb', line 5182

def visibility
  @visibility
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5189
5190
5191
5192
5193
5194
5195
5196
5197
# File 'lib/google/apis/sheets_v4/classes.rb', line 5189

def update!(**args)
  @location_matching_strategy = args[:location_matching_strategy] if args.key?(:location_matching_strategy)
  @location_type = args[:location_type] if args.key?(:location_type)
   = args[:metadata_id] if args.key?(:metadata_id)
   = args[:metadata_key] if args.key?(:metadata_key)
   = args[:metadata_location] if args.key?(:metadata_location)
   = args[:metadata_value] if args.key?(:metadata_value)
  @visibility = args[:visibility] if args.key?(:visibility)
end