Class: Google::Apis::SheetsV4::DimensionGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A group over an interval of rows or columns on a sheet, which can contain or be contained within other groups. A group can be collapsed or expanded as a unit on the sheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DimensionGroup

Returns a new instance of DimensionGroup.



5230
5231
5232
# File 'lib/google/apis/sheets_v4/classes.rb', line 5230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collapsedBoolean Also known as: collapsed?

This field is true if this group is collapsed. A collapsed group remains collapsed if an overlapping group at a shallower depth is expanded. A true value does not imply that all dimensions within the group are hidden, since a dimension's visibility can change independently from this group property. However, when this property is updated, all dimensions within it are set to hidden if this field is true, or set to visible if this field is false. Corresponds to the JSON property collapsed

Returns:

  • (Boolean)


5214
5215
5216
# File 'lib/google/apis/sheets_v4/classes.rb', line 5214

def collapsed
  @collapsed
end

#depthFixnum

The depth of the group, representing how many groups have a range that wholly contains the range of this group. Corresponds to the JSON property depth

Returns:

  • (Fixnum)


5221
5222
5223
# File 'lib/google/apis/sheets_v4/classes.rb', line 5221

def depth
  @depth
end

#rangeGoogle::Apis::SheetsV4::DimensionRange

A range along a single dimension on a sheet. All indexes are zero-based. Indexes are half open: the start index is inclusive and the end index is exclusive. Missing indexes indicate the range is unbounded on that side. Corresponds to the JSON property range



5228
5229
5230
# File 'lib/google/apis/sheets_v4/classes.rb', line 5228

def range
  @range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5235
5236
5237
5238
5239
# File 'lib/google/apis/sheets_v4/classes.rb', line 5235

def update!(**args)
  @collapsed = args[:collapsed] if args.key?(:collapsed)
  @depth = args[:depth] if args.key?(:depth)
  @range = args[:range] if args.key?(:range)
end