Class: Google::Apis::SheetsV4::DimensionRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A range along a single dimension on a sheet. All indexes are zero-based. Indexes are half open: the start index is inclusive and the end index is exclusive. Missing indexes indicate the range is unbounded on that side.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DimensionRange

Returns a new instance of DimensionRange.



5313
5314
5315
# File 'lib/google/apis/sheets_v4/classes.rb', line 5313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionString

The dimension of the span. Corresponds to the JSON property dimension

Returns:

  • (String)


5296
5297
5298
# File 'lib/google/apis/sheets_v4/classes.rb', line 5296

def dimension
  @dimension
end

#end_indexFixnum

The end (exclusive) of the span, or not set if unbounded. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


5301
5302
5303
# File 'lib/google/apis/sheets_v4/classes.rb', line 5301

def end_index
  @end_index
end

#sheet_idFixnum

The sheet this span is on. Corresponds to the JSON property sheetId

Returns:

  • (Fixnum)


5306
5307
5308
# File 'lib/google/apis/sheets_v4/classes.rb', line 5306

def sheet_id
  @sheet_id
end

#start_indexFixnum

The start (inclusive) of the span, or not set if unbounded. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


5311
5312
5313
# File 'lib/google/apis/sheets_v4/classes.rb', line 5311

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5318
5319
5320
5321
5322
5323
# File 'lib/google/apis/sheets_v4/classes.rb', line 5318

def update!(**args)
  @dimension = args[:dimension] if args.key?(:dimension)
  @end_index = args[:end_index] if args.key?(:end_index)
  @sheet_id = args[:sheet_id] if args.key?(:sheet_id)
  @start_index = args[:start_index] if args.key?(:start_index)
end