Class: Google::Apis::SheetsV4::DuplicateSheetRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::DuplicateSheetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Duplicates the contents of a sheet.
Instance Attribute Summary collapse
-
#insert_sheet_index ⇒ Fixnum
The zero-based index where the new sheet should be inserted.
-
#new_sheet_id ⇒ Fixnum
If set, the ID of the new sheet.
-
#new_sheet_name ⇒ String
The name of the new sheet.
-
#source_sheet_id ⇒ Fixnum
The sheet to duplicate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DuplicateSheetRequest
constructor
A new instance of DuplicateSheetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DuplicateSheetRequest
Returns a new instance of DuplicateSheetRequest.
5394 5395 5396 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insert_sheet_index ⇒ Fixnum
The zero-based index where the new sheet should be inserted. The index of all
sheets after this are incremented.
Corresponds to the JSON property insertSheetIndex
5373 5374 5375 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5373 def insert_sheet_index @insert_sheet_index end |
#new_sheet_id ⇒ Fixnum
If set, the ID of the new sheet. If not set, an ID is chosen. If set, the ID
must not conflict with any existing sheet ID. If set, it must be non-negative.
Corresponds to the JSON property newSheetId
5379 5380 5381 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5379 def new_sheet_id @new_sheet_id end |
#new_sheet_name ⇒ String
The name of the new sheet. If empty, a new name is chosen for you.
Corresponds to the JSON property newSheetName
5384 5385 5386 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5384 def new_sheet_name @new_sheet_name end |
#source_sheet_id ⇒ Fixnum
The sheet to duplicate. If the source sheet is of DATA_SOURCE type, its
backing DataSource is also duplicated and associated with the new copy of the
sheet. No data execution is triggered, the grid data of this sheet is also
copied over but only available after the batch request completes.
Corresponds to the JSON property sourceSheetId
5392 5393 5394 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5392 def source_sheet_id @source_sheet_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5399 5400 5401 5402 5403 5404 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5399 def update!(**args) @insert_sheet_index = args[:insert_sheet_index] if args.key?(:insert_sheet_index) @new_sheet_id = args[:new_sheet_id] if args.key?(:new_sheet_id) @new_sheet_name = args[:new_sheet_name] if args.key?(:new_sheet_name) @source_sheet_id = args[:source_sheet_id] if args.key?(:source_sheet_id) end |