Class: Google::Apis::SheetsV4::EmbeddedObjectPosition
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::EmbeddedObjectPosition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The position of an embedded object such as a chart.
Instance Attribute Summary collapse
-
#new_sheet ⇒ Boolean
(also: #new_sheet?)
If true, the embedded object is put on a new sheet whose ID is chosen for you.
-
#overlay_position ⇒ Google::Apis::SheetsV4::OverlayPosition
The location an object is overlaid on top of a grid.
-
#sheet_id ⇒ Fixnum
The sheet this is on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmbeddedObjectPosition
constructor
A new instance of EmbeddedObjectPosition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmbeddedObjectPosition
Returns a new instance of EmbeddedObjectPosition.
5587 5588 5589 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5587 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_sheet ⇒ Boolean Also known as: new_sheet?
If true, the embedded object is put on a new sheet whose ID is chosen for you.
Used only when writing.
Corresponds to the JSON property newSheet
5573 5574 5575 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5573 def new_sheet @new_sheet end |
#overlay_position ⇒ Google::Apis::SheetsV4::OverlayPosition
The location an object is overlaid on top of a grid.
Corresponds to the JSON property overlayPosition
5579 5580 5581 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5579 def end |
#sheet_id ⇒ Fixnum
The sheet this is on. Set only if the embedded object is on its own sheet.
Must be non-negative.
Corresponds to the JSON property sheetId
5585 5586 5587 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5585 def sheet_id @sheet_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5592 5593 5594 5595 5596 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5592 def update!(**args) @new_sheet = args[:new_sheet] if args.key?(:new_sheet) = args[:overlay_position] if args.key?(:overlay_position) @sheet_id = args[:sheet_id] if args.key?(:sheet_id) end |