Class: Google::Apis::SheetsV4::FindReplaceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Finds and replaces data in cells over a range, sheet, or all sheets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FindReplaceRequest

Returns a new instance of FindReplaceRequest.



5994
5995
5996
# File 'lib/google/apis/sheets_v4/classes.rb', line 5994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_sheetsBoolean Also known as: all_sheets?

True to find/replace over all sheets. Corresponds to the JSON property allSheets

Returns:

  • (Boolean)


5928
5929
5930
# File 'lib/google/apis/sheets_v4/classes.rb', line 5928

def all_sheets
  @all_sheets
end

#findString

The value to search. Corresponds to the JSON property find

Returns:

  • (String)


5934
5935
5936
# File 'lib/google/apis/sheets_v4/classes.rb', line 5934

def find
  @find
end

#include_formulasBoolean Also known as: include_formulas?

True if the search should include cells with formulas. False to skip cells with formulas. Corresponds to the JSON property includeFormulas

Returns:

  • (Boolean)


5940
5941
5942
# File 'lib/google/apis/sheets_v4/classes.rb', line 5940

def include_formulas
  @include_formulas
end

#match_caseBoolean Also known as: match_case?

True if the search is case sensitive. Corresponds to the JSON property matchCase

Returns:

  • (Boolean)


5946
5947
5948
# File 'lib/google/apis/sheets_v4/classes.rb', line 5946

def match_case
  @match_case
end

#match_entire_cellBoolean Also known as: match_entire_cell?

True if the find value should match the entire cell. Corresponds to the JSON property matchEntireCell

Returns:

  • (Boolean)


5952
5953
5954
# File 'lib/google/apis/sheets_v4/classes.rb', line 5952

def match_entire_cell
  @match_entire_cell
end

#rangeGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, i.e. the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id: 123456, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id: 123456 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property range



5970
5971
5972
# File 'lib/google/apis/sheets_v4/classes.rb', line 5970

def range
  @range
end

#replacementString

The value to use as the replacement. Corresponds to the JSON property replacement

Returns:

  • (String)


5975
5976
5977
# File 'lib/google/apis/sheets_v4/classes.rb', line 5975

def replacement
  @replacement
end

#search_by_regexBoolean Also known as: search_by_regex?

True if the find value is a regex. The regular expression and replacement should follow Java regex rules at https://docs.oracle.com/javase/8/docs/api/ java/util/regex/Pattern.html. The replacement string is allowed to refer to capturing groups. For example, if one cell has the contents "Google Sheets" and another has "Google Docs", then searching for "o.* (.*)" with a replacement of "$1 Rocks" would change the contents of the cells to " GSheets Rocks" and "GDocs Rocks" respectively. Corresponds to the JSON property searchByRegex

Returns:

  • (Boolean)


5986
5987
5988
# File 'lib/google/apis/sheets_v4/classes.rb', line 5986

def search_by_regex
  @search_by_regex
end

#sheet_idFixnum

The sheet to find/replace over. Corresponds to the JSON property sheetId

Returns:

  • (Fixnum)


5992
5993
5994
# File 'lib/google/apis/sheets_v4/classes.rb', line 5992

def sheet_id
  @sheet_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
# File 'lib/google/apis/sheets_v4/classes.rb', line 5999

def update!(**args)
  @all_sheets = args[:all_sheets] if args.key?(:all_sheets)
  @find = args[:find] if args.key?(:find)
  @include_formulas = args[:include_formulas] if args.key?(:include_formulas)
  @match_case = args[:match_case] if args.key?(:match_case)
  @match_entire_cell = args[:match_entire_cell] if args.key?(:match_entire_cell)
  @range = args[:range] if args.key?(:range)
  @replacement = args[:replacement] if args.key?(:replacement)
  @search_by_regex = args[:search_by_regex] if args.key?(:search_by_regex)
  @sheet_id = args[:sheet_id] if args.key?(:sheet_id)
end