Class: Google::Apis::SheetsV4::GridData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Data in the grid, as well as metadata about the dimensions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GridData

Returns a new instance of GridData.



6190
6191
6192
# File 'lib/google/apis/sheets_v4/classes.rb', line 6190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_metadataArray<Google::Apis::SheetsV4::DimensionProperties>

Metadata about the requested columns in the grid, starting with the column in start_column. Corresponds to the JSON property columnMetadata



6166
6167
6168
# File 'lib/google/apis/sheets_v4/classes.rb', line 6166

def 
  
end

#row_dataArray<Google::Apis::SheetsV4::RowData>

The data in the grid, one entry per row, starting with the row in startRow. The values in RowData will correspond to columns starting at start_column. Corresponds to the JSON property rowData



6172
6173
6174
# File 'lib/google/apis/sheets_v4/classes.rb', line 6172

def row_data
  @row_data
end

#row_metadataArray<Google::Apis::SheetsV4::DimensionProperties>

Metadata about the requested rows in the grid, starting with the row in start_row. Corresponds to the JSON property rowMetadata



6178
6179
6180
# File 'lib/google/apis/sheets_v4/classes.rb', line 6178

def 
  
end

#start_columnFixnum

The first column this GridData refers to, zero-based. Corresponds to the JSON property startColumn

Returns:

  • (Fixnum)


6183
6184
6185
# File 'lib/google/apis/sheets_v4/classes.rb', line 6183

def start_column
  @start_column
end

#start_rowFixnum

The first row this GridData refers to, zero-based. Corresponds to the JSON property startRow

Returns:

  • (Fixnum)


6188
6189
6190
# File 'lib/google/apis/sheets_v4/classes.rb', line 6188

def start_row
  @start_row
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6195
6196
6197
6198
6199
6200
6201
# File 'lib/google/apis/sheets_v4/classes.rb', line 6195

def update!(**args)
   = args[:column_metadata] if args.key?(:column_metadata)
  @row_data = args[:row_data] if args.key?(:row_data)
   = args[:row_metadata] if args.key?(:row_metadata)
  @start_column = args[:start_column] if args.key?(:start_column)
  @start_row = args[:start_row] if args.key?(:start_row)
end