Class: Google::Apis::SheetsV4::GridProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Properties of a grid.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GridProperties

Returns a new instance of GridProperties.



6246
6247
6248
# File 'lib/google/apis/sheets_v4/classes.rb', line 6246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_countFixnum

The number of columns in the grid. Corresponds to the JSON property columnCount

Returns:

  • (Fixnum)


6211
6212
6213
# File 'lib/google/apis/sheets_v4/classes.rb', line 6211

def column_count
  @column_count
end

#column_group_control_afterBoolean Also known as: column_group_control_after?

True if the column grouping control toggle is shown after the group. Corresponds to the JSON property columnGroupControlAfter

Returns:

  • (Boolean)


6216
6217
6218
# File 'lib/google/apis/sheets_v4/classes.rb', line 6216

def column_group_control_after
  @column_group_control_after
end

#frozen_column_countFixnum

The number of columns that are frozen in the grid. Corresponds to the JSON property frozenColumnCount

Returns:

  • (Fixnum)


6222
6223
6224
# File 'lib/google/apis/sheets_v4/classes.rb', line 6222

def frozen_column_count
  @frozen_column_count
end

#frozen_row_countFixnum

The number of rows that are frozen in the grid. Corresponds to the JSON property frozenRowCount

Returns:

  • (Fixnum)


6227
6228
6229
# File 'lib/google/apis/sheets_v4/classes.rb', line 6227

def frozen_row_count
  @frozen_row_count
end

#hide_gridlinesBoolean Also known as: hide_gridlines?

True if the grid isn't showing gridlines in the UI. Corresponds to the JSON property hideGridlines

Returns:

  • (Boolean)


6232
6233
6234
# File 'lib/google/apis/sheets_v4/classes.rb', line 6232

def hide_gridlines
  @hide_gridlines
end

#row_countFixnum

The number of rows in the grid. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


6238
6239
6240
# File 'lib/google/apis/sheets_v4/classes.rb', line 6238

def row_count
  @row_count
end

#row_group_control_afterBoolean Also known as: row_group_control_after?

True if the row grouping control toggle is shown after the group. Corresponds to the JSON property rowGroupControlAfter

Returns:

  • (Boolean)


6243
6244
6245
# File 'lib/google/apis/sheets_v4/classes.rb', line 6243

def row_group_control_after
  @row_group_control_after
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6251
6252
6253
6254
6255
6256
6257
6258
6259
# File 'lib/google/apis/sheets_v4/classes.rb', line 6251

def update!(**args)
  @column_count = args[:column_count] if args.key?(:column_count)
  @column_group_control_after = args[:column_group_control_after] if args.key?(:column_group_control_after)
  @frozen_column_count = args[:frozen_column_count] if args.key?(:frozen_column_count)
  @frozen_row_count = args[:frozen_row_count] if args.key?(:frozen_row_count)
  @hide_gridlines = args[:hide_gridlines] if args.key?(:hide_gridlines)
  @row_count = args[:row_count] if args.key?(:row_count)
  @row_group_control_after = args[:row_group_control_after] if args.key?(:row_group_control_after)
end