Class: Google::Apis::SheetsV4::HistogramRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Allows you to organize the numeric values in a source data column into buckets of a constant size. All values from HistogramRule.start to HistogramRule.end are placed into groups of size HistogramRule.interval. In addition, all values below HistogramRule.start are placed in one group, and all values above HistogramRule.end are placed in another. Only HistogramRule.interval is required, though if HistogramRule.start and HistogramRule.end are both provided, HistogramRule.start must be less than HistogramRule.end. For example, a pivot table showing average purchase amount by age that has 50+ rows: +----- +-------------------+ | Age | AVERAGE of Amount | +-----+-------------------+ | 16 | $27.13 | | 17 | $5.24 | | 18 | $20.15 | ... +-----+-------------------+ could be turned into a pivot table that looks like the one below by applying a histogram group rule with a HistogramRule.start of 25, an HistogramRule. interval of 20, and an HistogramRule.end of 65. +-------------+---------------- ---+ | Grouped Age | AVERAGE of Amount | +-------------+-------------------+ | < 25 | $19.34 | | 25-45 | $31.43 | | 45-65 | $35.87 | | > 65 | $27.55 | +------ -------+-------------------+ | Grand Total | $29.12 | +-------------+---------- ---------+

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HistogramRule

Returns a new instance of HistogramRule.



6412
6413
6414
# File 'lib/google/apis/sheets_v4/classes.rb', line 6412

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endFloat

The maximum value at which items are placed into buckets of constant size. Values above end are lumped into a single bucket. This field is optional. Corresponds to the JSON property end

Returns:

  • (Float)


6399
6400
6401
# File 'lib/google/apis/sheets_v4/classes.rb', line 6399

def end
  @end
end

#intervalFloat

The size of the buckets that are created. Must be positive. Corresponds to the JSON property interval

Returns:

  • (Float)


6404
6405
6406
# File 'lib/google/apis/sheets_v4/classes.rb', line 6404

def interval
  @interval
end

#startFloat

The minimum value at which items are placed into buckets of constant size. Values below start are lumped into a single bucket. This field is optional. Corresponds to the JSON property start

Returns:

  • (Float)


6410
6411
6412
# File 'lib/google/apis/sheets_v4/classes.rb', line 6410

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6417
6418
6419
6420
6421
# File 'lib/google/apis/sheets_v4/classes.rb', line 6417

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @interval = args[:interval] if args.key?(:interval)
  @start = args[:start] if args.key?(:start)
end