Class: Google::Apis::SheetsV4::InsertRangeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Inserts cells into a range, shifting the existing cells over or down.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertRangeRequest

Returns a new instance of InsertRangeRequest.



6562
6563
6564
# File 'lib/google/apis/sheets_v4/classes.rb', line 6562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rangeGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, i.e. the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id: 123456, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id: 123456 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property range



6554
6555
6556
# File 'lib/google/apis/sheets_v4/classes.rb', line 6554

def range
  @range
end

#shift_dimensionString

The dimension which will be shifted when inserting cells. If ROWS, existing cells will be shifted down. If COLUMNS, existing cells will be shifted right. Corresponds to the JSON property shiftDimension

Returns:

  • (String)


6560
6561
6562
# File 'lib/google/apis/sheets_v4/classes.rb', line 6560

def shift_dimension
  @shift_dimension
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6567
6568
6569
6570
# File 'lib/google/apis/sheets_v4/classes.rb', line 6567

def update!(**args)
  @range = args[:range] if args.key?(:range)
  @shift_dimension = args[:shift_dimension] if args.key?(:shift_dimension)
end