Class: Google::Apis::SheetsV4::InterpolationPoint
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::InterpolationPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A single interpolation point on a gradient conditional format. These pin the gradient color scale according to the color, type and value chosen.
Instance Attribute Summary collapse
-
#color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space.
-
#color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
-
#type ⇒ String
How the value should be interpreted.
-
#value ⇒ String
The value this interpolation point uses.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterpolationPoint
constructor
A new instance of InterpolationPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterpolationPoint
Returns a new instance of InterpolationPoint.
6643 6644 6645 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6643 def initialize(**args) update!(**args) end |
Instance Attribute Details
#color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property color
6625 6626 6627 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6625 def color @color end |
#color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
Corresponds to the JSON property colorStyle
6630 6631 6632 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6630 def color_style @color_style end |
#type ⇒ String
How the value should be interpreted.
Corresponds to the JSON property type
6635 6636 6637 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6635 def type @type end |
#value ⇒ String
The value this interpolation point uses. May be a formula. Unused if type is
MIN or MAX.
Corresponds to the JSON property value
6641 6642 6643 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6641 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6648 6649 6650 6651 6652 6653 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6648 def update!(**args) @color = args[:color] if args.key?(:color) @color_style = args[:color_style] if args.key?(:color_style) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |