Class: Google::Apis::SheetsV4::ManualRuleGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A group name and a list of items from the source data that should be placed in the group with this name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManualRuleGroup

Returns a new instance of ManualRuleGroup.



6864
6865
6866
# File 'lib/google/apis/sheets_v4/classes.rb', line 6864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#group_nameGoogle::Apis::SheetsV4::ExtendedValue

The kinds of value that a cell in a spreadsheet can have. Corresponds to the JSON property groupName



6854
6855
6856
# File 'lib/google/apis/sheets_v4/classes.rb', line 6854

def group_name
  @group_name
end

#itemsArray<Google::Apis::SheetsV4::ExtendedValue>

The items in the source data that should be placed into this group. Each item may be a string, number, or boolean. Items may appear in at most one group within a given ManualRule. Items that do not appear in any group will appear on their own. Corresponds to the JSON property items



6862
6863
6864
# File 'lib/google/apis/sheets_v4/classes.rb', line 6862

def items
  @items
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6869
6870
6871
6872
# File 'lib/google/apis/sheets_v4/classes.rb', line 6869

def update!(**args)
  @group_name = args[:group_name] if args.key?(:group_name)
  @items = args[:items] if args.key?(:items)
end