Class: Google::Apis::SheetsV4::MatchedDeveloperMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A developer metadata entry and the data filters specified in the original request that matched it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MatchedDeveloperMetadata

Returns a new instance of MatchedDeveloperMetadata.



6899
6900
6901
# File 'lib/google/apis/sheets_v4/classes.rb', line 6899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_filtersArray<Google::Apis::SheetsV4::DataFilter>

All filters matching the returned developer metadata. Corresponds to the JSON property dataFilters



6883
6884
6885
# File 'lib/google/apis/sheets_v4/classes.rb', line 6883

def data_filters
  @data_filters
end

#developer_metadataGoogle::Apis::SheetsV4::DeveloperMetadata

Developer metadata associated with a location or object in a spreadsheet. For more information, see Read, write, and search metadata. Developer metadata may be used to associate arbitrary data with various parts of a spreadsheet and it will remain associated at those locations as they move around and the spreadsheet is edited. For example, if developer metadata is associated with row 5 and another row is then subsequently inserted above row 5, that original metadata is still associated with the row it was first associated with (what is now row 6). If the associated object is deleted then its metadata is deleted too. Corresponds to the JSON property developerMetadata



6897
6898
6899
# File 'lib/google/apis/sheets_v4/classes.rb', line 6897

def 
  
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6904
6905
6906
6907
# File 'lib/google/apis/sheets_v4/classes.rb', line 6904

def update!(**args)
  @data_filters = args[:data_filters] if args.key?(:data_filters)
   = args[:developer_metadata] if args.key?(:developer_metadata)
end