Class: Google::Apis::SheetsV4::MergeCellsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::MergeCellsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Merges all cells in the range.
Instance Attribute Summary collapse
-
#merge_type ⇒ String
How the cells should be merged.
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MergeCellsRequest
constructor
A new instance of MergeCellsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MergeCellsRequest
Returns a new instance of MergeCellsRequest.
6961 6962 6963 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#merge_type ⇒ String
How the cells should be merged.
Corresponds to the JSON property mergeType
6942 6943 6944 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6942 def merge_type @merge_type end |
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property range
6959 6960 6961 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6959 def range @range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6966 6967 6968 6969 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6966 def update!(**args) @merge_type = args[:merge_type] if args.key?(:merge_type) @range = args[:range] if args.key?(:range) end |