Class: Google::Apis::SheetsV4::NumberFormat

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The number format of a cell.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NumberFormat



7067
7068
7069
# File 'lib/google/apis/sheets_v4/classes.rb', line 7067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#patternString

Pattern string used for formatting. If not set, a default pattern based on the spreadsheet's locale will be used if necessary for the given type. See the Date and Number Formats guide for more information about the supported patterns. Corresponds to the JSON property pattern



7060
7061
7062
# File 'lib/google/apis/sheets_v4/classes.rb', line 7060

def pattern
  @pattern
end

#typeString

The type of the number format. When writing, this field must be set. Corresponds to the JSON property type



7065
7066
7067
# File 'lib/google/apis/sheets_v4/classes.rb', line 7065

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7072
7073
7074
7075
# File 'lib/google/apis/sheets_v4/classes.rb', line 7072

def update!(**args)
  @pattern = args[:pattern] if args.key?(:pattern)
  @type = args[:type] if args.key?(:type)
end