Class: Google::Apis::SheetsV4::PieChartSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A pie chart.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PieChartSpec

Returns a new instance of PieChartSpec.



7417
7418
7419
# File 'lib/google/apis/sheets_v4/classes.rb', line 7417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property domain



7394
7395
7396
# File 'lib/google/apis/sheets_v4/classes.rb', line 7394

def domain
  @domain
end

#legend_positionString

Where the legend of the pie chart should be drawn. Corresponds to the JSON property legendPosition

Returns:

  • (String)


7399
7400
7401
# File 'lib/google/apis/sheets_v4/classes.rb', line 7399

def legend_position
  @legend_position
end

#pie_holeFloat

The size of the hole in the pie chart. Corresponds to the JSON property pieHole

Returns:

  • (Float)


7404
7405
7406
# File 'lib/google/apis/sheets_v4/classes.rb', line 7404

def pie_hole
  @pie_hole
end

#seriesGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property series



7409
7410
7411
# File 'lib/google/apis/sheets_v4/classes.rb', line 7409

def series
  @series
end

#three_dimensionalBoolean Also known as: three_dimensional?

True if the pie is three dimensional. Corresponds to the JSON property threeDimensional

Returns:

  • (Boolean)


7414
7415
7416
# File 'lib/google/apis/sheets_v4/classes.rb', line 7414

def three_dimensional
  @three_dimensional
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7422
7423
7424
7425
7426
7427
7428
# File 'lib/google/apis/sheets_v4/classes.rb', line 7422

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @legend_position = args[:legend_position] if args.key?(:legend_position)
  @pie_hole = args[:pie_hole] if args.key?(:pie_hole)
  @series = args[:series] if args.key?(:series)
  @three_dimensional = args[:three_dimensional] if args.key?(:three_dimensional)
end