Class: Google::Apis::SheetsV4::PivotGroup
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::PivotGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A single grouping (either row or column) in a pivot table.
Instance Attribute Summary collapse
-
#data_source_column_reference ⇒ Google::Apis::SheetsV4::DataSourceColumnReference
An unique identifier that references a data source column.
-
#group_limit ⇒ Google::Apis::SheetsV4::PivotGroupLimit
The count limit on rows or columns in the pivot group.
-
#group_rule ⇒ Google::Apis::SheetsV4::PivotGroupRule
An optional setting on a PivotGroup that defines buckets for the values in the source data column rather than breaking out each individual value.
-
#label ⇒ String
The labels to use for the row/column groups which can be customized.
-
#repeat_headings ⇒ Boolean
(also: #repeat_headings?)
True if the headings in this pivot group should be repeated.
-
#show_totals ⇒ Boolean
(also: #show_totals?)
True if the pivot table should include the totals for this grouping.
-
#sort_order ⇒ String
The order the values in this group should be sorted.
-
#source_column_offset ⇒ Fixnum
The column offset of the source range that this grouping is based on.
-
#value_bucket ⇒ Google::Apis::SheetsV4::PivotGroupSortValueBucket
Information about which values in a pivot group should be used for sorting.
-
#value_metadata ⇒ Array<Google::Apis::SheetsV4::PivotGroupValueMetadata>
Metadata about values in the grouping.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PivotGroup
constructor
A new instance of PivotGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PivotGroup
Returns a new instance of PivotGroup.
7576 7577 7578 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_source_column_reference ⇒ Google::Apis::SheetsV4::DataSourceColumnReference
An unique identifier that references a data source column.
Corresponds to the JSON property dataSourceColumnReference
7505 7506 7507 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7505 def data_source_column_reference @data_source_column_reference end |
#group_limit ⇒ Google::Apis::SheetsV4::PivotGroupLimit
The count limit on rows or columns in the pivot group.
Corresponds to the JSON property groupLimit
7510 7511 7512 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7510 def group_limit @group_limit end |
#group_rule ⇒ Google::Apis::SheetsV4::PivotGroupRule
An optional setting on a PivotGroup that defines buckets for the values in the
source data column rather than breaking out each individual value. Only one
PivotGroup with a group rule may be added for each column in the source data,
though on any given column you may add both a PivotGroup that has a rule and a
PivotGroup that does not.
Corresponds to the JSON property groupRule
7519 7520 7521 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7519 def group_rule @group_rule end |
#label ⇒ String
The labels to use for the row/column groups which can be customized. For
example, in the following pivot table, the row label is Region (which could
be renamed to State) and the column label is Product (which could be
renamed Item). Pivot tables created before December 2017 do not have header
labels. If you'd like to add header labels to an existing pivot table, please
delete the existing pivot table and then create a new pivot table with same
parameters. +--------------+---------+-------+ | SUM of Units | Product | | |
Region | Pen | Paper | +--------------+---------+-------+ | New York | 345 |
98 | | Oregon | 234 | 123 | | Tennessee | 531 | 415 | +--------------+---------
+-------+ | Grand Total | 1110 | 636 | +--------------+---------+-------+
Corresponds to the JSON property label
7533 7534 7535 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7533 def label @label end |
#repeat_headings ⇒ Boolean Also known as: repeat_headings?
True if the headings in this pivot group should be repeated. This is only
valid for row groupings and is ignored by columns. By default, we minimize
repetition of headings by not showing higher level headings where they are the
same. For example, even though the third row below corresponds to "Q1 Mar", "
Q1" is not shown because it is redundant with previous rows. Setting
repeat_headings to true would cause "Q1" to be repeated for "Feb" and "Mar". +-
-------------+ | Q1 | Jan | | | Feb | | | Mar | +--------+-----+ | Q1 Total | +
--------------+
Corresponds to the JSON property repeatHeadings
7545 7546 7547 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7545 def repeat_headings @repeat_headings end |
#show_totals ⇒ Boolean Also known as: show_totals?
True if the pivot table should include the totals for this grouping.
Corresponds to the JSON property showTotals
7551 7552 7553 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7551 def show_totals @show_totals end |
#sort_order ⇒ String
The order the values in this group should be sorted.
Corresponds to the JSON property sortOrder
7557 7558 7559 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7557 def sort_order @sort_order end |
#source_column_offset ⇒ Fixnum
The column offset of the source range that this grouping is based on. For
example, if the source was C10:E15, a sourceColumnOffset of 0 means this
group refers to column C, whereas the offset 1 would refer to column D.
Corresponds to the JSON property sourceColumnOffset
7564 7565 7566 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7564 def source_column_offset @source_column_offset end |
#value_bucket ⇒ Google::Apis::SheetsV4::PivotGroupSortValueBucket
Information about which values in a pivot group should be used for sorting.
Corresponds to the JSON property valueBucket
7569 7570 7571 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7569 def value_bucket @value_bucket end |
#value_metadata ⇒ Array<Google::Apis::SheetsV4::PivotGroupValueMetadata>
Metadata about values in the grouping.
Corresponds to the JSON property valueMetadata
7574 7575 7576 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7574 def @value_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7581 7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7581 def update!(**args) @data_source_column_reference = args[:data_source_column_reference] if args.key?(:data_source_column_reference) @group_limit = args[:group_limit] if args.key?(:group_limit) @group_rule = args[:group_rule] if args.key?(:group_rule) @label = args[:label] if args.key?(:label) @repeat_headings = args[:repeat_headings] if args.key?(:repeat_headings) @show_totals = args[:show_totals] if args.key?(:show_totals) @sort_order = args[:sort_order] if args.key?(:sort_order) @source_column_offset = args[:source_column_offset] if args.key?(:source_column_offset) @value_bucket = args[:value_bucket] if args.key?(:value_bucket) @value_metadata = args[:value_metadata] if args.key?(:value_metadata) end |