Class: Google::Apis::SheetsV4::PivotGroupLimit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The count limit on rows or columns in the pivot group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PivotGroupLimit

Returns a new instance of PivotGroupLimit.



7614
7615
7616
# File 'lib/google/apis/sheets_v4/classes.rb', line 7614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apply_orderFixnum

The order in which the group limit is applied to the pivot table. Pivot group limits are applied from lower to higher order number. Order numbers are normalized to consecutive integers from 0. For write request, to fully customize the applying orders, all pivot group limits should have this field set with an unique number. Otherwise, the order is determined by the index in the PivotTable.rows list and then the PivotTable.columns list. Corresponds to the JSON property applyOrder

Returns:

  • (Fixnum)


7607
7608
7609
# File 'lib/google/apis/sheets_v4/classes.rb', line 7607

def apply_order
  @apply_order
end

#count_limitFixnum

The count limit. Corresponds to the JSON property countLimit

Returns:

  • (Fixnum)


7612
7613
7614
# File 'lib/google/apis/sheets_v4/classes.rb', line 7612

def count_limit
  @count_limit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7619
7620
7621
7622
# File 'lib/google/apis/sheets_v4/classes.rb', line 7619

def update!(**args)
  @apply_order = args[:apply_order] if args.key?(:apply_order)
  @count_limit = args[:count_limit] if args.key?(:count_limit)
end