Class: Google::Apis::SheetsV4::RandomizeRangeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Randomizes the order of the rows in a range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RandomizeRangeRequest



8044
8045
8046
# File 'lib/google/apis/sheets_v4/classes.rb', line 8044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rangeGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, i.e. the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id: 123456, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id: 123456 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property range



8042
8043
8044
# File 'lib/google/apis/sheets_v4/classes.rb', line 8042

def range
  @range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8049
8050
8051
# File 'lib/google/apis/sheets_v4/classes.rb', line 8049

def update!(**args)
  @range = args[:range] if args.key?(:range)
end