Class: Google::Apis::SheetsV4::RefreshCancellationStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The status of a refresh cancellation. You can send a cancel request to explicitly cancel one or multiple data source object refreshes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RefreshCancellationStatus

Returns a new instance of RefreshCancellationStatus.



8069
8070
8071
# File 'lib/google/apis/sheets_v4/classes.rb', line 8069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeString

The error code. Corresponds to the JSON property errorCode

Returns:

  • (String)


8062
8063
8064
# File 'lib/google/apis/sheets_v4/classes.rb', line 8062

def error_code
  @error_code
end

#stateString

The state of a call to cancel a refresh in Sheets. Corresponds to the JSON property state

Returns:

  • (String)


8067
8068
8069
# File 'lib/google/apis/sheets_v4/classes.rb', line 8067

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8074
8075
8076
8077
# File 'lib/google/apis/sheets_v4/classes.rb', line 8074

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @state = args[:state] if args.key?(:state)
end