Class: Google::Apis::SheetsV4::RefreshDataSourceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Refreshes one or multiple data source objects in the spreadsheet by the specified references. The request requires an additional bigquery.readonly OAuth scope if you are refreshing a BigQuery data source. If there are multiple refresh requests referencing the same data source objects in one batch, only the last refresh request is processed, and all those requests will have the same response accordingly.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RefreshDataSourceRequest

Returns a new instance of RefreshDataSourceRequest.



8147
8148
8149
# File 'lib/google/apis/sheets_v4/classes.rb', line 8147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_idString

Reference to a DataSource. If specified, refreshes all associated data source objects for the data source. Corresponds to the JSON property dataSourceId

Returns:

  • (String)


8126
8127
8128
# File 'lib/google/apis/sheets_v4/classes.rb', line 8126

def data_source_id
  @data_source_id
end

#forceBoolean Also known as: force?

Refreshes the data source objects regardless of the current state. If not set and a referenced data source object was in error state, the refresh will fail immediately. Corresponds to the JSON property force

Returns:

  • (Boolean)


8133
8134
8135
# File 'lib/google/apis/sheets_v4/classes.rb', line 8133

def force
  @force
end

#is_allBoolean Also known as: is_all?

Refreshes all existing data source objects in the spreadsheet. Corresponds to the JSON property isAll

Returns:

  • (Boolean)


8139
8140
8141
# File 'lib/google/apis/sheets_v4/classes.rb', line 8139

def is_all
  @is_all
end

#referencesGoogle::Apis::SheetsV4::DataSourceObjectReferences

A list of references to data source objects. Corresponds to the JSON property references



8145
8146
8147
# File 'lib/google/apis/sheets_v4/classes.rb', line 8145

def references
  @references
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8152
8153
8154
8155
8156
8157
# File 'lib/google/apis/sheets_v4/classes.rb', line 8152

def update!(**args)
  @data_source_id = args[:data_source_id] if args.key?(:data_source_id)
  @force = args[:force] if args.key?(:force)
  @is_all = args[:is_all] if args.key?(:is_all)
  @references = args[:references] if args.key?(:references)
end