Class: Google::Apis::SheetsV4::Request
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::Request
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A single kind of update to apply to a spreadsheet.
Instance Attribute Summary collapse
-
#add_banding ⇒ Google::Apis::SheetsV4::AddBandingRequest
Adds a new banded range to the spreadsheet.
-
#add_chart ⇒ Google::Apis::SheetsV4::AddChartRequest
Adds a chart to a sheet in the spreadsheet.
-
#add_conditional_format_rule ⇒ Google::Apis::SheetsV4::AddConditionalFormatRuleRequest
Adds a new conditional format rule at the given index.
-
#add_data_source ⇒ Google::Apis::SheetsV4::AddDataSourceRequest
Adds a data source.
-
#add_dimension_group ⇒ Google::Apis::SheetsV4::AddDimensionGroupRequest
Creates a group over the specified range.
-
#add_filter_view ⇒ Google::Apis::SheetsV4::AddFilterViewRequest
Adds a filter view.
-
#add_named_range ⇒ Google::Apis::SheetsV4::AddNamedRangeRequest
Adds a named range to the spreadsheet.
-
#add_protected_range ⇒ Google::Apis::SheetsV4::AddProtectedRangeRequest
Adds a new protected range.
-
#add_sheet ⇒ Google::Apis::SheetsV4::AddSheetRequest
Adds a new sheet.
-
#add_slicer ⇒ Google::Apis::SheetsV4::AddSlicerRequest
Adds a slicer to a sheet in the spreadsheet.
-
#add_table ⇒ Google::Apis::SheetsV4::AddTableRequest
Adds a new table to the spreadsheet.
-
#append_cells ⇒ Google::Apis::SheetsV4::AppendCellsRequest
Adds new cells after the last row with data in a sheet, inserting new rows into the sheet if necessary.
-
#append_dimension ⇒ Google::Apis::SheetsV4::AppendDimensionRequest
Appends rows or columns to the end of a sheet.
-
#auto_fill ⇒ Google::Apis::SheetsV4::AutoFillRequest
Fills in more data based on existing data.
-
#auto_resize_dimensions ⇒ Google::Apis::SheetsV4::AutoResizeDimensionsRequest
Automatically resizes one or more dimensions based on the contents of the cells in that dimension.
-
#cancel_data_source_refresh ⇒ Google::Apis::SheetsV4::CancelDataSourceRefreshRequest
Cancels one or multiple refreshes of data source objects in the spreadsheet by the specified references.
-
#clear_basic_filter ⇒ Google::Apis::SheetsV4::ClearBasicFilterRequest
Clears the basic filter, if any exists on the sheet.
-
#copy_paste ⇒ Google::Apis::SheetsV4::CopyPasteRequest
Copies data from the source to the destination.
-
#create_developer_metadata ⇒ Google::Apis::SheetsV4::CreateDeveloperMetadataRequest
A request to create developer metadata.
-
#cut_paste ⇒ Google::Apis::SheetsV4::CutPasteRequest
Moves data from the source to the destination.
-
#delete_banding ⇒ Google::Apis::SheetsV4::DeleteBandingRequest
Removes the banded range with the given ID from the spreadsheet.
-
#delete_conditional_format_rule ⇒ Google::Apis::SheetsV4::DeleteConditionalFormatRuleRequest
Deletes a conditional format rule at the given index.
-
#delete_data_source ⇒ Google::Apis::SheetsV4::DeleteDataSourceRequest
Deletes a data source.
-
#delete_developer_metadata ⇒ Google::Apis::SheetsV4::DeleteDeveloperMetadataRequest
A request to delete developer metadata.
-
#delete_dimension ⇒ Google::Apis::SheetsV4::DeleteDimensionRequest
Deletes the dimensions from the sheet.
-
#delete_dimension_group ⇒ Google::Apis::SheetsV4::DeleteDimensionGroupRequest
Deletes a group over the specified range by decrementing the depth of the dimensions in the range.
-
#delete_duplicates ⇒ Google::Apis::SheetsV4::DeleteDuplicatesRequest
Removes rows within this range that contain values in the specified columns that are duplicates of values in any previous row.
-
#delete_embedded_object ⇒ Google::Apis::SheetsV4::DeleteEmbeddedObjectRequest
Deletes the embedded object with the given ID.
-
#delete_filter_view ⇒ Google::Apis::SheetsV4::DeleteFilterViewRequest
Deletes a particular filter view.
-
#delete_named_range ⇒ Google::Apis::SheetsV4::DeleteNamedRangeRequest
Removes the named range with the given ID from the spreadsheet.
-
#delete_protected_range ⇒ Google::Apis::SheetsV4::DeleteProtectedRangeRequest
Deletes the protected range with the given ID.
-
#delete_range ⇒ Google::Apis::SheetsV4::DeleteRangeRequest
Deletes a range of cells, shifting other cells into the deleted area.
-
#delete_sheet ⇒ Google::Apis::SheetsV4::DeleteSheetRequest
Deletes the requested sheet.
-
#delete_table ⇒ Google::Apis::SheetsV4::DeleteTableRequest
Removes the table with the given ID from the spreadsheet.
-
#duplicate_filter_view ⇒ Google::Apis::SheetsV4::DuplicateFilterViewRequest
Duplicates a particular filter view.
-
#duplicate_sheet ⇒ Google::Apis::SheetsV4::DuplicateSheetRequest
Duplicates the contents of a sheet.
-
#find_replace ⇒ Google::Apis::SheetsV4::FindReplaceRequest
Finds and replaces data in cells over a range, sheet, or all sheets.
-
#insert_dimension ⇒ Google::Apis::SheetsV4::InsertDimensionRequest
Inserts rows or columns in a sheet at a particular index.
-
#insert_range ⇒ Google::Apis::SheetsV4::InsertRangeRequest
Inserts cells into a range, shifting the existing cells over or down.
-
#merge_cells ⇒ Google::Apis::SheetsV4::MergeCellsRequest
Merges all cells in the range.
-
#move_dimension ⇒ Google::Apis::SheetsV4::MoveDimensionRequest
Moves one or more rows or columns.
-
#paste_data ⇒ Google::Apis::SheetsV4::PasteDataRequest
Inserts data into the spreadsheet starting at the specified coordinate.
-
#randomize_range ⇒ Google::Apis::SheetsV4::RandomizeRangeRequest
Randomizes the order of the rows in a range.
-
#refresh_data_source ⇒ Google::Apis::SheetsV4::RefreshDataSourceRequest
Refreshes one or multiple data source objects in the spreadsheet by the specified references.
-
#repeat_cell ⇒ Google::Apis::SheetsV4::RepeatCellRequest
Updates all cells in the range to the values in the given Cell object.
-
#set_basic_filter ⇒ Google::Apis::SheetsV4::SetBasicFilterRequest
Sets the basic filter associated with a sheet.
-
#set_data_validation ⇒ Google::Apis::SheetsV4::SetDataValidationRequest
Sets a data validation rule to every cell in the range.
-
#sort_range ⇒ Google::Apis::SheetsV4::SortRangeRequest
Sorts data in rows based on a sort order per column.
-
#text_to_columns ⇒ Google::Apis::SheetsV4::TextToColumnsRequest
Splits a column of text into multiple columns, based on a delimiter in each cell.
-
#trim_whitespace ⇒ Google::Apis::SheetsV4::TrimWhitespaceRequest
Trims the whitespace (such as spaces, tabs, or new lines) in every cell in the specified range.
-
#unmerge_cells ⇒ Google::Apis::SheetsV4::UnmergeCellsRequest
Unmerges cells in the given range.
-
#update_banding ⇒ Google::Apis::SheetsV4::UpdateBandingRequest
Updates properties of the supplied banded range.
-
#update_borders ⇒ Google::Apis::SheetsV4::UpdateBordersRequest
Updates the borders of a range.
-
#update_cells ⇒ Google::Apis::SheetsV4::UpdateCellsRequest
Updates all cells in a range with new data.
-
#update_chart_spec ⇒ Google::Apis::SheetsV4::UpdateChartSpecRequest
Updates a chart's specifications.
-
#update_conditional_format_rule ⇒ Google::Apis::SheetsV4::UpdateConditionalFormatRuleRequest
Updates a conditional format rule at the given index, or moves a conditional format rule to another index.
-
#update_data_source ⇒ Google::Apis::SheetsV4::UpdateDataSourceRequest
Updates a data source.
-
#update_developer_metadata ⇒ Google::Apis::SheetsV4::UpdateDeveloperMetadataRequest
A request to update properties of developer metadata.
-
#update_dimension_group ⇒ Google::Apis::SheetsV4::UpdateDimensionGroupRequest
Updates the state of the specified group.
-
#update_dimension_properties ⇒ Google::Apis::SheetsV4::UpdateDimensionPropertiesRequest
Updates properties of dimensions within the specified range.
-
#update_embedded_object_border ⇒ Google::Apis::SheetsV4::UpdateEmbeddedObjectBorderRequest
Updates an embedded object's border property.
-
#update_embedded_object_position ⇒ Google::Apis::SheetsV4::UpdateEmbeddedObjectPositionRequest
Update an embedded object's position (such as a moving or resizing a chart or image).
-
#update_filter_view ⇒ Google::Apis::SheetsV4::UpdateFilterViewRequest
Updates properties of the filter view.
-
#update_named_range ⇒ Google::Apis::SheetsV4::UpdateNamedRangeRequest
Updates properties of the named range with the specified namedRangeId.
-
#update_protected_range ⇒ Google::Apis::SheetsV4::UpdateProtectedRangeRequest
Updates an existing protected range with the specified protectedRangeId.
-
#update_sheet_properties ⇒ Google::Apis::SheetsV4::UpdateSheetPropertiesRequest
Updates properties of the sheet with the specified sheetId.
-
#update_slicer_spec ⇒ Google::Apis::SheetsV4::UpdateSlicerSpecRequest
Updates a slicer's specifications.
-
#update_spreadsheet_properties ⇒ Google::Apis::SheetsV4::UpdateSpreadsheetPropertiesRequest
Updates properties of a spreadsheet.
-
#update_table ⇒ Google::Apis::SheetsV4::UpdateTableRequest
Updates a table in the spreadsheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Request
constructor
A new instance of Request.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Request
Returns a new instance of Request.
8653 8654 8655 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_banding ⇒ Google::Apis::SheetsV4::AddBandingRequest
Adds a new banded range to the spreadsheet.
Corresponds to the JSON property addBanding
8240 8241 8242 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8240 def add_banding @add_banding end |
#add_chart ⇒ Google::Apis::SheetsV4::AddChartRequest
Adds a chart to a sheet in the spreadsheet.
Corresponds to the JSON property addChart
8245 8246 8247 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8245 def add_chart @add_chart end |
#add_conditional_format_rule ⇒ Google::Apis::SheetsV4::AddConditionalFormatRuleRequest
Adds a new conditional format rule at the given index. All subsequent rules'
indexes are incremented.
Corresponds to the JSON property addConditionalFormatRule
8251 8252 8253 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8251 def add_conditional_format_rule @add_conditional_format_rule end |
#add_data_source ⇒ Google::Apis::SheetsV4::AddDataSourceRequest
Adds a data source. After the data source is added successfully, an associated
DATA_SOURCE sheet is created and an execution is triggered to refresh the
sheet to read data from the data source. The request requires an additional
bigquery.readonly OAuth scope if you are adding a BigQuery data source.
Corresponds to the JSON property addDataSource
8259 8260 8261 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8259 def add_data_source @add_data_source end |
#add_dimension_group ⇒ Google::Apis::SheetsV4::AddDimensionGroupRequest
Creates a group over the specified range. If the requested range is a superset
of the range of an existing group G, then the depth of G is incremented and
this new group G' has the depth of that group. For example, a group [C:D,
depth 1] + [B:E] results in groups [B:E, depth 1] and [C:D, depth 2]. If the
requested range is a subset of the range of an existing group G, then the
depth of the new group G' becomes one greater than the depth of G. For example,
a group [B:E, depth 1] + [C:D] results in groups [B:E, depth 1] and [C:D,
depth 2]. If the requested range starts before and ends within, or starts
within and ends after, the range of an existing group G, then the range of the
existing group G becomes the union of the ranges, and the new group G' has
depth one greater than the depth of G and range as the intersection of the
ranges. For example, a group [B:D, depth 1] + [C:E] results in groups [B:E,
depth 1] and [C:D, depth 2].
Corresponds to the JSON property addDimensionGroup
8276 8277 8278 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8276 def add_dimension_group @add_dimension_group end |
#add_filter_view ⇒ Google::Apis::SheetsV4::AddFilterViewRequest
Adds a filter view.
Corresponds to the JSON property addFilterView
8281 8282 8283 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8281 def add_filter_view @add_filter_view end |
#add_named_range ⇒ Google::Apis::SheetsV4::AddNamedRangeRequest
Adds a named range to the spreadsheet.
Corresponds to the JSON property addNamedRange
8286 8287 8288 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8286 def add_named_range @add_named_range end |
#add_protected_range ⇒ Google::Apis::SheetsV4::AddProtectedRangeRequest
Adds a new protected range.
Corresponds to the JSON property addProtectedRange
8291 8292 8293 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8291 def add_protected_range @add_protected_range end |
#add_sheet ⇒ Google::Apis::SheetsV4::AddSheetRequest
Adds a new sheet. When a sheet is added at a given index, all subsequent
sheets' indexes are incremented. To add an object sheet, use AddChartRequest
instead and specify EmbeddedObjectPosition.sheetId or EmbeddedObjectPosition.
newSheet.
Corresponds to the JSON property addSheet
8299 8300 8301 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8299 def add_sheet @add_sheet end |
#add_slicer ⇒ Google::Apis::SheetsV4::AddSlicerRequest
Adds a slicer to a sheet in the spreadsheet.
Corresponds to the JSON property addSlicer
8304 8305 8306 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8304 def add_slicer @add_slicer end |
#add_table ⇒ Google::Apis::SheetsV4::AddTableRequest
Adds a new table to the spreadsheet.
Corresponds to the JSON property addTable
8309 8310 8311 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8309 def add_table @add_table end |
#append_cells ⇒ Google::Apis::SheetsV4::AppendCellsRequest
Adds new cells after the last row with data in a sheet, inserting new rows
into the sheet if necessary.
Corresponds to the JSON property appendCells
8315 8316 8317 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8315 def append_cells @append_cells end |
#append_dimension ⇒ Google::Apis::SheetsV4::AppendDimensionRequest
Appends rows or columns to the end of a sheet.
Corresponds to the JSON property appendDimension
8320 8321 8322 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8320 def append_dimension @append_dimension end |
#auto_fill ⇒ Google::Apis::SheetsV4::AutoFillRequest
Fills in more data based on existing data.
Corresponds to the JSON property autoFill
8325 8326 8327 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8325 def auto_fill @auto_fill end |
#auto_resize_dimensions ⇒ Google::Apis::SheetsV4::AutoResizeDimensionsRequest
Automatically resizes one or more dimensions based on the contents of the
cells in that dimension.
Corresponds to the JSON property autoResizeDimensions
8331 8332 8333 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8331 def auto_resize_dimensions @auto_resize_dimensions end |
#cancel_data_source_refresh ⇒ Google::Apis::SheetsV4::CancelDataSourceRefreshRequest
Cancels one or multiple refreshes of data source objects in the spreadsheet by
the specified references. The request requires an additional bigquery.
readonly OAuth scope if you are cancelling a refresh on a BigQuery data
source.
Corresponds to the JSON property cancelDataSourceRefresh
8339 8340 8341 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8339 def cancel_data_source_refresh @cancel_data_source_refresh end |
#clear_basic_filter ⇒ Google::Apis::SheetsV4::ClearBasicFilterRequest
Clears the basic filter, if any exists on the sheet.
Corresponds to the JSON property clearBasicFilter
8344 8345 8346 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8344 def clear_basic_filter @clear_basic_filter end |
#copy_paste ⇒ Google::Apis::SheetsV4::CopyPasteRequest
Copies data from the source to the destination.
Corresponds to the JSON property copyPaste
8349 8350 8351 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8349 def copy_paste @copy_paste end |
#create_developer_metadata ⇒ Google::Apis::SheetsV4::CreateDeveloperMetadataRequest
A request to create developer metadata.
Corresponds to the JSON property createDeveloperMetadata
8354 8355 8356 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8354 def end |
#cut_paste ⇒ Google::Apis::SheetsV4::CutPasteRequest
Moves data from the source to the destination.
Corresponds to the JSON property cutPaste
8359 8360 8361 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8359 def cut_paste @cut_paste end |
#delete_banding ⇒ Google::Apis::SheetsV4::DeleteBandingRequest
Removes the banded range with the given ID from the spreadsheet.
Corresponds to the JSON property deleteBanding
8364 8365 8366 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8364 def delete_banding @delete_banding end |
#delete_conditional_format_rule ⇒ Google::Apis::SheetsV4::DeleteConditionalFormatRuleRequest
Deletes a conditional format rule at the given index. All subsequent rules'
indexes are decremented.
Corresponds to the JSON property deleteConditionalFormatRule
8370 8371 8372 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8370 def delete_conditional_format_rule @delete_conditional_format_rule end |
#delete_data_source ⇒ Google::Apis::SheetsV4::DeleteDataSourceRequest
Deletes a data source. The request also deletes the associated data source
sheet, and unlinks all associated data source objects.
Corresponds to the JSON property deleteDataSource
8376 8377 8378 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8376 def delete_data_source @delete_data_source end |
#delete_developer_metadata ⇒ Google::Apis::SheetsV4::DeleteDeveloperMetadataRequest
A request to delete developer metadata.
Corresponds to the JSON property deleteDeveloperMetadata
8381 8382 8383 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8381 def end |
#delete_dimension ⇒ Google::Apis::SheetsV4::DeleteDimensionRequest
Deletes the dimensions from the sheet.
Corresponds to the JSON property deleteDimension
8386 8387 8388 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8386 def delete_dimension @delete_dimension end |
#delete_dimension_group ⇒ Google::Apis::SheetsV4::DeleteDimensionGroupRequest
Deletes a group over the specified range by decrementing the depth of the
dimensions in the range. For example, assume the sheet has a depth-1 group
over B:E and a depth-2 group over C:D. Deleting a group over D:E leaves the
sheet with a depth-1 group over B:D and a depth-2 group over C:C.
Corresponds to the JSON property deleteDimensionGroup
8394 8395 8396 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8394 def delete_dimension_group @delete_dimension_group end |
#delete_duplicates ⇒ Google::Apis::SheetsV4::DeleteDuplicatesRequest
Removes rows within this range that contain values in the specified columns
that are duplicates of values in any previous row. Rows with identical values
but different letter cases, formatting, or formulas are considered to be
duplicates. This request also removes duplicate rows hidden from view (for
example, due to a filter). When removing duplicates, the first instance of
each duplicate row scanning from the top downwards is kept in the resulting
range. Content outside of the specified range isn't removed, and rows
considered duplicates do not have to be adjacent to each other in the range.
Corresponds to the JSON property deleteDuplicates
8406 8407 8408 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8406 def delete_duplicates @delete_duplicates end |
#delete_embedded_object ⇒ Google::Apis::SheetsV4::DeleteEmbeddedObjectRequest
Deletes the embedded object with the given ID.
Corresponds to the JSON property deleteEmbeddedObject
8411 8412 8413 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8411 def end |
#delete_filter_view ⇒ Google::Apis::SheetsV4::DeleteFilterViewRequest
Deletes a particular filter view.
Corresponds to the JSON property deleteFilterView
8416 8417 8418 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8416 def delete_filter_view @delete_filter_view end |
#delete_named_range ⇒ Google::Apis::SheetsV4::DeleteNamedRangeRequest
Removes the named range with the given ID from the spreadsheet.
Corresponds to the JSON property deleteNamedRange
8421 8422 8423 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8421 def delete_named_range @delete_named_range end |
#delete_protected_range ⇒ Google::Apis::SheetsV4::DeleteProtectedRangeRequest
Deletes the protected range with the given ID.
Corresponds to the JSON property deleteProtectedRange
8426 8427 8428 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8426 def delete_protected_range @delete_protected_range end |
#delete_range ⇒ Google::Apis::SheetsV4::DeleteRangeRequest
Deletes a range of cells, shifting other cells into the deleted area.
Corresponds to the JSON property deleteRange
8431 8432 8433 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8431 def delete_range @delete_range end |
#delete_sheet ⇒ Google::Apis::SheetsV4::DeleteSheetRequest
Deletes the requested sheet.
Corresponds to the JSON property deleteSheet
8436 8437 8438 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8436 def delete_sheet @delete_sheet end |
#delete_table ⇒ Google::Apis::SheetsV4::DeleteTableRequest
Removes the table with the given ID from the spreadsheet.
Corresponds to the JSON property deleteTable
8441 8442 8443 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8441 def delete_table @delete_table end |
#duplicate_filter_view ⇒ Google::Apis::SheetsV4::DuplicateFilterViewRequest
Duplicates a particular filter view.
Corresponds to the JSON property duplicateFilterView
8446 8447 8448 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8446 def duplicate_filter_view @duplicate_filter_view end |
#duplicate_sheet ⇒ Google::Apis::SheetsV4::DuplicateSheetRequest
Duplicates the contents of a sheet.
Corresponds to the JSON property duplicateSheet
8451 8452 8453 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8451 def duplicate_sheet @duplicate_sheet end |
#find_replace ⇒ Google::Apis::SheetsV4::FindReplaceRequest
Finds and replaces data in cells over a range, sheet, or all sheets.
Corresponds to the JSON property findReplace
8456 8457 8458 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8456 def find_replace @find_replace end |
#insert_dimension ⇒ Google::Apis::SheetsV4::InsertDimensionRequest
Inserts rows or columns in a sheet at a particular index.
Corresponds to the JSON property insertDimension
8461 8462 8463 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8461 def insert_dimension @insert_dimension end |
#insert_range ⇒ Google::Apis::SheetsV4::InsertRangeRequest
Inserts cells into a range, shifting the existing cells over or down.
Corresponds to the JSON property insertRange
8466 8467 8468 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8466 def insert_range @insert_range end |
#merge_cells ⇒ Google::Apis::SheetsV4::MergeCellsRequest
Merges all cells in the range.
Corresponds to the JSON property mergeCells
8471 8472 8473 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8471 def merge_cells @merge_cells end |
#move_dimension ⇒ Google::Apis::SheetsV4::MoveDimensionRequest
Moves one or more rows or columns.
Corresponds to the JSON property moveDimension
8476 8477 8478 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8476 def move_dimension @move_dimension end |
#paste_data ⇒ Google::Apis::SheetsV4::PasteDataRequest
Inserts data into the spreadsheet starting at the specified coordinate.
Corresponds to the JSON property pasteData
8481 8482 8483 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8481 def paste_data @paste_data end |
#randomize_range ⇒ Google::Apis::SheetsV4::RandomizeRangeRequest
Randomizes the order of the rows in a range.
Corresponds to the JSON property randomizeRange
8486 8487 8488 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8486 def randomize_range @randomize_range end |
#refresh_data_source ⇒ Google::Apis::SheetsV4::RefreshDataSourceRequest
Refreshes one or multiple data source objects in the spreadsheet by the
specified references. The request requires an additional bigquery.readonly
OAuth scope if you are refreshing a BigQuery data source. If there are
multiple refresh requests referencing the same data source objects in one
batch, only the last refresh request is processed, and all those requests will
have the same response accordingly.
Corresponds to the JSON property refreshDataSource
8496 8497 8498 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8496 def refresh_data_source @refresh_data_source end |
#repeat_cell ⇒ Google::Apis::SheetsV4::RepeatCellRequest
Updates all cells in the range to the values in the given Cell object. Only
the fields listed in the fields field are updated; others are unchanged. If
writing a cell with a formula, the formula's ranges will automatically
increment for each field in the range. For example, if writing a cell with
formula =A1 into range B2:C4, B2 would be =A1, B3 would be =A2, B4 would
be =A3, C2 would be =B1, C3 would be =B2, C4 would be =B3. To keep the
formula's ranges static, use the $ indicator. For example, use the formula =
$A$1 to prevent both the row and the column from incrementing.
Corresponds to the JSON property repeatCell
8508 8509 8510 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8508 def repeat_cell @repeat_cell end |
#set_basic_filter ⇒ Google::Apis::SheetsV4::SetBasicFilterRequest
Sets the basic filter associated with a sheet.
Corresponds to the JSON property setBasicFilter
8513 8514 8515 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8513 def set_basic_filter @set_basic_filter end |
#set_data_validation ⇒ Google::Apis::SheetsV4::SetDataValidationRequest
Sets a data validation rule to every cell in the range. To clear validation in
a range, call this with no rule specified.
Corresponds to the JSON property setDataValidation
8519 8520 8521 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8519 def set_data_validation @set_data_validation end |
#sort_range ⇒ Google::Apis::SheetsV4::SortRangeRequest
Sorts data in rows based on a sort order per column.
Corresponds to the JSON property sortRange
8524 8525 8526 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8524 def sort_range @sort_range end |
#text_to_columns ⇒ Google::Apis::SheetsV4::TextToColumnsRequest
Splits a column of text into multiple columns, based on a delimiter in each
cell.
Corresponds to the JSON property textToColumns
8530 8531 8532 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8530 def text_to_columns @text_to_columns end |
#trim_whitespace ⇒ Google::Apis::SheetsV4::TrimWhitespaceRequest
Trims the whitespace (such as spaces, tabs, or new lines) in every cell in the
specified range. This request removes all whitespace from the start and end of
each cell's text, and reduces any subsequence of remaining whitespace
characters to a single space. If the resulting trimmed text starts with a '+'
or '=' character, the text remains as a string value and isn't interpreted as
a formula.
Corresponds to the JSON property trimWhitespace
8540 8541 8542 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8540 def trim_whitespace @trim_whitespace end |
#unmerge_cells ⇒ Google::Apis::SheetsV4::UnmergeCellsRequest
Unmerges cells in the given range.
Corresponds to the JSON property unmergeCells
8545 8546 8547 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8545 def unmerge_cells @unmerge_cells end |
#update_banding ⇒ Google::Apis::SheetsV4::UpdateBandingRequest
Updates properties of the supplied banded range.
Corresponds to the JSON property updateBanding
8550 8551 8552 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8550 def update_banding @update_banding end |
#update_borders ⇒ Google::Apis::SheetsV4::UpdateBordersRequest
Updates the borders of a range. If a field is not set in the request, that
means the border remains as-is. For example, with two subsequent
UpdateBordersRequest: 1. range: A1:A5 top: RED, bottom: WHITE 2. range:
A1:A5 left: BLUE That would result in A1:A5 having a borders of top:
RED, bottom: WHITE, left: BLUE. If you want to clear a border, explicitly
set the style to NONE.
Corresponds to the JSON property updateBorders
8560 8561 8562 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8560 def update_borders @update_borders end |
#update_cells ⇒ Google::Apis::SheetsV4::UpdateCellsRequest
Updates all cells in a range with new data.
Corresponds to the JSON property updateCells
8565 8566 8567 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8565 def update_cells @update_cells end |
#update_chart_spec ⇒ Google::Apis::SheetsV4::UpdateChartSpecRequest
Updates a chart's specifications. (This does not move or resize a chart. To
move or resize a chart, use UpdateEmbeddedObjectPositionRequest.)
Corresponds to the JSON property updateChartSpec
8571 8572 8573 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8571 def update_chart_spec @update_chart_spec end |
#update_conditional_format_rule ⇒ Google::Apis::SheetsV4::UpdateConditionalFormatRuleRequest
Updates a conditional format rule at the given index, or moves a conditional
format rule to another index.
Corresponds to the JSON property updateConditionalFormatRule
8577 8578 8579 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8577 def update_conditional_format_rule @update_conditional_format_rule end |
#update_data_source ⇒ Google::Apis::SheetsV4::UpdateDataSourceRequest
Updates a data source. After the data source is updated successfully, an
execution is triggered to refresh the associated DATA_SOURCE sheet to read
data from the updated data source. The request requires an additional
bigquery.readonly OAuth scope if you are updating a BigQuery data source.
Corresponds to the JSON property updateDataSource
8585 8586 8587 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8585 def update_data_source @update_data_source end |
#update_developer_metadata ⇒ Google::Apis::SheetsV4::UpdateDeveloperMetadataRequest
A request to update properties of developer metadata. Updates the properties
of the developer metadata selected by the filters to the values provided in
the DeveloperMetadata resource. Callers must specify the properties they wish
to update in the fields parameter, as well as specify at least one DataFilter
matching the metadata they wish to update.
Corresponds to the JSON property updateDeveloperMetadata
8594 8595 8596 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8594 def end |
#update_dimension_group ⇒ Google::Apis::SheetsV4::UpdateDimensionGroupRequest
Updates the state of the specified group.
Corresponds to the JSON property updateDimensionGroup
8599 8600 8601 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8599 def update_dimension_group @update_dimension_group end |
#update_dimension_properties ⇒ Google::Apis::SheetsV4::UpdateDimensionPropertiesRequest
Updates properties of dimensions within the specified range.
Corresponds to the JSON property updateDimensionProperties
8604 8605 8606 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8604 def update_dimension_properties @update_dimension_properties end |
#update_embedded_object_border ⇒ Google::Apis::SheetsV4::UpdateEmbeddedObjectBorderRequest
Updates an embedded object's border property.
Corresponds to the JSON property updateEmbeddedObjectBorder
8609 8610 8611 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8609 def end |
#update_embedded_object_position ⇒ Google::Apis::SheetsV4::UpdateEmbeddedObjectPositionRequest
Update an embedded object's position (such as a moving or resizing a chart or
image).
Corresponds to the JSON property updateEmbeddedObjectPosition
8615 8616 8617 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8615 def end |
#update_filter_view ⇒ Google::Apis::SheetsV4::UpdateFilterViewRequest
Updates properties of the filter view.
Corresponds to the JSON property updateFilterView
8620 8621 8622 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8620 def update_filter_view @update_filter_view end |
#update_named_range ⇒ Google::Apis::SheetsV4::UpdateNamedRangeRequest
Updates properties of the named range with the specified namedRangeId.
Corresponds to the JSON property updateNamedRange
8625 8626 8627 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8625 def update_named_range @update_named_range end |
#update_protected_range ⇒ Google::Apis::SheetsV4::UpdateProtectedRangeRequest
Updates an existing protected range with the specified protectedRangeId.
Corresponds to the JSON property updateProtectedRange
8630 8631 8632 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8630 def update_protected_range @update_protected_range end |
#update_sheet_properties ⇒ Google::Apis::SheetsV4::UpdateSheetPropertiesRequest
Updates properties of the sheet with the specified sheetId.
Corresponds to the JSON property updateSheetProperties
8635 8636 8637 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8635 def update_sheet_properties @update_sheet_properties end |
#update_slicer_spec ⇒ Google::Apis::SheetsV4::UpdateSlicerSpecRequest
Updates a slicer's specifications. (This does not move or resize a slicer. To
move or resize a slicer use UpdateEmbeddedObjectPositionRequest.
Corresponds to the JSON property updateSlicerSpec
8641 8642 8643 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8641 def update_slicer_spec @update_slicer_spec end |
#update_spreadsheet_properties ⇒ Google::Apis::SheetsV4::UpdateSpreadsheetPropertiesRequest
Updates properties of a spreadsheet.
Corresponds to the JSON property updateSpreadsheetProperties
8646 8647 8648 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8646 def update_spreadsheet_properties @update_spreadsheet_properties end |
#update_table ⇒ Google::Apis::SheetsV4::UpdateTableRequest
Updates a table in the spreadsheet.
Corresponds to the JSON property updateTable
8651 8652 8653 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8651 def update_table @update_table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8658 8659 8660 8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 8679 8680 8681 8682 8683 8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 8697 8698 8699 8700 8701 8702 8703 8704 8705 8706 8707 8708 8709 8710 8711 8712 8713 8714 8715 8716 8717 8718 8719 8720 8721 8722 8723 8724 8725 8726 8727 8728 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8658 def update!(**args) @add_banding = args[:add_banding] if args.key?(:add_banding) @add_chart = args[:add_chart] if args.key?(:add_chart) @add_conditional_format_rule = args[:add_conditional_format_rule] if args.key?(:add_conditional_format_rule) @add_data_source = args[:add_data_source] if args.key?(:add_data_source) @add_dimension_group = args[:add_dimension_group] if args.key?(:add_dimension_group) @add_filter_view = args[:add_filter_view] if args.key?(:add_filter_view) @add_named_range = args[:add_named_range] if args.key?(:add_named_range) @add_protected_range = args[:add_protected_range] if args.key?(:add_protected_range) @add_sheet = args[:add_sheet] if args.key?(:add_sheet) @add_slicer = args[:add_slicer] if args.key?(:add_slicer) @add_table = args[:add_table] if args.key?(:add_table) @append_cells = args[:append_cells] if args.key?(:append_cells) @append_dimension = args[:append_dimension] if args.key?(:append_dimension) @auto_fill = args[:auto_fill] if args.key?(:auto_fill) @auto_resize_dimensions = args[:auto_resize_dimensions] if args.key?(:auto_resize_dimensions) @cancel_data_source_refresh = args[:cancel_data_source_refresh] if args.key?(:cancel_data_source_refresh) @clear_basic_filter = args[:clear_basic_filter] if args.key?(:clear_basic_filter) @copy_paste = args[:copy_paste] if args.key?(:copy_paste) = args[:create_developer_metadata] if args.key?(:create_developer_metadata) @cut_paste = args[:cut_paste] if args.key?(:cut_paste) @delete_banding = args[:delete_banding] if args.key?(:delete_banding) @delete_conditional_format_rule = args[:delete_conditional_format_rule] if args.key?(:delete_conditional_format_rule) @delete_data_source = args[:delete_data_source] if args.key?(:delete_data_source) = args[:delete_developer_metadata] if args.key?(:delete_developer_metadata) @delete_dimension = args[:delete_dimension] if args.key?(:delete_dimension) @delete_dimension_group = args[:delete_dimension_group] if args.key?(:delete_dimension_group) @delete_duplicates = args[:delete_duplicates] if args.key?(:delete_duplicates) = args[:delete_embedded_object] if args.key?(:delete_embedded_object) @delete_filter_view = args[:delete_filter_view] if args.key?(:delete_filter_view) @delete_named_range = args[:delete_named_range] if args.key?(:delete_named_range) @delete_protected_range = args[:delete_protected_range] if args.key?(:delete_protected_range) @delete_range = args[:delete_range] if args.key?(:delete_range) @delete_sheet = args[:delete_sheet] if args.key?(:delete_sheet) @delete_table = args[:delete_table] if args.key?(:delete_table) @duplicate_filter_view = args[:duplicate_filter_view] if args.key?(:duplicate_filter_view) @duplicate_sheet = args[:duplicate_sheet] if args.key?(:duplicate_sheet) @find_replace = args[:find_replace] if args.key?(:find_replace) @insert_dimension = args[:insert_dimension] if args.key?(:insert_dimension) @insert_range = args[:insert_range] if args.key?(:insert_range) @merge_cells = args[:merge_cells] if args.key?(:merge_cells) @move_dimension = args[:move_dimension] if args.key?(:move_dimension) @paste_data = args[:paste_data] if args.key?(:paste_data) @randomize_range = args[:randomize_range] if args.key?(:randomize_range) @refresh_data_source = args[:refresh_data_source] if args.key?(:refresh_data_source) @repeat_cell = args[:repeat_cell] if args.key?(:repeat_cell) @set_basic_filter = args[:set_basic_filter] if args.key?(:set_basic_filter) @set_data_validation = args[:set_data_validation] if args.key?(:set_data_validation) @sort_range = args[:sort_range] if args.key?(:sort_range) @text_to_columns = args[:text_to_columns] if args.key?(:text_to_columns) @trim_whitespace = args[:trim_whitespace] if args.key?(:trim_whitespace) @unmerge_cells = args[:unmerge_cells] if args.key?(:unmerge_cells) @update_banding = args[:update_banding] if args.key?(:update_banding) @update_borders = args[:update_borders] if args.key?(:update_borders) @update_cells = args[:update_cells] if args.key?(:update_cells) @update_chart_spec = args[:update_chart_spec] if args.key?(:update_chart_spec) @update_conditional_format_rule = args[:update_conditional_format_rule] if args.key?(:update_conditional_format_rule) @update_data_source = args[:update_data_source] if args.key?(:update_data_source) = args[:update_developer_metadata] if args.key?(:update_developer_metadata) @update_dimension_group = args[:update_dimension_group] if args.key?(:update_dimension_group) @update_dimension_properties = args[:update_dimension_properties] if args.key?(:update_dimension_properties) = args[:update_embedded_object_border] if args.key?(:update_embedded_object_border) = args[:update_embedded_object_position] if args.key?(:update_embedded_object_position) @update_filter_view = args[:update_filter_view] if args.key?(:update_filter_view) @update_named_range = args[:update_named_range] if args.key?(:update_named_range) @update_protected_range = args[:update_protected_range] if args.key?(:update_protected_range) @update_sheet_properties = args[:update_sheet_properties] if args.key?(:update_sheet_properties) @update_slicer_spec = args[:update_slicer_spec] if args.key?(:update_slicer_spec) @update_spreadsheet_properties = args[:update_spreadsheet_properties] if args.key?(:update_spreadsheet_properties) @update_table = args[:update_table] if args.key?(:update_table) end |