Class: Google::Apis::SheetsV4::RichLinkProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Properties of a link to a Google resource (such as a file in Drive, a YouTube video, a Maps address, or a Calendar event). Only Drive files can be written as chips. All other rich link types are read only. URIs cannot exceed 2000 bytes when writing. NOTE: Writing Drive file chips requires at least one of the drive.file, drive.readonly, or drive OAuth scopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RichLinkProperties

Returns a new instance of RichLinkProperties.



8913
8914
8915
# File 'lib/google/apis/sheets_v4/classes.rb', line 8913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mime_typeString

Output only. The MIME type of the link, if there's one (for example, when it's a file in Drive). Corresponds to the JSON property mimeType

Returns:

  • (String)


8906
8907
8908
# File 'lib/google/apis/sheets_v4/classes.rb', line 8906

def mime_type
  @mime_type
end

#uriString

Required. The URI to the link. This is always present. Corresponds to the JSON property uri

Returns:

  • (String)


8911
8912
8913
# File 'lib/google/apis/sheets_v4/classes.rb', line 8911

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8918
8919
8920
8921
# File 'lib/google/apis/sheets_v4/classes.rb', line 8918

def update!(**args)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @uri = args[:uri] if args.key?(:uri)
end