Class: Google::Apis::SheetsV4::ScorecardChartSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A scorecard chart. Scorecard charts are used to highlight key performance indicators, known as KPIs, on the spreadsheet. A scorecard chart can represent things like total sales, average cost, or a top selling item. You can specify a single data value, or aggregate over a range of data. Percentage or absolute difference from a baseline value can be highlighted, like changes over time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScorecardChartSpec

Returns a new instance of ScorecardChartSpec.



8995
8996
8997
# File 'lib/google/apis/sheets_v4/classes.rb', line 8995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregate_typeString

The aggregation type for key and baseline chart data in scorecard chart. This field is not supported for data source charts. Use the ChartData.aggregateType field of the key_value_data or baseline_value_data instead for data source charts. This field is optional. Corresponds to the JSON property aggregateType

Returns:

  • (String)


8957
8958
8959
# File 'lib/google/apis/sheets_v4/classes.rb', line 8957

def aggregate_type
  @aggregate_type
end

#baseline_value_dataGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property baselineValueData



8962
8963
8964
# File 'lib/google/apis/sheets_v4/classes.rb', line 8962

def baseline_value_data
  @baseline_value_data
end

#baseline_value_formatGoogle::Apis::SheetsV4::BaselineValueFormat

Formatting options for baseline value. Corresponds to the JSON property baselineValueFormat



8967
8968
8969
# File 'lib/google/apis/sheets_v4/classes.rb', line 8967

def baseline_value_format
  @baseline_value_format
end

#custom_format_optionsGoogle::Apis::SheetsV4::ChartCustomNumberFormatOptions

Custom number formatting options for chart attributes. Corresponds to the JSON property customFormatOptions



8972
8973
8974
# File 'lib/google/apis/sheets_v4/classes.rb', line 8972

def custom_format_options
  @custom_format_options
end

#key_value_dataGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property keyValueData



8977
8978
8979
# File 'lib/google/apis/sheets_v4/classes.rb', line 8977

def key_value_data
  @key_value_data
end

#key_value_formatGoogle::Apis::SheetsV4::KeyValueFormat

Formatting options for key value. Corresponds to the JSON property keyValueFormat



8982
8983
8984
# File 'lib/google/apis/sheets_v4/classes.rb', line 8982

def key_value_format
  @key_value_format
end

#number_format_sourceString

The number format source used in the scorecard chart. This field is optional. Corresponds to the JSON property numberFormatSource

Returns:

  • (String)


8987
8988
8989
# File 'lib/google/apis/sheets_v4/classes.rb', line 8987

def number_format_source
  @number_format_source
end

#scale_factorFloat

Value to scale scorecard key and baseline value. For example, a factor of 10 can be used to divide all values in the chart by 10. This field is optional. Corresponds to the JSON property scaleFactor

Returns:

  • (Float)


8993
8994
8995
# File 'lib/google/apis/sheets_v4/classes.rb', line 8993

def scale_factor
  @scale_factor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9000
9001
9002
9003
9004
9005
9006
9007
9008
9009
# File 'lib/google/apis/sheets_v4/classes.rb', line 9000

def update!(**args)
  @aggregate_type = args[:aggregate_type] if args.key?(:aggregate_type)
  @baseline_value_data = args[:baseline_value_data] if args.key?(:baseline_value_data)
  @baseline_value_format = args[:baseline_value_format] if args.key?(:baseline_value_format)
  @custom_format_options = args[:custom_format_options] if args.key?(:custom_format_options)
  @key_value_data = args[:key_value_data] if args.key?(:key_value_data)
  @key_value_format = args[:key_value_format] if args.key?(:key_value_format)
  @number_format_source = args[:number_format_source] if args.key?(:number_format_source)
  @scale_factor = args[:scale_factor] if args.key?(:scale_factor)
end