Class: Google::Apis::SheetsV4::SearchDeveloperMetadataRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::SearchDeveloperMetadataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A request to retrieve all developer metadata matching the set of specified criteria.
Instance Attribute Summary collapse
-
#data_filters ⇒ Array<Google::Apis::SheetsV4::DataFilter>
The data filters describing the criteria used to determine which DeveloperMetadata entries to return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchDeveloperMetadataRequest
constructor
A new instance of SearchDeveloperMetadataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchDeveloperMetadataRequest
9024 9025 9026 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_filters ⇒ Array<Google::Apis::SheetsV4::DataFilter>
The data filters describing the criteria used to determine which
DeveloperMetadata entries to return. DeveloperMetadata matching any of the
specified filters are included in the response.
Corresponds to the JSON property dataFilters
9022 9023 9024 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9022 def data_filters @data_filters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9029 9030 9031 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9029 def update!(**args) @data_filters = args[:data_filters] if args.key?(:data_filters) end |