Class: Google::Apis::SheetsV4::SetDataValidationRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::SetDataValidationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Sets a data validation rule to every cell in the range. To clear validation in a range, call this with no rule specified.
Instance Attribute Summary collapse
-
#filtered_rows_included ⇒ Boolean
(also: #filtered_rows_included?)
Optional.
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#rule ⇒ Google::Apis::SheetsV4::DataValidationRule
A data validation rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetDataValidationRequest
constructor
A new instance of SetDataValidationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetDataValidationRequest
9108 9109 9110 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filtered_rows_included ⇒ Boolean Also known as: filtered_rows_included?
Optional. If true, the data validation rule will be applied to the filtered
rows as well.
Corresponds to the JSON property filteredRowsIncluded
9083 9084 9085 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9083 def filtered_rows_included @filtered_rows_included end |
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property range
9101 9102 9103 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9101 def range @range end |
#rule ⇒ Google::Apis::SheetsV4::DataValidationRule
A data validation rule.
Corresponds to the JSON property rule
9106 9107 9108 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9106 def rule @rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9113 9114 9115 9116 9117 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9113 def update!(**args) @filtered_rows_included = args[:filtered_rows_included] if args.key?(:filtered_rows_included) @range = args[:range] if args.key?(:range) @rule = args[:rule] if args.key?(:rule) end |