Class: Google::Apis::SheetsV4::SheetProperties
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::SheetProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Properties of a sheet.
Instance Attribute Summary collapse
-
#data_source_sheet_properties ⇒ Google::Apis::SheetsV4::DataSourceSheetProperties
Additional properties of a DATA_SOURCE sheet.
-
#grid_properties ⇒ Google::Apis::SheetsV4::GridProperties
Properties of a grid.
-
#hidden ⇒ Boolean
(also: #hidden?)
True if the sheet is hidden in the UI, false if it's visible.
-
#index ⇒ Fixnum
The index of the sheet within the spreadsheet.
-
#right_to_left ⇒ Boolean
(also: #right_to_left?)
True if the sheet is an RTL sheet instead of an LTR sheet.
-
#sheet_id ⇒ Fixnum
The ID of the sheet.
-
#sheet_type ⇒ String
The type of sheet.
-
#tab_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space.
-
#tab_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
-
#title ⇒ String
The name of the sheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SheetProperties
constructor
A new instance of SheetProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SheetProperties
Returns a new instance of SheetProperties.
9336 9337 9338 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_source_sheet_properties ⇒ Google::Apis::SheetsV4::DataSourceSheetProperties
Additional properties of a DATA_SOURCE sheet.
Corresponds to the JSON property dataSourceSheetProperties
9235 9236 9237 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9235 def data_source_sheet_properties @data_source_sheet_properties end |
#grid_properties ⇒ Google::Apis::SheetsV4::GridProperties
Properties of a grid.
Corresponds to the JSON property gridProperties
9240 9241 9242 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9240 def grid_properties @grid_properties end |
#hidden ⇒ Boolean Also known as:
True if the sheet is hidden in the UI, false if it's visible.
Corresponds to the JSON property hidden
9245 9246 9247 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9245 def hidden @hidden end |
#index ⇒ Fixnum
The index of the sheet within the spreadsheet. When adding or updating sheet
properties, if this field is excluded then the sheet is added or moved to the
end of the sheet list. When updating sheet indices or inserting sheets,
movement is considered in "before the move" indexes. For example, if there
were three sheets (S1, S2, S3) in order to move S1 ahead of S2 the index would
have to be set to 2. A sheet index update request is ignored if the requested
index is identical to the sheets current index or if the requested new index
is equal to the current sheet index + 1.
Corresponds to the JSON property index
9258 9259 9260 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9258 def index @index end |
#right_to_left ⇒ Boolean Also known as: right_to_left?
True if the sheet is an RTL sheet instead of an LTR sheet.
Corresponds to the JSON property rightToLeft
9263 9264 9265 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9263 def right_to_left @right_to_left end |
#sheet_id ⇒ Fixnum
The ID of the sheet. Must be non-negative. This field cannot be changed once
set.
Corresponds to the JSON property sheetId
9270 9271 9272 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9270 def sheet_id @sheet_id end |
#sheet_type ⇒ String
The type of sheet. Defaults to GRID. This field cannot be changed once set.
Corresponds to the JSON property sheetType
9275 9276 9277 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9275 def sheet_type @sheet_type end |
#tab_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property tabColor
9324 9325 9326 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9324 def tab_color @tab_color end |
#tab_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
Corresponds to the JSON property tabColorStyle
9329 9330 9331 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9329 def tab_color_style @tab_color_style end |
#title ⇒ String
The name of the sheet.
Corresponds to the JSON property title
9334 9335 9336 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9334 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9341 def update!(**args) @data_source_sheet_properties = args[:data_source_sheet_properties] if args.key?(:data_source_sheet_properties) @grid_properties = args[:grid_properties] if args.key?(:grid_properties) @hidden = args[:hidden] if args.key?(:hidden) @index = args[:index] if args.key?(:index) @right_to_left = args[:right_to_left] if args.key?(:right_to_left) @sheet_id = args[:sheet_id] if args.key?(:sheet_id) @sheet_type = args[:sheet_type] if args.key?(:sheet_type) @tab_color = args[:tab_color] if args.key?(:tab_color) @tab_color_style = args[:tab_color_style] if args.key?(:tab_color_style) @title = args[:title] if args.key?(:title) end |