Class: Google::Apis::SheetsV4::SlicerSpec
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::SlicerSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The specifications of a slicer.
Instance Attribute Summary collapse
-
#apply_to_pivot_tables ⇒ Boolean
(also: #apply_to_pivot_tables?)
True if the filter should apply to pivot tables.
-
#background_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space.
-
#background_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
-
#column_index ⇒ Fixnum
The zero-based column index in the data table on which the filter is applied to.
-
#data_range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#filter_criteria ⇒ Google::Apis::SheetsV4::FilterCriteria
Criteria for showing or hiding rows in a filter or filter view.
-
#horizontal_alignment ⇒ String
The horizontal alignment of title in the slicer.
-
#text_format ⇒ Google::Apis::SheetsV4::TextFormat
The format of a run of text in a cell.
-
#title ⇒ String
The title of the slicer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlicerSpec
constructor
A new instance of SlicerSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlicerSpec
Returns a new instance of SlicerSpec.
9495 9496 9497 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apply_to_pivot_tables ⇒ Boolean Also known as: apply_to_pivot_tables?
True if the filter should apply to pivot tables. If not set, default to True.
Corresponds to the JSON property applyToPivotTables
9393 9394 9395 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9393 def apply_to_pivot_tables @apply_to_pivot_tables end |
#background_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property backgroundColor
9443 9444 9445 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9443 def background_color @background_color end |
#background_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
Corresponds to the JSON property backgroundColorStyle
9448 9449 9450 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9448 def background_color_style @background_color_style end |
#column_index ⇒ Fixnum
The zero-based column index in the data table on which the filter is applied
to.
Corresponds to the JSON property columnIndex
9454 9455 9456 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9454 def column_index @column_index end |
#data_range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property dataRange
9471 9472 9473 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9471 def data_range @data_range end |
#filter_criteria ⇒ Google::Apis::SheetsV4::FilterCriteria
Criteria for showing or hiding rows in a filter or filter view.
Corresponds to the JSON property filterCriteria
9476 9477 9478 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9476 def filter_criteria @filter_criteria end |
#horizontal_alignment ⇒ String
The horizontal alignment of title in the slicer. If unspecified, defaults to
LEFT
Corresponds to the JSON property horizontalAlignment
9482 9483 9484 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9482 def horizontal_alignment @horizontal_alignment end |
#text_format ⇒ Google::Apis::SheetsV4::TextFormat
The format of a run of text in a cell. Absent values indicate that the field
isn't specified.
Corresponds to the JSON property textFormat
9488 9489 9490 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9488 def text_format @text_format end |
#title ⇒ String
The title of the slicer.
Corresponds to the JSON property title
9493 9494 9495 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9493 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9500 9501 9502 9503 9504 9505 9506 9507 9508 9509 9510 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9500 def update!(**args) @apply_to_pivot_tables = args[:apply_to_pivot_tables] if args.key?(:apply_to_pivot_tables) @background_color = args[:background_color] if args.key?(:background_color) @background_color_style = args[:background_color_style] if args.key?(:background_color_style) @column_index = args[:column_index] if args.key?(:column_index) @data_range = args[:data_range] if args.key?(:data_range) @filter_criteria = args[:filter_criteria] if args.key?(:filter_criteria) @horizontal_alignment = args[:horizontal_alignment] if args.key?(:horizontal_alignment) @text_format = args[:text_format] if args.key?(:text_format) @title = args[:title] if args.key?(:title) end |