Class: Google::Apis::SheetsV4::SortRangeRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::SortRangeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Sorts data in rows based on a sort order per column.
Instance Attribute Summary collapse
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#sort_specs ⇒ Array<Google::Apis::SheetsV4::SortSpec>
The sort order per column.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SortRangeRequest
constructor
A new instance of SortRangeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SortRangeRequest
Returns a new instance of SortRangeRequest.
9540 9541 9542 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property range
9532 9533 9534 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9532 def range @range end |
#sort_specs ⇒ Array<Google::Apis::SheetsV4::SortSpec>
The sort order per column. Later specifications are used when values are equal
in the earlier specifications.
Corresponds to the JSON property sortSpecs
9538 9539 9540 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9538 def sort_specs @sort_specs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9545 9546 9547 9548 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9545 def update!(**args) @range = args[:range] if args.key?(:range) @sort_specs = args[:sort_specs] if args.key?(:sort_specs) end |