Class: Google::Apis::SheetsV4::SourceAndDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A combination of a source range and how to extend that source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceAndDestination



9727
9728
9729
# File 'lib/google/apis/sheets_v4/classes.rb', line 9727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionString

The dimension that data should be filled into. Corresponds to the JSON property dimension



9701
9702
9703
# File 'lib/google/apis/sheets_v4/classes.rb', line 9701

def dimension
  @dimension
end

#fill_lengthFixnum

The number of rows or columns that data should be filled into. Positive numbers expand beyond the last row or last column of the source. Negative numbers expand before the first row or first column of the source. Corresponds to the JSON property fillLength



9708
9709
9710
# File 'lib/google/apis/sheets_v4/classes.rb', line 9708

def fill_length
  @fill_length
end

#sourceGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, i.e. the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id: 123456, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id: 123456 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property source



9725
9726
9727
# File 'lib/google/apis/sheets_v4/classes.rb', line 9725

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9732
9733
9734
9735
9736
# File 'lib/google/apis/sheets_v4/classes.rb', line 9732

def update!(**args)
  @dimension = args[:dimension] if args.key?(:dimension)
  @fill_length = args[:fill_length] if args.key?(:fill_length)
  @source = args[:source] if args.key?(:source)
end