Class: Google::Apis::SheetsV4::SpreadsheetProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Properties of a spreadsheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpreadsheetProperties

Returns a new instance of SpreadsheetProperties.



9855
9856
9857
# File 'lib/google/apis/sheets_v4/classes.rb', line 9855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_recalcString

The amount of time to wait before volatile functions are recalculated. Corresponds to the JSON property autoRecalc

Returns:

  • (String)


9807
9808
9809
# File 'lib/google/apis/sheets_v4/classes.rb', line 9807

def auto_recalc
  @auto_recalc
end

#default_formatGoogle::Apis::SheetsV4::CellFormat

The format of a cell. Corresponds to the JSON property defaultFormat



9812
9813
9814
# File 'lib/google/apis/sheets_v4/classes.rb', line 9812

def default_format
  @default_format
end

#import_functions_external_url_access_allowedBoolean Also known as: import_functions_external_url_access_allowed?

Whether to allow external URL access for image and import functions. Read only when true. When false, you can set to true. This value will be bypassed and always return true if the admin has enabled the allowlisting feature. Corresponds to the JSON property importFunctionsExternalUrlAccessAllowed

Returns:

  • (Boolean)


9820
9821
9822
# File 'lib/google/apis/sheets_v4/classes.rb', line 9820

def import_functions_external_url_access_allowed
  @import_functions_external_url_access_allowed
end

#iterative_calculation_settingsGoogle::Apis::SheetsV4::IterativeCalculationSettings

Settings to control how circular dependencies are resolved with iterative calculation. Corresponds to the JSON property iterativeCalculationSettings



9827
9828
9829
# File 'lib/google/apis/sheets_v4/classes.rb', line 9827

def iterative_calculation_settings
  @iterative_calculation_settings
end

#localeString

The locale of the spreadsheet in one of the following formats: * an ISO 639-1 language code such as en * an ISO 639-2 language code such as fil, if no 639-1 code exists * a combination of the ISO language code and country code, such as en_US Note: when updating this field, not all locales/languages are supported. Corresponds to the JSON property locale

Returns:

  • (String)


9836
9837
9838
# File 'lib/google/apis/sheets_v4/classes.rb', line 9836

def locale
  @locale
end

#spreadsheet_themeGoogle::Apis::SheetsV4::SpreadsheetTheme

Represents spreadsheet theme Corresponds to the JSON property spreadsheetTheme



9841
9842
9843
# File 'lib/google/apis/sheets_v4/classes.rb', line 9841

def spreadsheet_theme
  @spreadsheet_theme
end

#time_zoneString

The time zone of the spreadsheet, in CLDR format such as America/New_York. If the time zone isn't recognized, this may be a custom time zone such as GMT- 07:00. Corresponds to the JSON property timeZone

Returns:

  • (String)


9848
9849
9850
# File 'lib/google/apis/sheets_v4/classes.rb', line 9848

def time_zone
  @time_zone
end

#titleString

The title of the spreadsheet. Corresponds to the JSON property title

Returns:

  • (String)


9853
9854
9855
# File 'lib/google/apis/sheets_v4/classes.rb', line 9853

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
# File 'lib/google/apis/sheets_v4/classes.rb', line 9860

def update!(**args)
  @auto_recalc = args[:auto_recalc] if args.key?(:auto_recalc)
  @default_format = args[:default_format] if args.key?(:default_format)
  @import_functions_external_url_access_allowed = args[:import_functions_external_url_access_allowed] if args.key?(:import_functions_external_url_access_allowed)
  @iterative_calculation_settings = args[:iterative_calculation_settings] if args.key?(:iterative_calculation_settings)
  @locale = args[:locale] if args.key?(:locale)
  @spreadsheet_theme = args[:spreadsheet_theme] if args.key?(:spreadsheet_theme)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @title = args[:title] if args.key?(:title)
end