Class: Google::Apis::SheetsV4::Table

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Table

Returns a new instance of Table.



9939
9940
9941
# File 'lib/google/apis/sheets_v4/classes.rb', line 9939

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_propertiesArray<Google::Apis::SheetsV4::TableColumnProperties>

The table column properties. Corresponds to the JSON property columnProperties



9905
9906
9907
# File 'lib/google/apis/sheets_v4/classes.rb', line 9905

def column_properties
  @column_properties
end

#nameString

The table name. This is unique to all tables in the same spreadsheet. Corresponds to the JSON property name

Returns:

  • (String)


9910
9911
9912
# File 'lib/google/apis/sheets_v4/classes.rb', line 9910

def name
  @name
end

#rangeGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, i.e. the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id: 123456, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id: 123456 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property range



9927
9928
9929
# File 'lib/google/apis/sheets_v4/classes.rb', line 9927

def range
  @range
end

#rows_propertiesGoogle::Apis::SheetsV4::TableRowsProperties

The table row properties. Corresponds to the JSON property rowsProperties



9932
9933
9934
# File 'lib/google/apis/sheets_v4/classes.rb', line 9932

def rows_properties
  @rows_properties
end

#table_idString

The id of the table. Corresponds to the JSON property tableId

Returns:

  • (String)


9937
9938
9939
# File 'lib/google/apis/sheets_v4/classes.rb', line 9937

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9944
9945
9946
9947
9948
9949
9950
# File 'lib/google/apis/sheets_v4/classes.rb', line 9944

def update!(**args)
  @column_properties = args[:column_properties] if args.key?(:column_properties)
  @name = args[:name] if args.key?(:name)
  @range = args[:range] if args.key?(:range)
  @rows_properties = args[:rows_properties] if args.key?(:rows_properties)
  @table_id = args[:table_id] if args.key?(:table_id)
end