Class: Google::Apis::SheetsV4::TableColumnDataValidationRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A data validation rule for a column in a table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableColumnDataValidationRule

Returns a new instance of TableColumnDataValidationRule.



9963
9964
9965
# File 'lib/google/apis/sheets_v4/classes.rb', line 9963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionGoogle::Apis::SheetsV4::BooleanCondition

A condition that can evaluate to true or false. BooleanConditions are used by conditional formatting, data validation, and the criteria in filters. Corresponds to the JSON property condition



9961
9962
9963
# File 'lib/google/apis/sheets_v4/classes.rb', line 9961

def condition
  @condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9968
9969
9970
# File 'lib/google/apis/sheets_v4/classes.rb', line 9968

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
end