Class: Google::Apis::SheetsV4::TableColumnProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The table column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableColumnProperties

Returns a new instance of TableColumnProperties.



9998
9999
10000
# File 'lib/google/apis/sheets_v4/classes.rb', line 9998

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_indexFixnum

The 0-based column index. This index is relative to its position in the table and is not necessarily the same as the column index in the sheet. Corresponds to the JSON property columnIndex

Returns:

  • (Fixnum)


9981
9982
9983
# File 'lib/google/apis/sheets_v4/classes.rb', line 9981

def column_index
  @column_index
end

#column_nameString

The column name. Corresponds to the JSON property columnName

Returns:

  • (String)


9986
9987
9988
# File 'lib/google/apis/sheets_v4/classes.rb', line 9986

def column_name
  @column_name
end

#column_typeString

The column type. Corresponds to the JSON property columnType

Returns:

  • (String)


9991
9992
9993
# File 'lib/google/apis/sheets_v4/classes.rb', line 9991

def column_type
  @column_type
end

#data_validation_ruleGoogle::Apis::SheetsV4::TableColumnDataValidationRule

A data validation rule for a column in a table. Corresponds to the JSON property dataValidationRule



9996
9997
9998
# File 'lib/google/apis/sheets_v4/classes.rb', line 9996

def data_validation_rule
  @data_validation_rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10003
10004
10005
10006
10007
10008
# File 'lib/google/apis/sheets_v4/classes.rb', line 10003

def update!(**args)
  @column_index = args[:column_index] if args.key?(:column_index)
  @column_name = args[:column_name] if args.key?(:column_name)
  @column_type = args[:column_type] if args.key?(:column_type)
  @data_validation_rule = args[:data_validation_rule] if args.key?(:data_validation_rule)
end