Class: Google::Apis::SheetsV4::TextFormatRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A run of a text format. The format of this run continues until the start index of the next run. When updating, all fields must be set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TextFormatRun



10180
10181
10182
# File 'lib/google/apis/sheets_v4/classes.rb', line 10180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#formatGoogle::Apis::SheetsV4::TextFormat

The format of a run of text in a cell. Absent values indicate that the field isn't specified. Corresponds to the JSON property format



10173
10174
10175
# File 'lib/google/apis/sheets_v4/classes.rb', line 10173

def format
  @format
end

#start_indexFixnum

The zero-based character index where this run starts, in UTF-16 code units. Corresponds to the JSON property startIndex



10178
10179
10180
# File 'lib/google/apis/sheets_v4/classes.rb', line 10178

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10185
10186
10187
10188
# File 'lib/google/apis/sheets_v4/classes.rb', line 10185

def update!(**args)
  @format = args[:format] if args.key?(:format)
  @start_index = args[:start_index] if args.key?(:start_index)
end