Class: Google::Apis::SheetsV4::TextToColumnsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::TextToColumnsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Splits a column of text into multiple columns, based on a delimiter in each cell.
Instance Attribute Summary collapse
-
#delimiter ⇒ String
The delimiter to use.
-
#delimiter_type ⇒ String
The delimiter type to use.
-
#source ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TextToColumnsRequest
constructor
A new instance of TextToColumnsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TextToColumnsRequest
Returns a new instance of TextToColumnsRequest.
10274 10275 10276 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delimiter ⇒ String
The delimiter to use. Used only if delimiterType is CUSTOM.
Corresponds to the JSON property delimiter
10250 10251 10252 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10250 def delimiter @delimiter end |
#delimiter_type ⇒ String
The delimiter type to use.
Corresponds to the JSON property delimiterType
10255 10256 10257 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10255 def delimiter_type @delimiter_type end |
#source ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property source
10272 10273 10274 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10272 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10279 10280 10281 10282 10283 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10279 def update!(**args) @delimiter = args[:delimiter] if args.key?(:delimiter) @delimiter_type = args[:delimiter_type] if args.key?(:delimiter_type) @source = args[:source] if args.key?(:source) end |