Class: Google::Apis::SheetsV4::TreemapChartSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A Treemap chart.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TreemapChartSpec

Returns a new instance of TreemapChartSpec.



10718
10719
10720
# File 'lib/google/apis/sheets_v4/classes.rb', line 10718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#color_dataGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property colorData



10601
10602
10603
# File 'lib/google/apis/sheets_v4/classes.rb', line 10601

def color_data
  @color_data
end

#color_scaleGoogle::Apis::SheetsV4::TreemapChartColorScale

A color scale for a treemap chart. Corresponds to the JSON property colorScale



10606
10607
10608
# File 'lib/google/apis/sheets_v4/classes.rb', line 10606

def color_scale
  @color_scale
end

#header_colorGoogle::Apis::SheetsV4::Color

Represents a color in the RGBA color space. This representation is designed for simplicity of conversion to and from color representations in various languages over compactness. For example, the fields of this representation can be trivially provided to the constructor of java.awt.Color in Java; it can also be trivially provided to UIColor's +colorWithRed:green:blue:alpha method in iOS; and, with just a little work, it can be easily formatted into a CSS rgba() string in JavaScript. This reference page doesn't have information about the absolute color space that should be used to interpret the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default, applications should assume the sRGB color space. When color equality needs to be decided, implementations, unless documented otherwise, treat two colors as equal if all their red, green, blue, and alpha values each differ by at most 1e-5. Example (Java): import com.google.type.Color; // ... public static java. awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ? protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor. getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static Color toProto(java.awt.Color color) float red = (float) color.getRed(); float green = (float) color.getGreen(); float blue = (float) color.getBlue(); float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() . setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue / denominator); int alpha = color.getAlpha(); if (alpha != 255) result. setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) . build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // .. . static UIColor* fromProto(Color* protocolor) float red = [protocolor red]; float green = [protocolor green]; float blue = [protocolor blue]; FloatValue* alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper != nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green: green blue:blue alpha:alpha]; static Color* toProto(UIColor* color) CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:& blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [ result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha < = 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result autorelease]; return result; // ... Example (JavaScript): // ... var protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0; var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0; var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255); var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0. 0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ', ', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue) var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString = rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder. push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; / / ... Corresponds to the JSON property headerColor



10655
10656
10657
# File 'lib/google/apis/sheets_v4/classes.rb', line 10655

def header_color
  @header_color
end

#header_color_styleGoogle::Apis::SheetsV4::ColorStyle

A color value. Corresponds to the JSON property headerColorStyle



10660
10661
10662
# File 'lib/google/apis/sheets_v4/classes.rb', line 10660

def header_color_style
  @header_color_style
end

#hide_tooltipsBoolean Also known as: hide_tooltips?

True to hide tooltips. Corresponds to the JSON property hideTooltips

Returns:

  • (Boolean)


10665
10666
10667
# File 'lib/google/apis/sheets_v4/classes.rb', line 10665

def hide_tooltips
  @hide_tooltips
end

#hinted_levelsFixnum

The number of additional data levels beyond the labeled levels to be shown on the treemap chart. These levels are not interactive and are shown without their labels. Defaults to 0 if not specified. Corresponds to the JSON property hintedLevels

Returns:

  • (Fixnum)


10673
10674
10675
# File 'lib/google/apis/sheets_v4/classes.rb', line 10673

def hinted_levels
  @hinted_levels
end

#labelsGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property labels



10678
10679
10680
# File 'lib/google/apis/sheets_v4/classes.rb', line 10678

def labels
  @labels
end

#levelsFixnum

The number of data levels to show on the treemap chart. These levels are interactive and are shown with their labels. Defaults to 2 if not specified. Corresponds to the JSON property levels

Returns:

  • (Fixnum)


10684
10685
10686
# File 'lib/google/apis/sheets_v4/classes.rb', line 10684

def levels
  @levels
end

#max_valueFloat

The maximum possible data value. Cells with values greater than this will have the same color as cells with this value. If not specified, defaults to the actual maximum value from color_data, or the maximum value from size_data if color_data is not specified. Corresponds to the JSON property maxValue

Returns:

  • (Float)


10692
10693
10694
# File 'lib/google/apis/sheets_v4/classes.rb', line 10692

def max_value
  @max_value
end

#min_valueFloat

The minimum possible data value. Cells with values less than this will have the same color as cells with this value. If not specified, defaults to the actual minimum value from color_data, or the minimum value from size_data if color_data is not specified. Corresponds to the JSON property minValue

Returns:

  • (Float)


10700
10701
10702
# File 'lib/google/apis/sheets_v4/classes.rb', line 10700

def min_value
  @min_value
end

#parent_labelsGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property parentLabels



10705
10706
10707
# File 'lib/google/apis/sheets_v4/classes.rb', line 10705

def parent_labels
  @parent_labels
end

#size_dataGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property sizeData



10710
10711
10712
# File 'lib/google/apis/sheets_v4/classes.rb', line 10710

def size_data
  @size_data
end

#text_formatGoogle::Apis::SheetsV4::TextFormat

The format of a run of text in a cell. Absent values indicate that the field isn't specified. Corresponds to the JSON property textFormat



10716
10717
10718
# File 'lib/google/apis/sheets_v4/classes.rb', line 10716

def text_format
  @text_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
10733
10734
10735
10736
10737
# File 'lib/google/apis/sheets_v4/classes.rb', line 10723

def update!(**args)
  @color_data = args[:color_data] if args.key?(:color_data)
  @color_scale = args[:color_scale] if args.key?(:color_scale)
  @header_color = args[:header_color] if args.key?(:header_color)
  @header_color_style = args[:header_color_style] if args.key?(:header_color_style)
  @hide_tooltips = args[:hide_tooltips] if args.key?(:hide_tooltips)
  @hinted_levels = args[:hinted_levels] if args.key?(:hinted_levels)
  @labels = args[:labels] if args.key?(:labels)
  @levels = args[:levels] if args.key?(:levels)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
  @parent_labels = args[:parent_labels] if args.key?(:parent_labels)
  @size_data = args[:size_data] if args.key?(:size_data)
  @text_format = args[:text_format] if args.key?(:text_format)
end