Class: Google::Apis::SheetsV4::UnmergeCellsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::UnmergeCellsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Unmerges cells in the given range.
Instance Attribute Summary collapse
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnmergeCellsRequest
constructor
A new instance of UnmergeCellsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnmergeCellsRequest
Returns a new instance of UnmergeCellsRequest.
10816 10817 10818 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property range
10814 10815 10816 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10814 def range @range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10821 10822 10823 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10821 def update!(**args) @range = args[:range] if args.key?(:range) end |