Class: Google::Apis::SheetsV4::UpdateCellsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Updates all cells in a range with new data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateCellsRequest

Returns a new instance of UpdateCellsRequest.



10963
10964
10965
# File 'lib/google/apis/sheets_v4/classes.rb', line 10963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsString

The fields of CellData that should be updated. At least one field must be specified. The root is the CellData; 'row.values.' should not be specified. A single "*" can be used as short-hand for listing every field. Corresponds to the JSON property fields

Returns:

  • (String)


10934
10935
10936
# File 'lib/google/apis/sheets_v4/classes.rb', line 10934

def fields
  @fields
end

#rangeGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, i.e. the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id: 123456, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id: 123456 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property range



10951
10952
10953
# File 'lib/google/apis/sheets_v4/classes.rb', line 10951

def range
  @range
end

#rowsArray<Google::Apis::SheetsV4::RowData>

The data to write. Corresponds to the JSON property rows



10956
10957
10958
# File 'lib/google/apis/sheets_v4/classes.rb', line 10956

def rows
  @rows
end

#startGoogle::Apis::SheetsV4::GridCoordinate

A coordinate in a sheet. All indexes are zero-based. Corresponds to the JSON property start



10961
10962
10963
# File 'lib/google/apis/sheets_v4/classes.rb', line 10961

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10968
10969
10970
10971
10972
10973
# File 'lib/google/apis/sheets_v4/classes.rb', line 10968

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
  @range = args[:range] if args.key?(:range)
  @rows = args[:rows] if args.key?(:rows)
  @start = args[:start] if args.key?(:start)
end