Class: Google::Apis::SheetsV4::UpdateDimensionPropertiesRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::UpdateDimensionPropertiesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Updates properties of dimensions within the specified range.
Instance Attribute Summary collapse
-
#data_source_sheet_range ⇒ Google::Apis::SheetsV4::DataSourceSheetDimensionRange
A range along a single dimension on a DATA_SOURCE sheet.
-
#fields ⇒ String
The fields that should be updated.
-
#properties ⇒ Google::Apis::SheetsV4::DimensionProperties
Properties about a dimension.
-
#range ⇒ Google::Apis::SheetsV4::DimensionRange
A range along a single dimension on a sheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateDimensionPropertiesRequest
constructor
A new instance of UpdateDimensionPropertiesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateDimensionPropertiesRequest
Returns a new instance of UpdateDimensionPropertiesRequest.
11263 11264 11265 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 11263 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_source_sheet_range ⇒ Google::Apis::SheetsV4::DataSourceSheetDimensionRange
A range along a single dimension on a DATA_SOURCE sheet.
Corresponds to the JSON property dataSourceSheetRange
11242 11243 11244 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 11242 def data_source_sheet_range @data_source_sheet_range end |
#fields ⇒ String
The fields that should be updated. At least one field must be specified. The
root properties is implied and should not be specified. A single "*" can
be used as short-hand for listing every field.
Corresponds to the JSON property fields
11249 11250 11251 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 11249 def fields @fields end |
#properties ⇒ Google::Apis::SheetsV4::DimensionProperties
Properties about a dimension.
Corresponds to the JSON property properties
11254 11255 11256 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 11254 def properties @properties end |
#range ⇒ Google::Apis::SheetsV4::DimensionRange
A range along a single dimension on a sheet. All indexes are zero-based.
Indexes are half open: the start index is inclusive and the end index is
exclusive. Missing indexes indicate the range is unbounded on that side.
Corresponds to the JSON property range
11261 11262 11263 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 11261 def range @range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11268 11269 11270 11271 11272 11273 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 11268 def update!(**args) @data_source_sheet_range = args[:data_source_sheet_range] if args.key?(:data_source_sheet_range) @fields = args[:fields] if args.key?(:fields) @properties = args[:properties] if args.key?(:properties) @range = args[:range] if args.key?(:range) end |