Class: Google::Apis::SheetsV4::UpdateValuesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

The response when updating a range of values in a spreadsheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateValuesResponse

Returns a new instance of UpdateValuesResponse.



11647
11648
11649
# File 'lib/google/apis/sheets_v4/classes.rb', line 11647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spreadsheet_idString

The spreadsheet the updates were applied to. Corresponds to the JSON property spreadsheetId

Returns:



11620
11621
11622
# File 'lib/google/apis/sheets_v4/classes.rb', line 11620

def spreadsheet_id
  @spreadsheet_id
end

#updated_cellsFixnum

The number of cells updated. Corresponds to the JSON property updatedCells

Returns:



11625
11626
11627
# File 'lib/google/apis/sheets_v4/classes.rb', line 11625

def updated_cells
  @updated_cells
end

#updated_columnsFixnum

The number of columns where at least one cell in the column was updated. Corresponds to the JSON property updatedColumns

Returns:



11630
11631
11632
# File 'lib/google/apis/sheets_v4/classes.rb', line 11630

def updated_columns
  @updated_columns
end

#updated_dataGoogle::Apis::SheetsV4::ValueRange

Data within a range of the spreadsheet. Corresponds to the JSON property updatedData

Returns:



11635
11636
11637
# File 'lib/google/apis/sheets_v4/classes.rb', line 11635

def updated_data
  @updated_data
end

#updated_rangeString

The range (in A1 notation) that updates were applied to. Corresponds to the JSON property updatedRange

Returns:



11640
11641
11642
# File 'lib/google/apis/sheets_v4/classes.rb', line 11640

def updated_range
  @updated_range
end

#updated_rowsFixnum

The number of rows where at least one cell in the row was updated. Corresponds to the JSON property updatedRows

Returns:



11645
11646
11647
# File 'lib/google/apis/sheets_v4/classes.rb', line 11645

def updated_rows
  @updated_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11652
11653
11654
11655
11656
11657
11658
11659
# File 'lib/google/apis/sheets_v4/classes.rb', line 11652

def update!(**args)
  @spreadsheet_id = args[:spreadsheet_id] if args.key?(:spreadsheet_id)
  @updated_cells = args[:updated_cells] if args.key?(:updated_cells)
  @updated_columns = args[:updated_columns] if args.key?(:updated_columns)
  @updated_data = args[:updated_data] if args.key?(:updated_data)
  @updated_range = args[:updated_range] if args.key?(:updated_range)
  @updated_rows = args[:updated_rows] if args.key?(:updated_rows)
end