Class: Google::Apis::SheetsV4::ValueRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

Data within a range of the spreadsheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValueRange

Returns a new instance of ValueRange.



11696
11697
11698
# File 'lib/google/apis/sheets_v4/classes.rb', line 11696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#major_dimensionString

The major dimension of the values. For output, if the spreadsheet data is: A1= 1,B1=2,A2=3,B2=4, then requesting range=A1:B2,majorDimension=ROWS will return [[1,2],[3,4]], whereas requesting range=A1:B2,majorDimension=COLUMNS will return [[1,3],[2,4]]. For input, with range=A1:B2,majorDimension=ROWS then [[1,2],[3,4]] will set A1=1,B1=2,A2=3,B2=4. With range=A1:B2, majorDimension=COLUMNS then [[1,2],[3,4]] will set A1=1,B1=3,A2=2,B2=4. When writing, if this field is not set, it defaults to ROWS. Corresponds to the JSON property majorDimension

Returns:

  • (String)


11675
11676
11677
# File 'lib/google/apis/sheets_v4/classes.rb', line 11675

def major_dimension
  @major_dimension
end

#rangeString

The range the values cover, in A1 notation. For output, this range indicates the entire requested range, even though the values will exclude trailing rows and columns. When appending values, this field represents the range to search for a table, after which values will be appended. Corresponds to the JSON property range

Returns:

  • (String)


11684
11685
11686
# File 'lib/google/apis/sheets_v4/classes.rb', line 11684

def range
  @range
end

#valuesArray<Array<Object>>

The data that was read or to be written. This is an array of arrays, the outer array representing all the data and each inner array representing a major dimension. Each item in the inner array corresponds with one cell. For output, empty trailing rows and columns will not be included. For input, supported value types are: bool, string, and double. Null values will be skipped. To set a cell to an empty value, set the string value to an empty string. Corresponds to the JSON property values

Returns:

  • (Array<Array<Object>>)


11694
11695
11696
# File 'lib/google/apis/sheets_v4/classes.rb', line 11694

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11701
11702
11703
11704
11705
# File 'lib/google/apis/sheets_v4/classes.rb', line 11701

def update!(**args)
  @major_dimension = args[:major_dimension] if args.key?(:major_dimension)
  @range = args[:range] if args.key?(:range)
  @values = args[:values] if args.key?(:values)
end