Class: Google::Apis::SheetsV4::WaterfallChartCustomSubtotal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A custom subtotal column for a waterfall chart series.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WaterfallChartCustomSubtotal

Returns a new instance of WaterfallChartCustomSubtotal.



11810
11811
11812
# File 'lib/google/apis/sheets_v4/classes.rb', line 11810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_is_subtotalBoolean Also known as: data_is_subtotal?

True if the data point at subtotal_index is the subtotal. If false, the subtotal will be computed and appear after the data point. Corresponds to the JSON property dataIsSubtotal

Returns:

  • (Boolean)


11791
11792
11793
# File 'lib/google/apis/sheets_v4/classes.rb', line 11791

def data_is_subtotal
  @data_is_subtotal
end

#labelString

A label for the subtotal column. Corresponds to the JSON property label

Returns:

  • (String)


11797
11798
11799
# File 'lib/google/apis/sheets_v4/classes.rb', line 11797

def label
  @label
end

#subtotal_indexFixnum

The zero-based index of a data point within the series. If data_is_subtotal is true, the data point at this index is the subtotal. Otherwise, the subtotal appears after the data point with this index. A series can have multiple subtotals at arbitrary indices, but subtotals do not affect the indices of the data points. For example, if a series has three data points, their indices will always be 0, 1, and 2, regardless of how many subtotals exist on the series or what data points they are associated with. Corresponds to the JSON property subtotalIndex

Returns:

  • (Fixnum)


11808
11809
11810
# File 'lib/google/apis/sheets_v4/classes.rb', line 11808

def subtotal_index
  @subtotal_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11815
11816
11817
11818
11819
# File 'lib/google/apis/sheets_v4/classes.rb', line 11815

def update!(**args)
  @data_is_subtotal = args[:data_is_subtotal] if args.key?(:data_is_subtotal)
  @label = args[:label] if args.key?(:label)
  @subtotal_index = args[:subtotal_index] if args.key?(:subtotal_index)
end