Class: Google::Apis::SheetsV4::WaterfallChartSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb

Overview

A single series of data for a waterfall chart.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WaterfallChartSeries

Returns a new instance of WaterfallChartSeries.



11895
11896
11897
# File 'lib/google/apis/sheets_v4/classes.rb', line 11895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_subtotalsArray<Google::Apis::SheetsV4::WaterfallChartCustomSubtotal>

Custom subtotal columns appearing in this series. The order in which subtotals are defined is not significant. Only one subtotal may be defined for each data point. Corresponds to the JSON property customSubtotals



11857
11858
11859
# File 'lib/google/apis/sheets_v4/classes.rb', line 11857

def custom_subtotals
  @custom_subtotals
end

#dataGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property data



11862
11863
11864
# File 'lib/google/apis/sheets_v4/classes.rb', line 11862

def data
  @data
end

#data_labelGoogle::Apis::SheetsV4::DataLabel

Settings for one set of data labels. Data labels are annotations that appear next to a set of data, such as the points on a line chart, and provide additional information about what the data represents, such as a text representation of the value behind that point on the graph. Corresponds to the JSON property dataLabel



11870
11871
11872
# File 'lib/google/apis/sheets_v4/classes.rb', line 11870

def data_label
  @data_label
end

#hide_trailing_subtotalBoolean Also known as: hide_trailing_subtotal?

True to hide the subtotal column from the end of the series. By default, a subtotal column will appear at the end of each series. Setting this field to true will hide that subtotal column for this series. Corresponds to the JSON property hideTrailingSubtotal

Returns:

  • (Boolean)


11877
11878
11879
# File 'lib/google/apis/sheets_v4/classes.rb', line 11877

def hide_trailing_subtotal
  @hide_trailing_subtotal
end

#negative_columns_styleGoogle::Apis::SheetsV4::WaterfallChartColumnStyle

Styles for a waterfall chart column. Corresponds to the JSON property negativeColumnsStyle



11883
11884
11885
# File 'lib/google/apis/sheets_v4/classes.rb', line 11883

def negative_columns_style
  @negative_columns_style
end

#positive_columns_styleGoogle::Apis::SheetsV4::WaterfallChartColumnStyle

Styles for a waterfall chart column. Corresponds to the JSON property positiveColumnsStyle



11888
11889
11890
# File 'lib/google/apis/sheets_v4/classes.rb', line 11888

def positive_columns_style
  @positive_columns_style
end

#subtotal_columns_styleGoogle::Apis::SheetsV4::WaterfallChartColumnStyle

Styles for a waterfall chart column. Corresponds to the JSON property subtotalColumnsStyle



11893
11894
11895
# File 'lib/google/apis/sheets_v4/classes.rb', line 11893

def subtotal_columns_style
  @subtotal_columns_style
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11900
11901
11902
11903
11904
11905
11906
11907
11908
# File 'lib/google/apis/sheets_v4/classes.rb', line 11900

def update!(**args)
  @custom_subtotals = args[:custom_subtotals] if args.key?(:custom_subtotals)
  @data = args[:data] if args.key?(:data)
  @data_label = args[:data_label] if args.key?(:data_label)
  @hide_trailing_subtotal = args[:hide_trailing_subtotal] if args.key?(:hide_trailing_subtotal)
  @negative_columns_style = args[:negative_columns_style] if args.key?(:negative_columns_style)
  @positive_columns_style = args[:positive_columns_style] if args.key?(:positive_columns_style)
  @subtotal_columns_style = args[:subtotal_columns_style] if args.key?(:subtotal_columns_style)
end