Class: Google::Apis::SheetsV4::BaselineValueFormat
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BaselineValueFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Formatting options for baseline value.
Instance Attribute Summary collapse
-
#comparison_type ⇒ String
The comparison type of key value with baseline value.
-
#description ⇒ String
Description which is appended after the baseline value.
-
#negative_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space.
-
#negative_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
-
#position ⇒ Google::Apis::SheetsV4::TextPosition
Position settings for text.
-
#positive_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space.
-
#positive_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
-
#text_format ⇒ Google::Apis::SheetsV4::TextFormat
The format of a run of text in a cell.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BaselineValueFormat
constructor
A new instance of BaselineValueFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BaselineValueFormat
Returns a new instance of BaselineValueFormat.
1097 1098 1099 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comparison_type ⇒ String
The comparison type of key value with baseline value.
Corresponds to the JSON property comparisonType
971 972 973 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 971 def comparison_type @comparison_type end |
#description ⇒ String
Description which is appended after the baseline value. This field is optional.
Corresponds to the JSON property description
976 977 978 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 976 def description @description end |
#negative_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property negativeColor
1025 1026 1027 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1025 def negative_color @negative_color end |
#negative_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
Corresponds to the JSON property negativeColorStyle
1030 1031 1032 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1030 def negative_color_style @negative_color_style end |
#position ⇒ Google::Apis::SheetsV4::TextPosition
Position settings for text.
Corresponds to the JSON property position
1035 1036 1037 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1035 def position @position end |
#positive_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property positiveColor
1084 1085 1086 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1084 def positive_color @positive_color end |
#positive_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
Corresponds to the JSON property positiveColorStyle
1089 1090 1091 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1089 def positive_color_style @positive_color_style end |
#text_format ⇒ Google::Apis::SheetsV4::TextFormat
The format of a run of text in a cell. Absent values indicate that the field
isn't specified.
Corresponds to the JSON property textFormat
1095 1096 1097 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1095 def text_format @text_format end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1102 def update!(**args) @comparison_type = args[:comparison_type] if args.key?(:comparison_type) @description = args[:description] if args.key?(:description) @negative_color = args[:negative_color] if args.key?(:negative_color) @negative_color_style = args[:negative_color_style] if args.key?(:negative_color_style) @position = args[:position] if args.key?(:position) @positive_color = args[:positive_color] if args.key?(:positive_color) @positive_color_style = args[:positive_color_style] if args.key?(:positive_color_style) @text_format = args[:text_format] if args.key?(:text_format) end |