Class: Google::Apis::SheetsV4::BasicFilter
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BasicFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The default filter associated with a sheet. For more information, see Manage data visibility with filters.
Instance Attribute Summary collapse
-
#criteria ⇒ Hash<String,Google::Apis::SheetsV4::FilterCriteria>
The criteria for showing/hiding values per column.
-
#filter_specs ⇒ Array<Google::Apis::SheetsV4::FilterSpec>
The filter criteria per column.
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#sort_specs ⇒ Array<Google::Apis::SheetsV4::SortSpec>
The sort order per column.
-
#table_id ⇒ String
The table this filter is backed by, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BasicFilter
constructor
A new instance of BasicFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BasicFilter
Returns a new instance of BasicFilter.
1459 1460 1461 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#criteria ⇒ Hash<String,Google::Apis::SheetsV4::FilterCriteria>
The criteria for showing/hiding values per column. The map's key is the column
index, and the value is the criteria for that column. This field is deprecated
in favor of filter_specs.
Corresponds to the JSON property criteria
1421 1422 1423 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1421 def criteria @criteria end |
#filter_specs ⇒ Array<Google::Apis::SheetsV4::FilterSpec>
The filter criteria per column. Both criteria and filter_specs are populated
in responses. If both fields are specified in an update request, this field
takes precedence.
Corresponds to the JSON property filterSpecs
1428 1429 1430 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1428 def filter_specs @filter_specs end |
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property range
1445 1446 1447 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1445 def range @range end |
#sort_specs ⇒ Array<Google::Apis::SheetsV4::SortSpec>
The sort order per column. Later specifications are used when values are equal
in the earlier specifications.
Corresponds to the JSON property sortSpecs
1451 1452 1453 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1451 def sort_specs @sort_specs end |
#table_id ⇒ String
The table this filter is backed by, if any. When writing, only one of range or
table_id may be set.
Corresponds to the JSON property tableId
1457 1458 1459 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1457 def table_id @table_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1464 1465 1466 1467 1468 1469 1470 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1464 def update!(**args) @criteria = args[:criteria] if args.key?(:criteria) @filter_specs = args[:filter_specs] if args.key?(:filter_specs) @range = args[:range] if args.key?(:range) @sort_specs = args[:sort_specs] if args.key?(:sort_specs) @table_id = args[:table_id] if args.key?(:table_id) end |