Class: Google::Apis::SheetsV4::BatchUpdateSpreadsheetRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BatchUpdateSpreadsheetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The request for updating any aspect of a spreadsheet.
Instance Attribute Summary collapse
-
#include_spreadsheet_in_response ⇒ Boolean
(also: #include_spreadsheet_in_response?)
Determines if the update response should include the spreadsheet resource.
-
#requests ⇒ Array<Google::Apis::SheetsV4::Request>
A list of updates to apply to the spreadsheet.
-
#response_include_grid_data ⇒ Boolean
(also: #response_include_grid_data?)
True if grid data should be returned.
-
#response_ranges ⇒ Array<String>
Limits the ranges included in the response spreadsheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchUpdateSpreadsheetRequest
constructor
A new instance of BatchUpdateSpreadsheetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchUpdateSpreadsheetRequest
Returns a new instance of BatchUpdateSpreadsheetRequest.
1778 1779 1780 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#include_spreadsheet_in_response ⇒ Boolean Also known as: include_spreadsheet_in_response?
Determines if the update response should include the spreadsheet resource.
Corresponds to the JSON property includeSpreadsheetInResponse
1754 1755 1756 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1754 def include_spreadsheet_in_response @include_spreadsheet_in_response end |
#requests ⇒ Array<Google::Apis::SheetsV4::Request>
A list of updates to apply to the spreadsheet. Requests will be applied in the
order they are specified. If any request is not valid, no requests will be
applied.
Corresponds to the JSON property requests
1762 1763 1764 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1762 def requests @requests end |
#response_include_grid_data ⇒ Boolean Also known as: response_include_grid_data?
True if grid data should be returned. Meaningful only if
include_spreadsheet_in_response is 'true'. This parameter is ignored if a
field mask was set in the request.
Corresponds to the JSON property responseIncludeGridData
1769 1770 1771 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1769 def response_include_grid_data @response_include_grid_data end |
#response_ranges ⇒ Array<String>
Limits the ranges included in the response spreadsheet. Meaningful only if
include_spreadsheet_in_response is 'true'.
Corresponds to the JSON property responseRanges
1776 1777 1778 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1776 def response_ranges @response_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1783 1784 1785 1786 1787 1788 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1783 def update!(**args) @include_spreadsheet_in_response = args[:include_spreadsheet_in_response] if args.key?(:include_spreadsheet_in_response) @requests = args[:requests] if args.key?(:requests) @response_include_grid_data = args[:response_include_grid_data] if args.key?(:response_include_grid_data) @response_ranges = args[:response_ranges] if args.key?(:response_ranges) end |