Class: Google::Apis::SheetsV4::BatchUpdateValuesByDataFilterResponse
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BatchUpdateValuesByDataFilterResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The response when updating a range of values in a spreadsheet.
Instance Attribute Summary collapse
-
#responses ⇒ Array<Google::Apis::SheetsV4::UpdateValuesByDataFilterResponse>
The response for each range updated.
-
#spreadsheet_id ⇒ String
The spreadsheet the updates were applied to.
-
#total_updated_cells ⇒ Fixnum
The total number of cells updated.
-
#total_updated_columns ⇒ Fixnum
The total number of columns where at least one cell in the column was updated.
-
#total_updated_rows ⇒ Fixnum
The total number of rows where at least one cell in the row was updated.
-
#total_updated_sheets ⇒ Fixnum
The total number of sheets where at least one cell in the sheet was updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchUpdateValuesByDataFilterResponse
constructor
A new instance of BatchUpdateValuesByDataFilterResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchUpdateValuesByDataFilterResponse
Returns a new instance of BatchUpdateValuesByDataFilterResponse.
1911 1912 1913 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1911 def initialize(**args) update!(**args) end |
Instance Attribute Details
#responses ⇒ Array<Google::Apis::SheetsV4::UpdateValuesByDataFilterResponse>
The response for each range updated.
Corresponds to the JSON property responses
1884 1885 1886 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1884 def responses @responses end |
#spreadsheet_id ⇒ String
The spreadsheet the updates were applied to.
Corresponds to the JSON property spreadsheetId
1889 1890 1891 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1889 def spreadsheet_id @spreadsheet_id end |
#total_updated_cells ⇒ Fixnum
The total number of cells updated.
Corresponds to the JSON property totalUpdatedCells
1894 1895 1896 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1894 def total_updated_cells @total_updated_cells end |
#total_updated_columns ⇒ Fixnum
The total number of columns where at least one cell in the column was updated.
Corresponds to the JSON property totalUpdatedColumns
1899 1900 1901 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1899 def total_updated_columns @total_updated_columns end |
#total_updated_rows ⇒ Fixnum
The total number of rows where at least one cell in the row was updated.
Corresponds to the JSON property totalUpdatedRows
1904 1905 1906 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1904 def total_updated_rows @total_updated_rows end |
#total_updated_sheets ⇒ Fixnum
The total number of sheets where at least one cell in the sheet was updated.
Corresponds to the JSON property totalUpdatedSheets
1909 1910 1911 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1909 def total_updated_sheets @total_updated_sheets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 1916 def update!(**args) @responses = args[:responses] if args.key?(:responses) @spreadsheet_id = args[:spreadsheet_id] if args.key?(:spreadsheet_id) @total_updated_cells = args[:total_updated_cells] if args.key?(:total_updated_cells) @total_updated_columns = args[:total_updated_columns] if args.key?(:total_updated_columns) @total_updated_rows = args[:total_updated_rows] if args.key?(:total_updated_rows) @total_updated_sheets = args[:total_updated_sheets] if args.key?(:total_updated_sheets) end |