Class: Google::Apis::SheetsV4::BubbleChartSpec
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BubbleChartSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A bubble chart.
Instance Attribute Summary collapse
-
#bubble_border_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space.
-
#bubble_border_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
-
#bubble_labels ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
-
#bubble_max_radius_size ⇒ Fixnum
The max radius size of the bubbles, in pixels.
-
#bubble_min_radius_size ⇒ Fixnum
The minimum radius size of the bubbles, in pixels.
-
#bubble_opacity ⇒ Float
The opacity of the bubbles between 0 and 1.0.
-
#bubble_sizes ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
-
#bubble_text_style ⇒ Google::Apis::SheetsV4::TextFormat
The format of a run of text in a cell.
-
#domain ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
-
#group_ids ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
-
#legend_position ⇒ String
Where the legend of the chart should be drawn.
-
#series ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BubbleChartSpec
constructor
A new instance of BubbleChartSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BubbleChartSpec
Returns a new instance of BubbleChartSpec.
2399 2400 2401 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bubble_border_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property bubbleBorderColor
2338 2339 2340 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2338 def bubble_border_color @bubble_border_color end |
#bubble_border_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
Corresponds to the JSON property bubbleBorderColorStyle
2343 2344 2345 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2343 def bubble_border_color_style @bubble_border_color_style end |
#bubble_labels ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
Corresponds to the JSON property bubbleLabels
2348 2349 2350 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2348 def bubble_labels @bubble_labels end |
#bubble_max_radius_size ⇒ Fixnum
The max radius size of the bubbles, in pixels. If specified, the field must be
a positive value.
Corresponds to the JSON property bubbleMaxRadiusSize
2354 2355 2356 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2354 def bubble_max_radius_size @bubble_max_radius_size end |
#bubble_min_radius_size ⇒ Fixnum
The minimum radius size of the bubbles, in pixels. If specific, the field must
be a positive value.
Corresponds to the JSON property bubbleMinRadiusSize
2360 2361 2362 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2360 def bubble_min_radius_size @bubble_min_radius_size end |
#bubble_opacity ⇒ Float
The opacity of the bubbles between 0 and 1.0. 0 is fully transparent and 1 is
fully opaque.
Corresponds to the JSON property bubbleOpacity
2366 2367 2368 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2366 def bubble_opacity @bubble_opacity end |
#bubble_sizes ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
Corresponds to the JSON property bubbleSizes
2371 2372 2373 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2371 def bubble_sizes @bubble_sizes end |
#bubble_text_style ⇒ Google::Apis::SheetsV4::TextFormat
The format of a run of text in a cell. Absent values indicate that the field
isn't specified.
Corresponds to the JSON property bubbleTextStyle
2377 2378 2379 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2377 def bubble_text_style @bubble_text_style end |
#domain ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
Corresponds to the JSON property domain
2382 2383 2384 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2382 def domain @domain end |
#group_ids ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
Corresponds to the JSON property groupIds
2387 2388 2389 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2387 def group_ids @group_ids end |
#legend_position ⇒ String
Where the legend of the chart should be drawn.
Corresponds to the JSON property legendPosition
2392 2393 2394 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2392 def legend_position @legend_position end |
#series ⇒ Google::Apis::SheetsV4::ChartData
The data included in a domain or series.
Corresponds to the JSON property series
2397 2398 2399 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2397 def series @series end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2404 def update!(**args) @bubble_border_color = args[:bubble_border_color] if args.key?(:bubble_border_color) @bubble_border_color_style = args[:bubble_border_color_style] if args.key?(:bubble_border_color_style) @bubble_labels = args[:bubble_labels] if args.key?(:bubble_labels) @bubble_max_radius_size = args[:bubble_max_radius_size] if args.key?(:bubble_max_radius_size) @bubble_min_radius_size = args[:bubble_min_radius_size] if args.key?(:bubble_min_radius_size) @bubble_opacity = args[:bubble_opacity] if args.key?(:bubble_opacity) @bubble_sizes = args[:bubble_sizes] if args.key?(:bubble_sizes) @bubble_text_style = args[:bubble_text_style] if args.key?(:bubble_text_style) @domain = args[:domain] if args.key?(:domain) @group_ids = args[:group_ids] if args.key?(:group_ids) @legend_position = args[:legend_position] if args.key?(:legend_position) @series = args[:series] if args.key?(:series) end |