Class: Google::Apis::SheetsV4::CancelDataSourceRefreshResponse
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::CancelDataSourceRefreshResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The response from cancelling one or multiple data source object refreshes.
Instance Attribute Summary collapse
-
#statuses ⇒ Array<Google::Apis::SheetsV4::CancelDataSourceRefreshStatus>
The cancellation statuses of refreshes of all data source objects specified in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CancelDataSourceRefreshResponse
constructor
A new instance of CancelDataSourceRefreshResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CancelDataSourceRefreshResponse
Returns a new instance of CancelDataSourceRefreshResponse.
2469 2470 2471 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#statuses ⇒ Array<Google::Apis::SheetsV4::CancelDataSourceRefreshStatus>
The cancellation statuses of refreshes of all data source objects specified in
the request. If is_all is specified, the field contains only those in failure
status. Refreshing and canceling refresh the same data source object is also
not allowed in the same batchUpdate.
Corresponds to the JSON property statuses
2467 2468 2469 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2467 def statuses @statuses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2474 2475 2476 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2474 def update!(**args) @statuses = args[:statuses] if args.key?(:statuses) end |