Class: Google::Apis::SheetsV4::CellFormat
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::CellFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The format of a cell.
Instance Attribute Summary collapse
-
#background_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space.
-
#background_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
-
#borders ⇒ Google::Apis::SheetsV4::Borders
The borders of the cell.
-
#horizontal_alignment ⇒ String
The horizontal alignment of the value in the cell.
-
#hyperlink_display_type ⇒ String
If one exists, how a hyperlink should be displayed in the cell.
-
#number_format ⇒ Google::Apis::SheetsV4::NumberFormat
The number format of a cell.
-
#padding ⇒ Google::Apis::SheetsV4::Padding
The amount of padding around the cell, in pixels.
-
#text_direction ⇒ String
The direction of the text in the cell.
-
#text_format ⇒ Google::Apis::SheetsV4::TextFormat
The format of a run of text in a cell.
-
#text_rotation ⇒ Google::Apis::SheetsV4::TextRotation
The rotation applied to text in a cell.
-
#vertical_alignment ⇒ String
The vertical alignment of the value in the cell.
-
#wrap_strategy ⇒ String
The wrap strategy for the value in the cell.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CellFormat
constructor
A new instance of CellFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CellFormat
Returns a new instance of CellFormat.
2833 2834 2835 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property backgroundColor
2774 2775 2776 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2774 def background_color @background_color end |
#background_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
Corresponds to the JSON property backgroundColorStyle
2779 2780 2781 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2779 def background_color_style @background_color_style end |
#borders ⇒ Google::Apis::SheetsV4::Borders
The borders of the cell.
Corresponds to the JSON property borders
2784 2785 2786 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2784 def borders @borders end |
#horizontal_alignment ⇒ String
The horizontal alignment of the value in the cell.
Corresponds to the JSON property horizontalAlignment
2789 2790 2791 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2789 def horizontal_alignment @horizontal_alignment end |
#hyperlink_display_type ⇒ String
If one exists, how a hyperlink should be displayed in the cell.
Corresponds to the JSON property hyperlinkDisplayType
2794 2795 2796 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2794 def hyperlink_display_type @hyperlink_display_type end |
#number_format ⇒ Google::Apis::SheetsV4::NumberFormat
The number format of a cell.
Corresponds to the JSON property numberFormat
2799 2800 2801 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2799 def number_format @number_format end |
#padding ⇒ Google::Apis::SheetsV4::Padding
The amount of padding around the cell, in pixels. When updating padding, every
field must be specified.
Corresponds to the JSON property padding
2805 2806 2807 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2805 def padding @padding end |
#text_direction ⇒ String
The direction of the text in the cell.
Corresponds to the JSON property textDirection
2810 2811 2812 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2810 def text_direction @text_direction end |
#text_format ⇒ Google::Apis::SheetsV4::TextFormat
The format of a run of text in a cell. Absent values indicate that the field
isn't specified.
Corresponds to the JSON property textFormat
2816 2817 2818 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2816 def text_format @text_format end |
#text_rotation ⇒ Google::Apis::SheetsV4::TextRotation
The rotation applied to text in a cell.
Corresponds to the JSON property textRotation
2821 2822 2823 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2821 def text_rotation @text_rotation end |
#vertical_alignment ⇒ String
The vertical alignment of the value in the cell.
Corresponds to the JSON property verticalAlignment
2826 2827 2828 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2826 def vertical_alignment @vertical_alignment end |
#wrap_strategy ⇒ String
The wrap strategy for the value in the cell.
Corresponds to the JSON property wrapStrategy
2831 2832 2833 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2831 def wrap_strategy @wrap_strategy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 2838 def update!(**args) @background_color = args[:background_color] if args.key?(:background_color) @background_color_style = args[:background_color_style] if args.key?(:background_color_style) @borders = args[:borders] if args.key?(:borders) @horizontal_alignment = args[:horizontal_alignment] if args.key?(:horizontal_alignment) @hyperlink_display_type = args[:hyperlink_display_type] if args.key?(:hyperlink_display_type) @number_format = args[:number_format] if args.key?(:number_format) @padding = args[:padding] if args.key?(:padding) @text_direction = args[:text_direction] if args.key?(:text_direction) @text_format = args[:text_format] if args.key?(:text_format) @text_rotation = args[:text_rotation] if args.key?(:text_rotation) @vertical_alignment = args[:vertical_alignment] if args.key?(:vertical_alignment) @wrap_strategy = args[:wrap_strategy] if args.key?(:wrap_strategy) end |