Class: Google::Apis::SheetsV4::ChipRun
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::ChipRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The run of a chip. The chip continues until the start index of the next run.
Instance Attribute Summary collapse
-
#chip ⇒ Google::Apis::SheetsV4::Chip
The Smart Chip.
-
#start_index ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChipRun
constructor
A new instance of ChipRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChipRun
Returns a new instance of ChipRun.
3341 3342 3343 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chip ⇒ Google::Apis::SheetsV4::Chip
The Smart Chip.
Corresponds to the JSON property chip
3333 3334 3335 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3333 def chip @chip end |
#start_index ⇒ Fixnum
Required. The zero-based character index where this run starts, in UTF-16 code
units.
Corresponds to the JSON property startIndex
3339 3340 3341 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3339 def start_index @start_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3346 3347 3348 3349 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3346 def update!(**args) @chip = args[:chip] if args.key?(:chip) @start_index = args[:start_index] if args.key?(:start_index) end |