Class: Google::Apis::SheetsV4::CopyPasteRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::CopyPasteRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Copies data from the source to the destination.
Instance Attribute Summary collapse
-
#destination ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#paste_orientation ⇒ String
How that data should be oriented when pasting.
-
#paste_type ⇒ String
What kind of data to paste.
-
#source ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CopyPasteRequest
constructor
A new instance of CopyPasteRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CopyPasteRequest
Returns a new instance of CopyPasteRequest.
3679 3680 3681 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property destination
3650 3651 3652 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3650 def destination @destination end |
#paste_orientation ⇒ String
How that data should be oriented when pasting.
Corresponds to the JSON property pasteOrientation
3655 3656 3657 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3655 def paste_orientation @paste_orientation end |
#paste_type ⇒ String
What kind of data to paste.
Corresponds to the JSON property pasteType
3660 3661 3662 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3660 def paste_type @paste_type end |
#source ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property source
3677 3678 3679 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3677 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3684 3685 3686 3687 3688 3689 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3684 def update!(**args) @destination = args[:destination] if args.key?(:destination) @paste_orientation = args[:paste_orientation] if args.key?(:paste_orientation) @paste_type = args[:paste_type] if args.key?(:paste_type) @source = args[:source] if args.key?(:source) end |