Class: Google::Apis::SheetsV4::CreateDeveloperMetadataRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::CreateDeveloperMetadataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A request to create developer metadata.
Instance Attribute Summary collapse
-
#developer_metadata ⇒ Google::Apis::SheetsV4::DeveloperMetadata
Developer metadata associated with a location or object in a spreadsheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateDeveloperMetadataRequest
constructor
A new instance of CreateDeveloperMetadataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateDeveloperMetadataRequest
Returns a new instance of CreateDeveloperMetadataRequest.
3729 3730 3731 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3729 def initialize(**args) update!(**args) end |
Instance Attribute Details
#developer_metadata ⇒ Google::Apis::SheetsV4::DeveloperMetadata
Developer metadata associated with a location or object in a spreadsheet. For
more information, see Read, write, and search metadata. Developer metadata may be
used to associate arbitrary data with various parts of a spreadsheet and it
will remain associated at those locations as they move around and the
spreadsheet is edited. For example, if developer metadata is associated with
row 5 and another row is then subsequently inserted above row 5, that original
metadata is still associated with the row it was first associated with (what
is now row 6). If the associated object is deleted then its metadata is
deleted too.
Corresponds to the JSON property developerMetadata
3727 3728 3729 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3727 def @developer_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3734 3735 3736 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3734 def update!(**args) @developer_metadata = args[:developer_metadata] if args.key?(:developer_metadata) end |