Class: Google::Apis::SheetsV4::DataFilter
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::DataFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Filter that describes what data should be selected or returned from a request. For more information, see Read, write, and search metadata.
Instance Attribute Summary collapse
-
#a1_range ⇒ String
Selects data that matches the specified A1 range.
-
#developer_metadata_lookup ⇒ Google::Apis::SheetsV4::DeveloperMetadataLookup
Selects DeveloperMetadata that matches all of the specified fields.
-
#grid_range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataFilter
constructor
A new instance of DataFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataFilter
Returns a new instance of DataFilter.
3897 3898 3899 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3897 def initialize(**args) update!(**args) end |
Instance Attribute Details
#a1_range ⇒ String
Selects data that matches the specified A1 range.
Corresponds to the JSON property a1Range
3865 3866 3867 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3865 def a1_range @a1_range end |
#developer_metadata_lookup ⇒ Google::Apis::SheetsV4::DeveloperMetadataLookup
Selects DeveloperMetadata that matches all of the specified fields. For
example, if only a metadata ID is specified this considers the
DeveloperMetadata with that particular unique ID. If a metadata key is
specified, this considers all developer metadata with that key. If a key,
visibility, and location type are all specified, this considers all developer
metadata with that key and visibility that are associated with a location of
that type. In general, this selects all DeveloperMetadata that match the
intersection of all the specified fields; any field or combination of fields
may be specified.
Corresponds to the JSON property developerMetadataLookup
3878 3879 3880 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3878 def end |
#grid_range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property gridRange
3895 3896 3897 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3895 def grid_range @grid_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3902 3903 3904 3905 3906 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 3902 def update!(**args) @a1_range = args[:a1_range] if args.key?(:a1_range) = args[:developer_metadata_lookup] if args.key?(:developer_metadata_lookup) @grid_range = args[:grid_range] if args.key?(:grid_range) end |