Class: Google::Apis::SheetsV4::DataSourceRefreshDailySchedule
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::DataSourceRefreshDailySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A schedule for data to refresh every day in a given time interval.
Instance Attribute Summary collapse
-
#start_time ⇒ Google::Apis::SheetsV4::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSourceRefreshDailySchedule
constructor
A new instance of DataSourceRefreshDailySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSourceRefreshDailySchedule
Returns a new instance of DataSourceRefreshDailySchedule.
4257 4258 4259 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#start_time ⇒ Google::Apis::SheetsV4::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
4255 4256 4257 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4255 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4262 4263 4264 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4262 def update!(**args) @start_time = args[:start_time] if args.key?(:start_time) end |