Class: Google::Apis::SheetsV4::DataSourceRefreshMonthlySchedule
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::DataSourceRefreshMonthlySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A monthly schedule for data to refresh on specific days in the month in a given time interval.
Instance Attribute Summary collapse
-
#days_of_month ⇒ Array<Fixnum>
Days of the month to refresh.
-
#start_time ⇒ Google::Apis::SheetsV4::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSourceRefreshMonthlySchedule
constructor
A new instance of DataSourceRefreshMonthlySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSourceRefreshMonthlySchedule
Returns a new instance of DataSourceRefreshMonthlySchedule.
4285 4286 4287 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#days_of_month ⇒ Array<Fixnum>
Days of the month to refresh. Only 1-28 are supported, mapping to the 1st to
the 28th day. At least one day must be specified.
Corresponds to the JSON property daysOfMonth
4276 4277 4278 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4276 def days_of_month @days_of_month end |
#start_time ⇒ Google::Apis::SheetsV4::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
4283 4284 4285 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4283 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4290 4291 4292 4293 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 4290 def update!(**args) @days_of_month = args[:days_of_month] if args.key?(:days_of_month) @start_time = args[:start_time] if args.key?(:start_time) end |