Class: Google::Apis::SheetsV4::FilterView
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::FilterView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A filter view. For more information, see Manage data visibility with filters.
Instance Attribute Summary collapse
-
#criteria ⇒ Hash<String,Google::Apis::SheetsV4::FilterCriteria>
The criteria for showing/hiding values per column.
-
#filter_specs ⇒ Array<Google::Apis::SheetsV4::FilterSpec>
The filter criteria for showing or hiding values per column.
-
#filter_view_id ⇒ Fixnum
The ID of the filter view.
-
#named_range_id ⇒ String
The named range this filter view is backed by, if any.
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#sort_specs ⇒ Array<Google::Apis::SheetsV4::SortSpec>
The sort order per column.
-
#table_id ⇒ String
The table this filter view is backed by, if any.
-
#title ⇒ String
The name of the filter view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FilterView
constructor
A new instance of FilterView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FilterView
Returns a new instance of FilterView.
5904 5905 5906 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#criteria ⇒ Hash<String,Google::Apis::SheetsV4::FilterCriteria>
The criteria for showing/hiding values per column. The map's key is the column
index, and the value is the criteria for that column. This field is deprecated
in favor of filter_specs.
Corresponds to the JSON property criteria
5850 5851 5852 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5850 def criteria @criteria end |
#filter_specs ⇒ Array<Google::Apis::SheetsV4::FilterSpec>
The filter criteria for showing or hiding values per column. Both criteria and
filter_specs are populated in responses. If both fields are specified in an
update request, this field takes precedence.
Corresponds to the JSON property filterSpecs
5857 5858 5859 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5857 def filter_specs @filter_specs end |
#filter_view_id ⇒ Fixnum
The ID of the filter view.
Corresponds to the JSON property filterViewId
5862 5863 5864 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5862 def filter_view_id @filter_view_id end |
#named_range_id ⇒ String
The named range this filter view is backed by, if any. When writing, only one
of range, named_range_id, or table_id may be set.
Corresponds to the JSON property namedRangeId
5868 5869 5870 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5868 def named_range_id @named_range_id end |
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property range
5885 5886 5887 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5885 def range @range end |
#sort_specs ⇒ Array<Google::Apis::SheetsV4::SortSpec>
The sort order per column. Later specifications are used when values are equal
in the earlier specifications.
Corresponds to the JSON property sortSpecs
5891 5892 5893 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5891 def sort_specs @sort_specs end |
#table_id ⇒ String
The table this filter view is backed by, if any. When writing, only one of
range, named_range_id, or table_id may be set.
Corresponds to the JSON property tableId
5897 5898 5899 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5897 def table_id @table_id end |
#title ⇒ String
The name of the filter view.
Corresponds to the JSON property title
5902 5903 5904 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5902 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 5909 def update!(**args) @criteria = args[:criteria] if args.key?(:criteria) @filter_specs = args[:filter_specs] if args.key?(:filter_specs) @filter_view_id = args[:filter_view_id] if args.key?(:filter_view_id) @named_range_id = args[:named_range_id] if args.key?(:named_range_id) @range = args[:range] if args.key?(:range) @sort_specs = args[:sort_specs] if args.key?(:sort_specs) @table_id = args[:table_id] if args.key?(:table_id) @title = args[:title] if args.key?(:title) end |