Class: Google::Apis::SheetsV4::GridRange
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::GridRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Instance Attribute Summary collapse
-
#end_column_index ⇒ Fixnum
The end column (exclusive) of the range, or not set if unbounded.
-
#end_row_index ⇒ Fixnum
The end row (exclusive) of the range, or not set if unbounded.
-
#sheet_id ⇒ Fixnum
The sheet this range is on.
-
#start_column_index ⇒ Fixnum
The start column (inclusive) of the range, or not set if unbounded.
-
#start_row_index ⇒ Fixnum
The start row (inclusive) of the range, or not set if unbounded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GridRange
constructor
A new instance of GridRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GridRange
Returns a new instance of GridRange.
6303 6304 6305 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_column_index ⇒ Fixnum
The end column (exclusive) of the range, or not set if unbounded.
Corresponds to the JSON property endColumnIndex
6281 6282 6283 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6281 def end_column_index @end_column_index end |
#end_row_index ⇒ Fixnum
The end row (exclusive) of the range, or not set if unbounded.
Corresponds to the JSON property endRowIndex
6286 6287 6288 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6286 def end_row_index @end_row_index end |
#sheet_id ⇒ Fixnum
The sheet this range is on.
Corresponds to the JSON property sheetId
6291 6292 6293 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6291 def sheet_id @sheet_id end |
#start_column_index ⇒ Fixnum
The start column (inclusive) of the range, or not set if unbounded.
Corresponds to the JSON property startColumnIndex
6296 6297 6298 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6296 def start_column_index @start_column_index end |
#start_row_index ⇒ Fixnum
The start row (inclusive) of the range, or not set if unbounded.
Corresponds to the JSON property startRowIndex
6301 6302 6303 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6301 def start_row_index @start_row_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6308 6309 6310 6311 6312 6313 6314 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 6308 def update!(**args) @end_column_index = args[:end_column_index] if args.key?(:end_column_index) @end_row_index = args[:end_row_index] if args.key?(:end_row_index) @sheet_id = args[:sheet_id] if args.key?(:sheet_id) @start_column_index = args[:start_column_index] if args.key?(:start_column_index) @start_row_index = args[:start_row_index] if args.key?(:start_row_index) end |