Class: Google::Apis::SheetsV4::NamedRange
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::NamedRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A named range.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the named range.
-
#named_range_id ⇒ String
The ID of the named range.
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NamedRange
constructor
A new instance of NamedRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NamedRange
Returns a new instance of NamedRange.
7038 7039 7040 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the named range.
Corresponds to the JSON property name
7014 7015 7016 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7014 def name @name end |
#named_range_id ⇒ String
The ID of the named range.
Corresponds to the JSON property namedRangeId
7019 7020 7021 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7019 def named_range_id @named_range_id end |
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property range
7036 7037 7038 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7036 def range @range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7043 7044 7045 7046 7047 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7043 def update!(**args) @name = args[:name] if args.key?(:name) @named_range_id = args[:named_range_id] if args.key?(:named_range_id) @range = args[:range] if args.key?(:range) end |