Class: Google::Apis::SheetsV4::PivotTable
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::PivotTable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A pivot table.
Instance Attribute Summary collapse
-
#columns ⇒ Array<Google::Apis::SheetsV4::PivotGroup>
Each column grouping in the pivot table.
-
#criteria ⇒ Hash<String,Google::Apis::SheetsV4::PivotFilterCriteria>
An optional mapping of filters per source column offset.
-
#data_execution_status ⇒ Google::Apis::SheetsV4::DataExecutionStatus
The data execution status.
-
#data_source_id ⇒ String
The ID of the data source the pivot table is reading data from.
-
#filter_specs ⇒ Array<Google::Apis::SheetsV4::PivotFilterSpec>
The filters applied to the source columns before aggregating data for the pivot table.
-
#rows ⇒ Array<Google::Apis::SheetsV4::PivotGroup>
Each row grouping in the pivot table.
-
#source ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#value_layout ⇒ String
Whether values should be listed horizontally (as columns) or vertically (as rows).
-
#values ⇒ Array<Google::Apis::SheetsV4::PivotValue>
A list of values to include in the pivot table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PivotTable
constructor
A new instance of PivotTable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PivotTable
Returns a new instance of PivotTable.
7831 7832 7833 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<Google::Apis::SheetsV4::PivotGroup>
Each column grouping in the pivot table.
Corresponds to the JSON property columns
7761 7762 7763 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7761 def columns @columns end |
#criteria ⇒ Hash<String,Google::Apis::SheetsV4::PivotFilterCriteria>
An optional mapping of filters per source column offset. The filters are
applied before aggregating data into the pivot table. The map's key is the
column offset of the source range that you want to filter, and the value is
the criteria for that column. For example, if the source was C10:E15, a key
of 0 will have the filter for column C, whereas the key 1 is for column
D. This field is deprecated in favor of filter_specs.
Corresponds to the JSON property criteria
7771 7772 7773 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7771 def criteria @criteria end |
#data_execution_status ⇒ Google::Apis::SheetsV4::DataExecutionStatus
The data execution status. A data execution is created to sync a data source
object with the latest data from a DataSource. It is usually scheduled to run
at background, you can check its state to tell if an execution completes There
are several scenarios where a data execution is triggered to run: * Adding a
data source creates an associated data source sheet as well as a data
execution to sync the data from the data source to the sheet. * Updating a
data source creates a data execution to refresh the associated data source
sheet similarly. * You can send refresh request to explicitly refresh one or
multiple data source objects.
Corresponds to the JSON property dataExecutionStatus
7784 7785 7786 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7784 def data_execution_status @data_execution_status end |
#data_source_id ⇒ String
The ID of the data source the pivot table is reading data from.
Corresponds to the JSON property dataSourceId
7789 7790 7791 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7789 def data_source_id @data_source_id end |
#filter_specs ⇒ Array<Google::Apis::SheetsV4::PivotFilterSpec>
The filters applied to the source columns before aggregating data for the
pivot table. Both criteria and filter_specs are populated in responses. If
both fields are specified in an update request, this field takes precedence.
Corresponds to the JSON property filterSpecs
7796 7797 7798 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7796 def filter_specs @filter_specs end |
#rows ⇒ Array<Google::Apis::SheetsV4::PivotGroup>
Each row grouping in the pivot table.
Corresponds to the JSON property rows
7801 7802 7803 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7801 def rows @rows end |
#source ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property source
7818 7819 7820 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7818 def source @source end |
#value_layout ⇒ String
Whether values should be listed horizontally (as columns) or vertically (as
rows).
Corresponds to the JSON property valueLayout
7824 7825 7826 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7824 def value_layout @value_layout end |
#values ⇒ Array<Google::Apis::SheetsV4::PivotValue>
A list of values to include in the pivot table.
Corresponds to the JSON property values
7829 7830 7831 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7829 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7836 def update!(**args) @columns = args[:columns] if args.key?(:columns) @criteria = args[:criteria] if args.key?(:criteria) @data_execution_status = args[:data_execution_status] if args.key?(:data_execution_status) @data_source_id = args[:data_source_id] if args.key?(:data_source_id) @filter_specs = args[:filter_specs] if args.key?(:filter_specs) @rows = args[:rows] if args.key?(:rows) @source = args[:source] if args.key?(:source) @value_layout = args[:value_layout] if args.key?(:value_layout) @values = args[:values] if args.key?(:values) end |