Class: Google::Apis::SheetsV4::PivotValue
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::PivotValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The definition of how a value in a pivot table should be calculated.
Instance Attribute Summary collapse
-
#calculated_display_type ⇒ String
If specified, indicates that pivot values should be displayed as the result of a calculation with another pivot value.
-
#data_source_column_reference ⇒ Google::Apis::SheetsV4::DataSourceColumnReference
An unique identifier that references a data source column.
-
#formula ⇒ String
A custom formula to calculate the value.
-
#name ⇒ String
A name to use for the value.
-
#source_column_offset ⇒ Fixnum
The column offset of the source range that this value reads from.
-
#summarize_function ⇒ String
A function to summarize the value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PivotValue
constructor
A new instance of PivotValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PivotValue
Returns a new instance of PivotValue.
7892 7893 7894 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7892 def initialize(**args) update!(**args) end |
Instance Attribute Details
#calculated_display_type ⇒ String
If specified, indicates that pivot values should be displayed as the result of
a calculation with another pivot value. For example, if
calculated_display_type is specified as PERCENT_OF_GRAND_TOTAL, all the pivot
values are displayed as the percentage of the grand total. In the Sheets
editor, this is referred to as "Show As" in the value section of a pivot table.
Corresponds to the JSON property calculatedDisplayType
7860 7861 7862 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7860 def calculated_display_type @calculated_display_type end |
#data_source_column_reference ⇒ Google::Apis::SheetsV4::DataSourceColumnReference
An unique identifier that references a data source column.
Corresponds to the JSON property dataSourceColumnReference
7865 7866 7867 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7865 def data_source_column_reference @data_source_column_reference end |
#formula ⇒ String
A custom formula to calculate the value. The formula must start with an =
character.
Corresponds to the JSON property formula
7871 7872 7873 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7871 def formula @formula end |
#name ⇒ String
A name to use for the value.
Corresponds to the JSON property name
7876 7877 7878 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7876 def name @name end |
#source_column_offset ⇒ Fixnum
The column offset of the source range that this value reads from. For example,
if the source was C10:E15, a sourceColumnOffset of 0 means this value
refers to column C, whereas the offset 1 would refer to column D.
Corresponds to the JSON property sourceColumnOffset
7883 7884 7885 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7883 def source_column_offset @source_column_offset end |
#summarize_function ⇒ String
A function to summarize the value. If formula is set, the only supported
values are SUM and CUSTOM. If sourceColumnOffset is set, then CUSTOM is not
supported.
Corresponds to the JSON property summarizeFunction
7890 7891 7892 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7890 def summarize_function @summarize_function end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7897 7898 7899 7900 7901 7902 7903 7904 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 7897 def update!(**args) @calculated_display_type = args[:calculated_display_type] if args.key?(:calculated_display_type) @data_source_column_reference = args[:data_source_column_reference] if args.key?(:data_source_column_reference) @formula = args[:formula] if args.key?(:formula) @name = args[:name] if args.key?(:name) @source_column_offset = args[:source_column_offset] if args.key?(:source_column_offset) @summarize_function = args[:summarize_function] if args.key?(:summarize_function) end |