Class: Google::Apis::SheetsV4::Response
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::Response
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A single response from an update.
Instance Attribute Summary collapse
-
#add_banding ⇒ Google::Apis::SheetsV4::AddBandingResponse
The result of adding a banded range.
-
#add_chart ⇒ Google::Apis::SheetsV4::AddChartResponse
The result of adding a chart to a spreadsheet.
-
#add_data_source ⇒ Google::Apis::SheetsV4::AddDataSourceResponse
The result of adding a data source.
-
#add_dimension_group ⇒ Google::Apis::SheetsV4::AddDimensionGroupResponse
The result of adding a group.
-
#add_filter_view ⇒ Google::Apis::SheetsV4::AddFilterViewResponse
The result of adding a filter view.
-
#add_named_range ⇒ Google::Apis::SheetsV4::AddNamedRangeResponse
The result of adding a named range.
-
#add_protected_range ⇒ Google::Apis::SheetsV4::AddProtectedRangeResponse
The result of adding a new protected range.
-
#add_sheet ⇒ Google::Apis::SheetsV4::AddSheetResponse
The result of adding a sheet.
-
#add_slicer ⇒ Google::Apis::SheetsV4::AddSlicerResponse
The result of adding a slicer to a spreadsheet.
-
#add_table ⇒ Google::Apis::SheetsV4::AddTableResponse
The result of adding a table.
-
#cancel_data_source_refresh ⇒ Google::Apis::SheetsV4::CancelDataSourceRefreshResponse
The response from cancelling one or multiple data source object refreshes.
-
#create_developer_metadata ⇒ Google::Apis::SheetsV4::CreateDeveloperMetadataResponse
The response from creating developer metadata.
-
#delete_conditional_format_rule ⇒ Google::Apis::SheetsV4::DeleteConditionalFormatRuleResponse
The result of deleting a conditional format rule.
-
#delete_developer_metadata ⇒ Google::Apis::SheetsV4::DeleteDeveloperMetadataResponse
The response from deleting developer metadata.
-
#delete_dimension_group ⇒ Google::Apis::SheetsV4::DeleteDimensionGroupResponse
The result of deleting a group.
-
#delete_duplicates ⇒ Google::Apis::SheetsV4::DeleteDuplicatesResponse
The result of removing duplicates in a range.
-
#duplicate_filter_view ⇒ Google::Apis::SheetsV4::DuplicateFilterViewResponse
The result of a filter view being duplicated.
-
#duplicate_sheet ⇒ Google::Apis::SheetsV4::DuplicateSheetResponse
The result of duplicating a sheet.
-
#find_replace ⇒ Google::Apis::SheetsV4::FindReplaceResponse
The result of the find/replace.
-
#refresh_data_source ⇒ Google::Apis::SheetsV4::RefreshDataSourceResponse
The response from refreshing one or multiple data source objects.
-
#trim_whitespace ⇒ Google::Apis::SheetsV4::TrimWhitespaceResponse
The result of trimming whitespace in cells.
-
#update_conditional_format_rule ⇒ Google::Apis::SheetsV4::UpdateConditionalFormatRuleResponse
The result of updating a conditional format rule.
-
#update_data_source ⇒ Google::Apis::SheetsV4::UpdateDataSourceResponse
The response from updating data source.
-
#update_developer_metadata ⇒ Google::Apis::SheetsV4::UpdateDeveloperMetadataResponse
The response from updating developer metadata.
-
#update_embedded_object_position ⇒ Google::Apis::SheetsV4::UpdateEmbeddedObjectPositionResponse
The result of updating an embedded object's position.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Response
constructor
A new instance of Response.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Response
Returns a new instance of Response.
8860 8861 8862 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8860 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_banding ⇒ Google::Apis::SheetsV4::AddBandingResponse
The result of adding a banded range.
Corresponds to the JSON property addBanding
8738 8739 8740 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8738 def add_banding @add_banding end |
#add_chart ⇒ Google::Apis::SheetsV4::AddChartResponse
The result of adding a chart to a spreadsheet.
Corresponds to the JSON property addChart
8743 8744 8745 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8743 def add_chart @add_chart end |
#add_data_source ⇒ Google::Apis::SheetsV4::AddDataSourceResponse
The result of adding a data source.
Corresponds to the JSON property addDataSource
8748 8749 8750 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8748 def add_data_source @add_data_source end |
#add_dimension_group ⇒ Google::Apis::SheetsV4::AddDimensionGroupResponse
The result of adding a group.
Corresponds to the JSON property addDimensionGroup
8753 8754 8755 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8753 def add_dimension_group @add_dimension_group end |
#add_filter_view ⇒ Google::Apis::SheetsV4::AddFilterViewResponse
The result of adding a filter view.
Corresponds to the JSON property addFilterView
8758 8759 8760 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8758 def add_filter_view @add_filter_view end |
#add_named_range ⇒ Google::Apis::SheetsV4::AddNamedRangeResponse
The result of adding a named range.
Corresponds to the JSON property addNamedRange
8763 8764 8765 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8763 def add_named_range @add_named_range end |
#add_protected_range ⇒ Google::Apis::SheetsV4::AddProtectedRangeResponse
The result of adding a new protected range.
Corresponds to the JSON property addProtectedRange
8768 8769 8770 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8768 def add_protected_range @add_protected_range end |
#add_sheet ⇒ Google::Apis::SheetsV4::AddSheetResponse
The result of adding a sheet.
Corresponds to the JSON property addSheet
8773 8774 8775 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8773 def add_sheet @add_sheet end |
#add_slicer ⇒ Google::Apis::SheetsV4::AddSlicerResponse
The result of adding a slicer to a spreadsheet.
Corresponds to the JSON property addSlicer
8778 8779 8780 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8778 def add_slicer @add_slicer end |
#add_table ⇒ Google::Apis::SheetsV4::AddTableResponse
The result of adding a table.
Corresponds to the JSON property addTable
8783 8784 8785 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8783 def add_table @add_table end |
#cancel_data_source_refresh ⇒ Google::Apis::SheetsV4::CancelDataSourceRefreshResponse
The response from cancelling one or multiple data source object refreshes.
Corresponds to the JSON property cancelDataSourceRefresh
8788 8789 8790 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8788 def cancel_data_source_refresh @cancel_data_source_refresh end |
#create_developer_metadata ⇒ Google::Apis::SheetsV4::CreateDeveloperMetadataResponse
The response from creating developer metadata.
Corresponds to the JSON property createDeveloperMetadata
8793 8794 8795 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8793 def @create_developer_metadata end |
#delete_conditional_format_rule ⇒ Google::Apis::SheetsV4::DeleteConditionalFormatRuleResponse
The result of deleting a conditional format rule.
Corresponds to the JSON property deleteConditionalFormatRule
8798 8799 8800 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8798 def delete_conditional_format_rule @delete_conditional_format_rule end |
#delete_developer_metadata ⇒ Google::Apis::SheetsV4::DeleteDeveloperMetadataResponse
The response from deleting developer metadata.
Corresponds to the JSON property deleteDeveloperMetadata
8803 8804 8805 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8803 def @delete_developer_metadata end |
#delete_dimension_group ⇒ Google::Apis::SheetsV4::DeleteDimensionGroupResponse
The result of deleting a group.
Corresponds to the JSON property deleteDimensionGroup
8808 8809 8810 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8808 def delete_dimension_group @delete_dimension_group end |
#delete_duplicates ⇒ Google::Apis::SheetsV4::DeleteDuplicatesResponse
The result of removing duplicates in a range.
Corresponds to the JSON property deleteDuplicates
8813 8814 8815 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8813 def delete_duplicates @delete_duplicates end |
#duplicate_filter_view ⇒ Google::Apis::SheetsV4::DuplicateFilterViewResponse
The result of a filter view being duplicated.
Corresponds to the JSON property duplicateFilterView
8818 8819 8820 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8818 def duplicate_filter_view @duplicate_filter_view end |
#duplicate_sheet ⇒ Google::Apis::SheetsV4::DuplicateSheetResponse
The result of duplicating a sheet.
Corresponds to the JSON property duplicateSheet
8823 8824 8825 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8823 def duplicate_sheet @duplicate_sheet end |
#find_replace ⇒ Google::Apis::SheetsV4::FindReplaceResponse
The result of the find/replace.
Corresponds to the JSON property findReplace
8828 8829 8830 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8828 def find_replace @find_replace end |
#refresh_data_source ⇒ Google::Apis::SheetsV4::RefreshDataSourceResponse
The response from refreshing one or multiple data source objects.
Corresponds to the JSON property refreshDataSource
8833 8834 8835 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8833 def refresh_data_source @refresh_data_source end |
#trim_whitespace ⇒ Google::Apis::SheetsV4::TrimWhitespaceResponse
The result of trimming whitespace in cells.
Corresponds to the JSON property trimWhitespace
8838 8839 8840 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8838 def trim_whitespace @trim_whitespace end |
#update_conditional_format_rule ⇒ Google::Apis::SheetsV4::UpdateConditionalFormatRuleResponse
The result of updating a conditional format rule.
Corresponds to the JSON property updateConditionalFormatRule
8843 8844 8845 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8843 def update_conditional_format_rule @update_conditional_format_rule end |
#update_data_source ⇒ Google::Apis::SheetsV4::UpdateDataSourceResponse
The response from updating data source.
Corresponds to the JSON property updateDataSource
8848 8849 8850 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8848 def update_data_source @update_data_source end |
#update_developer_metadata ⇒ Google::Apis::SheetsV4::UpdateDeveloperMetadataResponse
The response from updating developer metadata.
Corresponds to the JSON property updateDeveloperMetadata
8853 8854 8855 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8853 def @update_developer_metadata end |
#update_embedded_object_position ⇒ Google::Apis::SheetsV4::UpdateEmbeddedObjectPositionResponse
The result of updating an embedded object's position.
Corresponds to the JSON property updateEmbeddedObjectPosition
8858 8859 8860 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8858 def @update_embedded_object_position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 8865 def update!(**args) @add_banding = args[:add_banding] if args.key?(:add_banding) @add_chart = args[:add_chart] if args.key?(:add_chart) @add_data_source = args[:add_data_source] if args.key?(:add_data_source) @add_dimension_group = args[:add_dimension_group] if args.key?(:add_dimension_group) @add_filter_view = args[:add_filter_view] if args.key?(:add_filter_view) @add_named_range = args[:add_named_range] if args.key?(:add_named_range) @add_protected_range = args[:add_protected_range] if args.key?(:add_protected_range) @add_sheet = args[:add_sheet] if args.key?(:add_sheet) @add_slicer = args[:add_slicer] if args.key?(:add_slicer) @add_table = args[:add_table] if args.key?(:add_table) @cancel_data_source_refresh = args[:cancel_data_source_refresh] if args.key?(:cancel_data_source_refresh) @create_developer_metadata = args[:create_developer_metadata] if args.key?(:create_developer_metadata) @delete_conditional_format_rule = args[:delete_conditional_format_rule] if args.key?(:delete_conditional_format_rule) @delete_developer_metadata = args[:delete_developer_metadata] if args.key?(:delete_developer_metadata) @delete_dimension_group = args[:delete_dimension_group] if args.key?(:delete_dimension_group) @delete_duplicates = args[:delete_duplicates] if args.key?(:delete_duplicates) @duplicate_filter_view = args[:duplicate_filter_view] if args.key?(:duplicate_filter_view) @duplicate_sheet = args[:duplicate_sheet] if args.key?(:duplicate_sheet) @find_replace = args[:find_replace] if args.key?(:find_replace) @refresh_data_source = args[:refresh_data_source] if args.key?(:refresh_data_source) @trim_whitespace = args[:trim_whitespace] if args.key?(:trim_whitespace) @update_conditional_format_rule = args[:update_conditional_format_rule] if args.key?(:update_conditional_format_rule) @update_data_source = args[:update_data_source] if args.key?(:update_data_source) @update_developer_metadata = args[:update_developer_metadata] if args.key?(:update_developer_metadata) @update_embedded_object_position = args[:update_embedded_object_position] if args.key?(:update_embedded_object_position) end |