Class: Google::Apis::SheetsV4::Sheet
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::Sheet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
A sheet in a spreadsheet.
Instance Attribute Summary collapse
-
#banded_ranges ⇒ Array<Google::Apis::SheetsV4::BandedRange>
The banded (alternating colors) ranges on this sheet.
-
#basic_filter ⇒ Google::Apis::SheetsV4::BasicFilter
The default filter associated with a sheet.
-
#charts ⇒ Array<Google::Apis::SheetsV4::EmbeddedChart>
The specifications of every chart on this sheet.
-
#column_groups ⇒ Array<Google::Apis::SheetsV4::DimensionGroup>
All column groups on this sheet, ordered by increasing range start index, then by group depth.
-
#conditional_formats ⇒ Array<Google::Apis::SheetsV4::ConditionalFormatRule>
The conditional format rules in this sheet.
-
#data ⇒ Array<Google::Apis::SheetsV4::GridData>
Data in the grid, if this is a grid sheet.
-
#developer_metadata ⇒ Array<Google::Apis::SheetsV4::DeveloperMetadata>
The developer metadata associated with a sheet.
-
#filter_views ⇒ Array<Google::Apis::SheetsV4::FilterView>
The filter views in this sheet.
-
#merges ⇒ Array<Google::Apis::SheetsV4::GridRange>
The ranges that are merged together.
-
#properties ⇒ Google::Apis::SheetsV4::SheetProperties
Properties of a sheet.
-
#protected_ranges ⇒ Array<Google::Apis::SheetsV4::ProtectedRange>
The protected ranges in this sheet.
-
#row_groups ⇒ Array<Google::Apis::SheetsV4::DimensionGroup>
All row groups on this sheet, ordered by increasing range start index, then by group depth.
-
#slicers ⇒ Array<Google::Apis::SheetsV4::Slicer>
The slicers on this sheet.
-
#tables ⇒ Array<Google::Apis::SheetsV4::Table>
The tables on this sheet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Sheet
constructor
A new instance of Sheet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Sheet
Returns a new instance of Sheet.
9205 9206 9207 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#banded_ranges ⇒ Array<Google::Apis::SheetsV4::BandedRange>
The banded (alternating colors) ranges on this sheet.
Corresponds to the JSON property bandedRanges
9127 9128 9129 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9127 def banded_ranges @banded_ranges end |
#basic_filter ⇒ Google::Apis::SheetsV4::BasicFilter
The default filter associated with a sheet. For more information, see Manage
data visibility with filters.
Corresponds to the JSON property basicFilter
9134 9135 9136 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9134 def basic_filter @basic_filter end |
#charts ⇒ Array<Google::Apis::SheetsV4::EmbeddedChart>
The specifications of every chart on this sheet.
Corresponds to the JSON property charts
9139 9140 9141 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9139 def charts @charts end |
#column_groups ⇒ Array<Google::Apis::SheetsV4::DimensionGroup>
All column groups on this sheet, ordered by increasing range start index, then
by group depth.
Corresponds to the JSON property columnGroups
9145 9146 9147 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9145 def column_groups @column_groups end |
#conditional_formats ⇒ Array<Google::Apis::SheetsV4::ConditionalFormatRule>
The conditional format rules in this sheet.
Corresponds to the JSON property conditionalFormats
9150 9151 9152 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9150 def conditional_formats @conditional_formats end |
#data ⇒ Array<Google::Apis::SheetsV4::GridData>
Data in the grid, if this is a grid sheet. The number of GridData objects
returned is dependent on the number of ranges requested on this sheet. For
example, if this is representing Sheet1, and the spreadsheet was requested
with ranges Sheet1!A1:C10 and Sheet1!D15:E20, then the first GridData will
have a startRow/startColumn of 0, while the second one will have startRow
14 (zero-based row 15), and startColumn 3 (zero-based column D). For a
DATA_SOURCE sheet, you can not request a specific range, the GridData contains
all the values.
Corresponds to the JSON property data
9162 9163 9164 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9162 def data @data end |
#developer_metadata ⇒ Array<Google::Apis::SheetsV4::DeveloperMetadata>
The developer metadata associated with a sheet.
Corresponds to the JSON property developerMetadata
9167 9168 9169 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9167 def @developer_metadata end |
#filter_views ⇒ Array<Google::Apis::SheetsV4::FilterView>
The filter views in this sheet.
Corresponds to the JSON property filterViews
9172 9173 9174 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9172 def filter_views @filter_views end |
#merges ⇒ Array<Google::Apis::SheetsV4::GridRange>
The ranges that are merged together.
Corresponds to the JSON property merges
9177 9178 9179 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9177 def merges @merges end |
#properties ⇒ Google::Apis::SheetsV4::SheetProperties
Properties of a sheet.
Corresponds to the JSON property properties
9182 9183 9184 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9182 def properties @properties end |
#protected_ranges ⇒ Array<Google::Apis::SheetsV4::ProtectedRange>
The protected ranges in this sheet.
Corresponds to the JSON property protectedRanges
9187 9188 9189 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9187 def protected_ranges @protected_ranges end |
#row_groups ⇒ Array<Google::Apis::SheetsV4::DimensionGroup>
All row groups on this sheet, ordered by increasing range start index, then by
group depth.
Corresponds to the JSON property rowGroups
9193 9194 9195 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9193 def row_groups @row_groups end |
#slicers ⇒ Array<Google::Apis::SheetsV4::Slicer>
The slicers on this sheet.
Corresponds to the JSON property slicers
9198 9199 9200 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9198 def slicers @slicers end |
#tables ⇒ Array<Google::Apis::SheetsV4::Table>
The tables on this sheet.
Corresponds to the JSON property tables
9203 9204 9205 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9203 def tables @tables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 9210 def update!(**args) @banded_ranges = args[:banded_ranges] if args.key?(:banded_ranges) @basic_filter = args[:basic_filter] if args.key?(:basic_filter) @charts = args[:charts] if args.key?(:charts) @column_groups = args[:column_groups] if args.key?(:column_groups) @conditional_formats = args[:conditional_formats] if args.key?(:conditional_formats) @data = args[:data] if args.key?(:data) @developer_metadata = args[:developer_metadata] if args.key?(:developer_metadata) @filter_views = args[:filter_views] if args.key?(:filter_views) @merges = args[:merges] if args.key?(:merges) @properties = args[:properties] if args.key?(:properties) @protected_ranges = args[:protected_ranges] if args.key?(:protected_ranges) @row_groups = args[:row_groups] if args.key?(:row_groups) @slicers = args[:slicers] if args.key?(:slicers) @tables = args[:tables] if args.key?(:tables) end |