Class: Google::Apis::SheetsV4::TextFormat
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::TextFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
The format of a run of text in a cell. Absent values indicate that the field isn't specified.
Instance Attribute Summary collapse
-
#bold ⇒ Boolean
(also: #bold?)
True if the text is bold.
-
#font_family ⇒ String
The font family.
-
#font_size ⇒ Fixnum
The size of the font.
-
#foreground_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space.
-
#foreground_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
-
#italic ⇒ Boolean
(also: #italic?)
True if the text is italicized.
-
#link ⇒ Google::Apis::SheetsV4::Link
An external or local reference.
-
#strikethrough ⇒ Boolean
(also: #strikethrough?)
True if the text has a strikethrough.
-
#underline ⇒ Boolean
(also: #underline?)
True if the text is underlined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TextFormat
constructor
A new instance of TextFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TextFormat
Returns a new instance of TextFormat.
10146 10147 10148 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bold ⇒ Boolean Also known as: bold?
True if the text is bold.
Corresponds to the JSON property bold
10056 10057 10058 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10056 def bold @bold end |
#font_family ⇒ String
The font family.
Corresponds to the JSON property fontFamily
10062 10063 10064 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10062 def font_family @font_family end |
#font_size ⇒ Fixnum
The size of the font.
Corresponds to the JSON property fontSize
10067 10068 10069 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10067 def font_size @font_size end |
#foreground_color ⇒ Google::Apis::SheetsV4::Color
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property foregroundColor
10116 10117 10118 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10116 def foreground_color @foreground_color end |
#foreground_color_style ⇒ Google::Apis::SheetsV4::ColorStyle
A color value.
Corresponds to the JSON property foregroundColorStyle
10121 10122 10123 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10121 def foreground_color_style @foreground_color_style end |
#italic ⇒ Boolean Also known as: italic?
True if the text is italicized.
Corresponds to the JSON property italic
10126 10127 10128 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10126 def italic @italic end |
#link ⇒ Google::Apis::SheetsV4::Link
An external or local reference.
Corresponds to the JSON property link
10132 10133 10134 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10132 def link @link end |
#strikethrough ⇒ Boolean Also known as: strikethrough?
True if the text has a strikethrough.
Corresponds to the JSON property strikethrough
10137 10138 10139 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10137 def strikethrough @strikethrough end |
#underline ⇒ Boolean Also known as: underline?
True if the text is underlined.
Corresponds to the JSON property underline
10143 10144 10145 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10143 def underline @underline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10151 10152 10153 10154 10155 10156 10157 10158 10159 10160 10161 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10151 def update!(**args) @bold = args[:bold] if args.key?(:bold) @font_family = args[:font_family] if args.key?(:font_family) @font_size = args[:font_size] if args.key?(:font_size) @foreground_color = args[:foreground_color] if args.key?(:foreground_color) @foreground_color_style = args[:foreground_color_style] if args.key?(:foreground_color_style) @italic = args[:italic] if args.key?(:italic) @link = args[:link] if args.key?(:link) @strikethrough = args[:strikethrough] if args.key?(:strikethrough) @underline = args[:underline] if args.key?(:underline) end |