Class: Google::Apis::SheetsV4::UpdateBordersRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::UpdateBordersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sheets_v4/classes.rb,
lib/google/apis/sheets_v4/representations.rb,
lib/google/apis/sheets_v4/representations.rb
Overview
Updates the borders of a range. If a field is not set in the request, that
means the border remains as-is. For example, with two subsequent
UpdateBordersRequest: 1. range: A1:A5 top: RED, bottom: WHITE 2. range:
A1:A5 left: BLUE That would result in A1:A5 having a borders of top:
RED, bottom: WHITE, left: BLUE. If you want to clear a border, explicitly
set the style to NONE.
Instance Attribute Summary collapse
-
#bottom ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#inner_horizontal ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#inner_vertical ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#left ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#right ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#top ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateBordersRequest
constructor
A new instance of UpdateBordersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateBordersRequest
Returns a new instance of UpdateBordersRequest.
10909 10910 10911 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10909 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bottom ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property bottom
10865 10866 10867 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10865 def bottom @bottom end |
#inner_horizontal ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property innerHorizontal
10870 10871 10872 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10870 def inner_horizontal @inner_horizontal end |
#inner_vertical ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property innerVertical
10875 10876 10877 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10875 def inner_vertical @inner_vertical end |
#left ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property left
10880 10881 10882 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10880 def left @left end |
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet. All indexes are zero-based. Indexes are half open, i.e.
the start index is inclusive and the end index is exclusive -- [start_index,
end_index). Missing indexes indicate the range is unbounded on that side. For
example, if "Sheet1" is sheet ID 123456, then: Sheet1!A1:A1 == sheet_id:
123456, start_row_index: 0, end_row_index: 1, start_column_index: 0,
end_column_index: 1 Sheet1!A3:B4 == sheet_id: 123456, start_row_index: 2,
end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B ==
sheet_id: 123456, start_column_index: 0, end_column_index: 2 Sheet1!A5:B ==
sheet_id: 123456, start_row_index: 4, start_column_index: 0, end_column_index:
2 Sheet1 == sheet_id: 123456 The start index must always be less than or
equal to the end index. If the start index equals the end index, then the
range is empty. Empty ranges are typically not meaningful and are usually
rendered in the UI as #REF!.
Corresponds to the JSON property range
10897 10898 10899 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10897 def range @range end |
#right ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property right
10902 10903 10904 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10902 def right @right end |
#top ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property top
10907 10908 10909 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10907 def top @top end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10914 10915 10916 10917 10918 10919 10920 10921 10922 |
# File 'lib/google/apis/sheets_v4/classes.rb', line 10914 def update!(**args) @bottom = args[:bottom] if args.key?(:bottom) @inner_horizontal = args[:inner_horizontal] if args.key?(:inner_horizontal) @inner_vertical = args[:inner_vertical] if args.key?(:inner_vertical) @left = args[:left] if args.key?(:left) @range = args[:range] if args.key?(:range) @right = args[:right] if args.key?(:right) @top = args[:top] if args.key?(:top) end |